# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/device.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from voltha_protos import common_pb2 as voltha__protos_dot_common__pb2
from voltha_protos import openflow_13_pb2 as voltha__protos_dot_openflow__13__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1avoltha_protos/device.proto\x12\x06\x64\x65vice\x1a\x19google/protobuf/any.proto\x1a\x1avoltha_protos/common.proto\x1a\x1fvoltha_protos/openflow_13.proto\"\xde\x01\n\nDeviceType\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tvendor_id\x18\x05 \x01(\t\x12\x12\n\nvendor_ids\x18\x06 \x03(\t\x12\x0f\n\x07\x61\x64\x61pter\x18\x02 \x01(\t\x12 \n\x18\x61\x63\x63\x65pts_bulk_flow_update\x18\x03 \x01(\x08\x12\'\n\x1f\x61\x63\x63\x65pts_add_remove_flow_updates\x18\x04 \x01(\x08\x12+\n#accepts_direct_logical_flows_update\x18\x07 \x01(\x08\x12\x14\n\x0c\x61\x64\x61pter_type\x18\x08 \x01(\t\"0\n\x0b\x44\x65viceTypes\x12!\n\x05items\x18\x01 \x03(\x0b\x32\x12.device.DeviceType\"\x9f\x01\n\x08PmConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12%\n\x04type\x18\x02 \x01(\x0e\x32\x17.device.PmConfig.PmType\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x12\x13\n\x0bsample_freq\x18\x04 \x01(\r\"8\n\x06PmType\x12\x0b\n\x07\x43OUNTER\x10\x00\x12\t\n\x05GAUGE\x10\x01\x12\t\n\x05STATE\x10\x02\x12\x0b\n\x07\x43ONTEXT\x10\x03\"k\n\rPmGroupConfig\x12\x12\n\ngroup_name\x18\x01 \x01(\t\x12\x12\n\ngroup_freq\x18\x02 \x01(\r\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x12!\n\x07metrics\x18\x04 \x03(\x0b\x32\x10.device.PmConfig\"\xb1\x01\n\tPmConfigs\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0c\x64\x65\x66\x61ult_freq\x18\x02 \x01(\r\x12\x0f\n\x07grouped\x18\x03 \x01(\x08\x12\x15\n\rfreq_override\x18\x04 \x01(\x08\x12%\n\x06groups\x18\x05 \x03(\x0b\x32\x15.device.PmGroupConfig\x12!\n\x07metrics\x18\x06 \x03(\x0b\x32\x10.device.PmConfig\x12\x10\n\x08max_skew\x18\x07 \x01(\r\"\xb5\x01\n\x05Image\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0c\n\x04hash\x18\x03 \x01(\r\x12\x18\n\x10install_datetime\x18\x04 \x01(\t\x12\x11\n\tis_active\x18\x05 \x01(\x08\x12\x14\n\x0cis_committed\x18\x06 \x01(\x08\x12\x10\n\x08is_valid\x18\x07 \x01(\x08\x12\x0b\n\x03url\x18\x08 \x01(\t\x12\x0e\n\x06vendor\x18\t \x01(\t\x12\r\n\x05\x63rc32\x18\n \x01(\r\"\xe1\x06\n\rImageDownload\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x0b\n\x03\x63rc\x18\x04 \x01(\r\x12@\n\x0e\x64ownload_state\x18\x05 \x01(\x0e\x32(.device.ImageDownload.ImageDownloadState\x12\x15\n\rimage_version\x18\x06 \x01(\t\x12\x18\n\x10\x64ownloaded_bytes\x18\x07 \x01(\r\x12@\n\x06reason\x18\x08 \x01(\x0e\x32\x30.device.ImageDownload.ImageDownloadFailureReason\x12\x17\n\x0f\x61\x64\x64itional_info\x18\t \x01(\t\x12\x13\n\x0bsave_config\x18\n \x01(\x08\x12\x11\n\tlocal_dir\x18\x0b \x01(\t\x12=\n\x0bimage_state\x18\x0c \x01(\x0e\x32(.device.ImageDownload.ImageActivateState\x12\x11\n\tfile_size\x18\r \x01(\r\"\xb7\x01\n\x12ImageDownloadState\x12\x14\n\x10\x44OWNLOAD_UNKNOWN\x10\x00\x12\x16\n\x12\x44OWNLOAD_SUCCEEDED\x10\x01\x12\x16\n\x12\x44OWNLOAD_REQUESTED\x10\x02\x12\x14\n\x10\x44OWNLOAD_STARTED\x10\x03\x12\x13\n\x0f\x44OWNLOAD_FAILED\x10\x04\x12\x18\n\x14\x44OWNLOAD_UNSUPPORTED\x10\x05\x12\x16\n\x12\x44OWNLOAD_CANCELLED\x10\x06\"\x86\x01\n\x1aImageDownloadFailureReason\x12\x0c\n\x08NO_ERROR\x10\x00\x12\x0f\n\x0bINVALID_URL\x10\x01\x12\x0f\n\x0b\x44\x45VICE_BUSY\x10\x02\x12\x16\n\x12INSUFFICIENT_SPACE\x10\x03\x12\x11\n\rUNKNOWN_ERROR\x10\x04\x12\r\n\tCANCELLED\x10\x05\"\x8c\x01\n\x12ImageActivateState\x12\x11\n\rIMAGE_UNKNOWN\x10\x00\x12\x12\n\x0eIMAGE_INACTIVE\x10\x01\x12\x14\n\x10IMAGE_ACTIVATING\x10\x02\x12\x10\n\x0cIMAGE_ACTIVE\x10\x03\x12\x13\n\x0fIMAGE_REVERTING\x10\x04\x12\x12\n\x0eIMAGE_REVERTED\x10\x05:\x02\x18\x01\":\n\x0eImageDownloads\x12$\n\x05items\x18\x02 \x03(\x0b\x32\x15.device.ImageDownload:\x02\x18\x01\"&\n\x06Images\x12\x1c\n\x05image\x18\x01 \x03(\x0b\x32\r.device.Image\"u\n\x08OnuImage\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x12\n\nisCommited\x18\x02 \x01(\x08\x12\x10\n\x08isActive\x18\x03 \x01(\x08\x12\x0f\n\x07isValid\x18\x04 \x01(\x08\x12\x13\n\x0bproductCode\x18\x05 \x01(\t\x12\x0c\n\x04hash\x18\x06 \x01(\t\",\n\tOnuImages\x12\x1f\n\x05items\x18\x01 \x03(\x0b\x32\x10.device.OnuImage\"M\n\x10\x44\x65viceImageState\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12&\n\nimageState\x18\x02 \x01(\x0b\x32\x12.device.ImageState\"\xd6\x07\n\nImageState\x12\x0f\n\x07version\x18\x01 \x01(\t\x12=\n\x0e\x64ownload_state\x18\x02 \x01(\x0e\x32%.device.ImageState.ImageDownloadState\x12\x35\n\x06reason\x18\x03 \x01(\x0e\x32%.device.ImageState.ImageFailureReason\x12<\n\x0bimage_state\x18\x04 \x01(\x0e\x32\'.device.ImageState.ImageActivationState\"\xd0\x01\n\x12ImageDownloadState\x12\x14\n\x10\x44OWNLOAD_UNKNOWN\x10\x00\x12\x16\n\x12\x44OWNLOAD_SUCCEEDED\x10\x01\x12\x16\n\x12\x44OWNLOAD_REQUESTED\x10\x02\x12\x14\n\x10\x44OWNLOAD_STARTED\x10\x03\x12\x13\n\x0f\x44OWNLOAD_FAILED\x10\x04\x12\x18\n\x14\x44OWNLOAD_UNSUPPORTED\x10\x05\x12\x17\n\x13\x44OWNLOAD_CANCELLING\x10\x06\x12\x16\n\x12\x44OWNLOAD_CANCELLED\x10\x07\"\xf4\x01\n\x12ImageFailureReason\x12\x0c\n\x08NO_ERROR\x10\x00\x12\x0f\n\x0bINVALID_URL\x10\x01\x12\x0f\n\x0b\x44\x45VICE_BUSY\x10\x02\x12\x16\n\x12INSUFFICIENT_SPACE\x10\x03\x12\x11\n\rUNKNOWN_ERROR\x10\x04\x12\x18\n\x14\x43\x41NCELLED_ON_REQUEST\x10\x05\x12\x1a\n\x16\x43\x41NCELLED_ON_ONU_STATE\x10\x06\x12\x1a\n\x16VENDOR_DEVICE_MISMATCH\x10\x07\x12\x17\n\x13OMCI_TRANSFER_ERROR\x10\x08\x12\x18\n\x14IMAGE_REFUSED_BY_ONU\x10\t\"\xb8\x02\n\x14ImageActivationState\x12\x11\n\rIMAGE_UNKNOWN\x10\x00\x12\x12\n\x0eIMAGE_INACTIVE\x10\x01\x12\x14\n\x10IMAGE_ACTIVATING\x10\x02\x12\x10\n\x0cIMAGE_ACTIVE\x10\x03\x12\x14\n\x10IMAGE_COMMITTING\x10\x04\x12\x13\n\x0fIMAGE_COMMITTED\x10\x05\x12\x1d\n\x19IMAGE_ACTIVATION_ABORTING\x10\x06\x12\x1c\n\x18IMAGE_ACTIVATION_ABORTED\x10\x07\x12\x19\n\x15IMAGE_COMMIT_ABORTING\x10\x08\x12\x18\n\x14IMAGE_COMMIT_ABORTED\x10\t\x12\x15\n\x11IMAGE_DOWNLOADING\x10\n\x12\x1d\n\x19IMAGE_DOWNLOADING_ABORTED\x10\x0b\"\xa2\x04\n\x04Port\x12\x0f\n\x07port_no\x18\x01 \x01(\r\x12\r\n\x05label\x18\x02 \x01(\t\x12#\n\x04type\x18\x03 \x01(\x0e\x32\x15.device.Port.PortType\x12-\n\x0b\x61\x64min_state\x18\x05 \x01(\x0e\x32\x18.common.AdminState.Types\x12-\n\x0boper_status\x18\x06 \x01(\x0e\x32\x18.common.OperStatus.Types\x12\x11\n\tdevice_id\x18\x07 \x01(\t\x12$\n\x05peers\x18\x08 \x03(\x0b\x32\x15.device.Port.PeerPort\x12\x12\n\nrx_packets\x18\t \x01(\x06\x12\x10\n\x08rx_bytes\x18\n \x01(\x06\x12\x11\n\trx_errors\x18\x0b \x01(\x06\x12\x12\n\ntx_packets\x18\x0c \x01(\x06\x12\x10\n\x08tx_bytes\x18\r \x01(\x06\x12\x11\n\ttx_errors\x18\x0e \x01(\x06\x12\'\n\x08ofp_port\x18\x0f \x01(\x0b\x32\x15.openflow_13.ofp_port\x1a.\n\x08PeerPort\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x0f\n\x07port_no\x18\x02 \x01(\r\"s\n\x08PortType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x10\n\x0c\x45THERNET_NNI\x10\x01\x12\x10\n\x0c\x45THERNET_UNI\x10\x02\x12\x0b\n\x07PON_OLT\x10\x03\x12\x0b\n\x07PON_ONU\x10\x04\x12\r\n\tVENET_OLT\x10\x05\x12\r\n\tVENET_ONU\x10\x06\"$\n\x05Ports\x12\x1b\n\x05items\x18\x01 \x03(\x0b\x32\x0c.device.Port\"\xbf\x07\n\x06\x44\x65vice\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0c\n\x04root\x18\x03 \x01(\x08\x12\x11\n\tparent_id\x18\x04 \x01(\t\x12\x16\n\x0eparent_port_no\x18\x14 \x01(\r\x12\x0e\n\x06vendor\x18\x05 \x01(\t\x12\r\n\x05model\x18\x06 \x01(\t\x12\x18\n\x10hardware_version\x18\x07 \x01(\t\x12\x18\n\x10\x66irmware_version\x18\x08 \x01(\t\x12\x1e\n\x06images\x18\t \x01(\x0b\x32\x0e.device.Images\x12\x15\n\rserial_number\x18\n \x01(\t\x12\x11\n\tvendor_id\x18\x18 \x01(\t\x12\x18\n\x10\x61\x64\x61pter_endpoint\x18\x19 \x01(\t\x12\x0c\n\x04vlan\x18\x0c \x01(\r\x12\x13\n\x0bmac_address\x18\r \x01(\t\x12\x16\n\x0cipv4_address\x18\x0e \x01(\tH\x00\x12\x16\n\x0cipv6_address\x18\x0f \x01(\tH\x00\x12\x17\n\rhost_and_port\x18\x15 \x01(\tH\x00\x12\x12\n\nextra_args\x18\x17 \x01(\t\x12\x32\n\rproxy_address\x18\x13 \x01(\x0b\x32\x1b.device.Device.ProxyAddress\x12-\n\x0b\x61\x64min_state\x18\x10 \x01(\x0e\x32\x18.common.AdminState.Types\x12-\n\x0boper_status\x18\x11 \x01(\x0e\x32\x18.common.OperStatus.Types\x12\x0e\n\x06reason\x18\x16 \x01(\t\x12\x33\n\x0e\x63onnect_status\x18\x12 \x01(\x0e\x32\x1b.common.ConnectStatus.Types\x12$\n\x06\x63ustom\x18@ \x01(\x0b\x32\x14.google.protobuf.Any\x12&\n\npm_configs\x18\x83\x01 \x01(\x0b\x32\x11.device.PmConfigs\x12/\n\x0fimage_downloads\x18\x85\x01 \x03(\x0b\x32\x15.device.ImageDownload\x1a\xc3\x01\n\x0cProxyAddress\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65vice_type\x18\x02 \x01(\t\x12\x12\n\nchannel_id\x18\x03 \x01(\r\x12\x18\n\x10\x63hannel_group_id\x18\x04 \x01(\r\x12\x1b\n\x13\x63hannel_termination\x18\x05 \x01(\t\x12\x0e\n\x06onu_id\x18\x06 \x01(\r\x12\x16\n\x0eonu_session_id\x18\x07 \x01(\r\x12\x18\n\x10\x61\x64\x61pter_endpoint\x18\x08 \x01(\tB\t\n\x07\x61\x64\x64ressJ\x04\x08\x0b\x10\x0c\"\x8d\x01\n\x1a\x44\x65viceImageDownloadRequest\x12\x1d\n\tdevice_id\x18\x01 \x03(\x0b\x32\n.common.ID\x12\x1c\n\x05image\x18\x02 \x01(\x0b\x32\r.device.Image\x12\x19\n\x11\x61\x63tivateOnSuccess\x18\x03 \x01(\x08\x12\x17\n\x0f\x63ommitOnSuccess\x18\x04 \x01(\x08\"]\n\x12\x44\x65viceImageRequest\x12\x1d\n\tdevice_id\x18\x01 \x03(\x0b\x32\n.common.ID\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x17\n\x0f\x63ommitOnSuccess\x18\x03 \x01(\x08\"L\n\x13\x44\x65viceImageResponse\x12\x35\n\x13\x64\x65vice_image_states\x18\x01 \x03(\x0b\x32\x18.device.DeviceImageState\"\x9d\x01\n\x10SelfTestResponse\x12\x37\n\x06result\x18\x01 \x01(\x0e\x32\'.device.SelfTestResponse.SelfTestResult\"P\n\x0eSelfTestResult\x12\x0b\n\x07SUCCESS\x10\x00\x12\x0b\n\x07\x46\x41ILURE\x10\x01\x12\x11\n\rNOT_SUPPORTED\x10\x02\x12\x11\n\rUNKNOWN_ERROR\x10\x03\"(\n\x07\x44\x65vices\x12\x1d\n\x05items\x18\x01 \x03(\x0b\x32\x0e.device.Device\"\xb6\x02\n\x14SimulateAlarmRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tindicator\x18\x02 \x01(\t\x12\x0f\n\x07intf_id\x18\x03 \x01(\t\x12\x16\n\x0eport_type_name\x18\x04 \x01(\t\x12\x15\n\ronu_device_id\x18\x05 \x01(\t\x12\x1e\n\x16inverse_bit_error_rate\x18\x06 \x01(\x05\x12\r\n\x05\x64rift\x18\x07 \x01(\x05\x12\x0f\n\x07new_eqd\x18\x08 \x01(\x05\x12\x19\n\x11onu_serial_number\x18\t \x01(\t\x12=\n\toperation\x18\n \x01(\x0e\x32*.device.SimulateAlarmRequest.OperationType\"%\n\rOperationType\x12\t\n\x05RAISE\x10\x00\x12\t\n\x05\x43LEAR\x10\x01\"o\n\x17OnuSerialNumberOnOLTPon\x12!\n\rolt_device_id\x18\x01 \x01(\x0b\x32\n.common.ID\x12\x1a\n\x04port\x18\x02 \x01(\x0b\x32\x0c.device.Port\x12\x15\n\rserial_number\x18\x03 \x01(\t\"n\n\x0cUpdateDevice\x12\n\n\x02id\x18\x01 \x01(\t\x12\x16\n\x0cipv4_address\x18\x02 \x01(\tH\x00\x12\x16\n\x0cipv6_address\x18\x03 \x01(\tH\x00\x12\x17\n\rhost_and_port\x18\x04 \x01(\tH\x00\x42\t\n\x07\x61\x64\x64ressBZ\n\x1aorg.opencord.voltha.deviceB\x0cVolthaDeviceZ.github.com/opencord/voltha-protos/v5/go/volthab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'voltha_protos.device_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032org.opencord.voltha.deviceB\014VolthaDeviceZ.github.com/opencord/voltha-protos/v5/go/voltha'
  _globals['_IMAGEDOWNLOAD']._options = None
  _globals['_IMAGEDOWNLOAD']._serialized_options = b'\030\001'
  _globals['_IMAGEDOWNLOADS']._options = None
  _globals['_IMAGEDOWNLOADS']._serialized_options = b'\030\001'
  _globals['_DEVICETYPE']._serialized_start=127
  _globals['_DEVICETYPE']._serialized_end=349
  _globals['_DEVICETYPES']._serialized_start=351
  _globals['_DEVICETYPES']._serialized_end=399
  _globals['_PMCONFIG']._serialized_start=402
  _globals['_PMCONFIG']._serialized_end=561
  _globals['_PMCONFIG_PMTYPE']._serialized_start=505
  _globals['_PMCONFIG_PMTYPE']._serialized_end=561
  _globals['_PMGROUPCONFIG']._serialized_start=563
  _globals['_PMGROUPCONFIG']._serialized_end=670
  _globals['_PMCONFIGS']._serialized_start=673
  _globals['_PMCONFIGS']._serialized_end=850
  _globals['_IMAGE']._serialized_start=853
  _globals['_IMAGE']._serialized_end=1034
  _globals['_IMAGEDOWNLOAD']._serialized_start=1037
  _globals['_IMAGEDOWNLOAD']._serialized_end=1902
  _globals['_IMAGEDOWNLOAD_IMAGEDOWNLOADSTATE']._serialized_start=1435
  _globals['_IMAGEDOWNLOAD_IMAGEDOWNLOADSTATE']._serialized_end=1618
  _globals['_IMAGEDOWNLOAD_IMAGEDOWNLOADFAILUREREASON']._serialized_start=1621
  _globals['_IMAGEDOWNLOAD_IMAGEDOWNLOADFAILUREREASON']._serialized_end=1755
  _globals['_IMAGEDOWNLOAD_IMAGEACTIVATESTATE']._serialized_start=1758
  _globals['_IMAGEDOWNLOAD_IMAGEACTIVATESTATE']._serialized_end=1898
  _globals['_IMAGEDOWNLOADS']._serialized_start=1904
  _globals['_IMAGEDOWNLOADS']._serialized_end=1962
  _globals['_IMAGES']._serialized_start=1964
  _globals['_IMAGES']._serialized_end=2002
  _globals['_ONUIMAGE']._serialized_start=2004
  _globals['_ONUIMAGE']._serialized_end=2121
  _globals['_ONUIMAGES']._serialized_start=2123
  _globals['_ONUIMAGES']._serialized_end=2167
  _globals['_DEVICEIMAGESTATE']._serialized_start=2169
  _globals['_DEVICEIMAGESTATE']._serialized_end=2246
  _globals['_IMAGESTATE']._serialized_start=2249
  _globals['_IMAGESTATE']._serialized_end=3231
  _globals['_IMAGESTATE_IMAGEDOWNLOADSTATE']._serialized_start=2461
  _globals['_IMAGESTATE_IMAGEDOWNLOADSTATE']._serialized_end=2669
  _globals['_IMAGESTATE_IMAGEFAILUREREASON']._serialized_start=2672
  _globals['_IMAGESTATE_IMAGEFAILUREREASON']._serialized_end=2916
  _globals['_IMAGESTATE_IMAGEACTIVATIONSTATE']._serialized_start=2919
  _globals['_IMAGESTATE_IMAGEACTIVATIONSTATE']._serialized_end=3231
  _globals['_PORT']._serialized_start=3234
  _globals['_PORT']._serialized_end=3780
  _globals['_PORT_PEERPORT']._serialized_start=3617
  _globals['_PORT_PEERPORT']._serialized_end=3663
  _globals['_PORT_PORTTYPE']._serialized_start=3665
  _globals['_PORT_PORTTYPE']._serialized_end=3780
  _globals['_PORTS']._serialized_start=3782
  _globals['_PORTS']._serialized_end=3818
  _globals['_DEVICE']._serialized_start=3821
  _globals['_DEVICE']._serialized_end=4780
  _globals['_DEVICE_PROXYADDRESS']._serialized_start=4568
  _globals['_DEVICE_PROXYADDRESS']._serialized_end=4763
  _globals['_DEVICEIMAGEDOWNLOADREQUEST']._serialized_start=4783
  _globals['_DEVICEIMAGEDOWNLOADREQUEST']._serialized_end=4924
  _globals['_DEVICEIMAGEREQUEST']._serialized_start=4926
  _globals['_DEVICEIMAGEREQUEST']._serialized_end=5019
  _globals['_DEVICEIMAGERESPONSE']._serialized_start=5021
  _globals['_DEVICEIMAGERESPONSE']._serialized_end=5097
  _globals['_SELFTESTRESPONSE']._serialized_start=5100
  _globals['_SELFTESTRESPONSE']._serialized_end=5257
  _globals['_SELFTESTRESPONSE_SELFTESTRESULT']._serialized_start=5177
  _globals['_SELFTESTRESPONSE_SELFTESTRESULT']._serialized_end=5257
  _globals['_DEVICES']._serialized_start=5259
  _globals['_DEVICES']._serialized_end=5299
  _globals['_SIMULATEALARMREQUEST']._serialized_start=5302
  _globals['_SIMULATEALARMREQUEST']._serialized_end=5612
  _globals['_SIMULATEALARMREQUEST_OPERATIONTYPE']._serialized_start=5575
  _globals['_SIMULATEALARMREQUEST_OPERATIONTYPE']._serialized_end=5612
  _globals['_ONUSERIALNUMBERONOLTPON']._serialized_start=5614
  _globals['_ONUSERIALNUMBERONOLTPON']._serialized_end=5725
  _globals['_UPDATEDEVICE']._serialized_start=5727
  _globals['_UPDATEDEVICE']._serialized_end=5837
# @@protoc_insertion_point(module_scope)
