# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/voip_system_profile.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'voltha_protos/voip_system_profile.proto\x12\x13voip_system_profile\x1a\x1cgoogle/api/annotations.proto\"j\n\x18VoipSystemProfileRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x41\n\x11voipSystemProfile\x18\x02 \x01(\x0b\x32&.voip_system_profile.VoipSystemProfile\"{\n\x11VoipSystemProfile\x12\x31\n\tsipConfig\x18\x01 \x01(\x0b\x32\x1e.voip_system_profile.SipConfig\x12\x33\n\nvoipConfig\x18\x02 \x01(\x0b\x32\x1f.voip_system_profile.VoipConfig\"\xab\x03\n\nVoipConfig\x12\x37\n\x0cipHostConfig\x18\x01 \x01(\x0b\x32!.voip_system_profile.IpHostConfig\x12\x37\n\x0ctcpUdpConfig\x18\x02 \x01(\x0b\x32!.voip_system_profile.TcpUdpConfig\x12\x37\n\x0cvoipVoiceCtp\x18\x03 \x01(\x0b\x32!.voip_system_profile.VoipVoiceCtp\x12?\n\x10voipMediaProfile\x18\x04 \x01(\x0b\x32%.voip_system_profile.VoipMediaProfile\x12\x45\n\x13voiceServiceProfile\x18\x05 \x01(\x0b\x32(.voip_system_profile.VoiceServiceProfile\x12\x33\n\nrtpProfile\x18\x06 \x01(\x0b\x32\x1f.voip_system_profile.RtpProfile\x12\x35\n\x0bpptpPotsUni\x18\x07 \x01(\x0b\x32 .voip_system_profile.PptpPotsUni\"\xaf\x01\n\x0cIpHostConfig\x12\x11\n\tipOptions\x18\x01 \x01(\r\x12\x15\n\ronuIdentifier\x18\x02 \x01(\t\x12\x11\n\tipAddress\x18\x03 \x01(\t\x12\x0c\n\x04mask\x18\x04 \x01(\t\x12\x0f\n\x07gateway\x18\x05 \x01(\t\x12\x12\n\nprimaryDns\x18\x06 \x01(\t\x12\x14\n\x0csecondaryDns\x18\x07 \x01(\t\x12\x19\n\x11relayAgentOptions\x18\x08 \x01(\t\"2\n\x0cTcpUdpConfig\x12\x10\n\x08protocol\x18\x01 \x01(\r\x12\x10\n\x08tosField\x18\x02 \x01(\t\"&\n\x0cVoipVoiceCtp\x12\x16\n\x0esignallingCode\x18\x01 \x01(\r\"\x8c\x03\n\x10VoipMediaProfile\x12\x0f\n\x07\x66\x61xMode\x18\x01 \x01(\r\x12\x17\n\x0f\x63odecSelection1\x18\x02 \x01(\r\x12\x1e\n\x16packetPeriodSelection1\x18\x03 \x01(\r\x12\x1b\n\x13silenceSuppression1\x18\x04 \x01(\r\x12\x17\n\x0f\x63odecSelection2\x18\x05 \x01(\r\x12\x1e\n\x16packetPeriodSelection2\x18\x06 \x01(\r\x12\x1b\n\x13silenceSuppression2\x18\x07 \x01(\r\x12\x17\n\x0f\x63odecSelection3\x18\x08 \x01(\r\x12\x1e\n\x16packetPeriodSelection3\x18\t \x01(\r\x12\x1b\n\x13silenceSuppression3\x18\n \x01(\r\x12\x17\n\x0f\x63odecSelection4\x18\x0b \x01(\r\x12\x1e\n\x16packetPeriodSelection4\x18\x0c \x01(\r\x12\x1b\n\x13silenceSuppression4\x18\r \x01(\r\x12\x0f\n\x07oobDtmf\x18\x0e \x01(\r\"\xe4\x01\n\x13VoiceServiceProfile\x12\x18\n\x10\x61nnouncementType\x18\x01 \x01(\r\x12\x14\n\x0cjitterTarget\x18\x02 \x01(\r\x12\x17\n\x0fjitterBufferMax\x18\x03 \x01(\r\x12\x15\n\rechoCancelInd\x18\x04 \x01(\x08\x12\x1b\n\x13pstnProtocolVariant\x18\x05 \x01(\r\x12\x17\n\x0f\x64tmfDigitLevels\x18\x06 \x01(\r\x12\x19\n\x11\x64tmfDigitDuration\x18\x07 \x01(\r\x12\x1c\n\x14hookFlashMinimumTime\x18\x08 \x01(\r\"\x9e\x01\n\nRtpProfile\x12\x14\n\x0clocalPortMin\x18\x01 \x01(\r\x12\x14\n\x0clocalPortMax\x18\x02 \x01(\r\x12\x10\n\x08\x64scpMark\x18\x03 \x01(\t\x12\x17\n\x0fpiggyBackEvents\x18\x04 \x01(\r\x12\x12\n\ntoneEvents\x18\x05 \x01(\r\x12\x12\n\ndtmfEvents\x18\x06 \x01(\r\x12\x11\n\tcasEvents\x18\x07 \x01(\r\"\xcc\x01\n\x0bPptpPotsUni\x12\x0b\n\x03\x61rc\x18\x01 \x01(\t\x12\x13\n\x0b\x61rcInterval\x18\x02 \x01(\t\x12\x11\n\timpedance\x18\x03 \x01(\r\x12\x18\n\x10transmissionPath\x18\x04 \x01(\r\x12\x0e\n\x06rxGain\x18\x05 \x01(\x11\x12\x0e\n\x06txGain\x18\x06 \x01(\x11\x12\x18\n\x10potsHoldOverTime\x18\x07 \x01(\r\x12\x1a\n\x12nominalFeedVoltage\x18\x08 \x01(\r\x12\x18\n\x10lossOfSoftSwitch\x18\t \x01(\r\"\xe6\x02\n\tSipConfig\x12\x35\n\x0bsipUserData\x18\x01 \x01(\x0b\x32 .voip_system_profile.SipUserData\x12;\n\x0esipAgentConfig\x18\x02 \x01(\x0b\x32#.voip_system_profile.SipAgentConfig\x12=\n\x0fnetworkDialPlan\x18\x03 \x01(\x0b\x32$.voip_system_profile.NetworkDialPlan\x12K\n\x16voipFeatureAccessCodes\x18\x04 \x01(\x0b\x32+.voip_system_profile.VoipFeatureAccessCodes\x12Y\n\x1dvoipApplicationServiceProfile\x18\x05 \x01(\x0b\x32\x32.voip_system_profile.VoipApplicationServiceProfile\"\xdd\x01\n\x0bSipUserData\x12\x13\n\x0buserPartAor\x18\x01 \x01(\t\x12\x45\n\x13usernameAndPassword\x18\x02 \x01(\x0b\x32(.voip_system_profile.UsernameAndPassword\x12\x1d\n\x15voicemailServerSipUri\x18\x03 \x01(\t\x12+\n#voicemailSubscriptionExpirationTime\x18\x04 \x01(\x05\x12\x14\n\x0creleaseTimer\x18\x05 \x01(\x05\x12\x10\n\x08rohTimer\x18\x06 \x01(\x05\"\xd9\x02\n\x0eSipAgentConfig\x12\x1c\n\x14outboundProxyAddress\x18\x01 \x01(\t\x12\x15\n\rprimarySipDns\x18\x02 \x01(\t\x12\x17\n\x0fsecondarySipDns\x18\x03 \x01(\t\x12\x15\n\rsipRegExpTime\x18\x04 \x01(\x05\x12\x1d\n\x15sipReregHeadStartTime\x18\x05 \x01(\x05\x12\x14\n\x0cSipRegistrar\x18\x06 \x01(\t\x12\x12\n\nsoftSwitch\x18\x07 \x01(\t\x12?\n\x10sipResponseTable\x18\x08 \x01(\x0b\x32%.voip_system_profile.SipResponseTable\x12 \n\x18sipOptionTransmitControl\x18\t \x01(\x08\x12\x14\n\x0csipUriFormat\x18\n \x01(\t\x12 \n\x18redundantSipAgentPointer\x18\x0b \x01(\t\"\x9d\x01\n\x0fNetworkDialPlan\x12\x1b\n\x13\x63riticalDialTimeout\x18\x01 \x01(\r\x12\x1a\n\x12partialDialTimeout\x18\x02 \x01(\r\x12\x16\n\x0e\x64ialPlanFormat\x18\x03 \x01(\r\x12\x39\n\rdialPlanTable\x18\x04 \x01(\x0b\x32\".voip_system_profile.DialPlanTable\"/\n\x13UsernameAndPassword\x12\x18\n\x10validationScheme\x18\x01 \x01(\x05\"N\n\x10SipResponseTable\x12\x17\n\x0fsipResponseCode\x18\x01 \x01(\t\x12\x0c\n\x04tone\x18\x02 \x01(\t\x12\x13\n\x0btextMessage\x18\x03 \x01(\t\"h\n\rDialPlanTable\x12\x12\n\ndialPlanId\x18\x01 \x01(\r\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\r\x12\x15\n\rdialPlanToken\x18\x03 \x01(\t\x12\x1c\n\x14\x64ialPlanTableMaxSize\x18\x04 \x01(\r\"\xe5\x02\n\x16VoipFeatureAccessCodes\x12\x19\n\x11\x63\x61ncelCallWaiting\x18\x01 \x01(\t\x12\x10\n\x08\x63\x61llHold\x18\x02 \x01(\t\x12\x10\n\x08\x63\x61llPark\x18\x03 \x01(\t\x12\x18\n\x10\x63\x61llerIdActivate\x18\x04 \x01(\t\x12\x1a\n\x12\x63\x61llerIdDeactivate\x18\x05 \x01(\t\x12\x1e\n\x16\x64oNotDisturbActivation\x18\x06 \x01(\t\x12 \n\x18\x64oNotDisturbDeactivation\x18\x07 \x01(\t\x12\x1d\n\x15\x64oNotDisturbPinChange\x18\x08 \x01(\t\x12\x1e\n\x16\x65mergencyServiceNumber\x18\t \x01(\t\x12\x17\n\x0fintercomService\x18\n \x01(\t\x12\x1e\n\x16unattendedCallTransfer\x18\x0b \x01(\t\x12\x1c\n\x14\x61ttendedCallTransfer\x18\x0c \x01(\t\"\xbf\x02\n\x1dVoipApplicationServiceProfile\x12\x13\n\x0b\x63idFeatures\x18\x01 \x01(\r\x12\x1b\n\x13\x63\x61llWaitingFeatures\x18\x02 \x01(\r\x12&\n\x1e\x63\x61llProgressOrTransferFeatures\x18\x03 \x01(\r\x12 \n\x18\x63\x61llPresentationFeatures\x18\x04 \x01(\r\x12\x1c\n\x14\x64irectConnectFeature\x18\x05 \x01(\r\x12\x1f\n\x17\x64irectConnectUriPointer\x18\x06 \x01(\t\x12\"\n\x1a\x62ridgedLineAgentUriPointer\x18\x07 \x01(\t\x12#\n\x1b\x63onferenceFactoryUriPointer\x18\x08 \x01(\t\x12\x1a\n\x12\x64ialToneDelayTimer\x18\t \x01(\rBf\n\'org.opencord.voltha.voip_system_profileZ;github.com/opencord/voltha-protos/v5/go/voip_system_profileb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'voltha_protos.voip_system_profile_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'org.opencord.voltha.voip_system_profileZ;github.com/opencord/voltha-protos/v5/go/voip_system_profile'
  _globals['_VOIPSYSTEMPROFILEREQUEST']._serialized_start=94
  _globals['_VOIPSYSTEMPROFILEREQUEST']._serialized_end=200
  _globals['_VOIPSYSTEMPROFILE']._serialized_start=202
  _globals['_VOIPSYSTEMPROFILE']._serialized_end=325
  _globals['_VOIPCONFIG']._serialized_start=328
  _globals['_VOIPCONFIG']._serialized_end=755
  _globals['_IPHOSTCONFIG']._serialized_start=758
  _globals['_IPHOSTCONFIG']._serialized_end=933
  _globals['_TCPUDPCONFIG']._serialized_start=935
  _globals['_TCPUDPCONFIG']._serialized_end=985
  _globals['_VOIPVOICECTP']._serialized_start=987
  _globals['_VOIPVOICECTP']._serialized_end=1025
  _globals['_VOIPMEDIAPROFILE']._serialized_start=1028
  _globals['_VOIPMEDIAPROFILE']._serialized_end=1424
  _globals['_VOICESERVICEPROFILE']._serialized_start=1427
  _globals['_VOICESERVICEPROFILE']._serialized_end=1655
  _globals['_RTPPROFILE']._serialized_start=1658
  _globals['_RTPPROFILE']._serialized_end=1816
  _globals['_PPTPPOTSUNI']._serialized_start=1819
  _globals['_PPTPPOTSUNI']._serialized_end=2023
  _globals['_SIPCONFIG']._serialized_start=2026
  _globals['_SIPCONFIG']._serialized_end=2384
  _globals['_SIPUSERDATA']._serialized_start=2387
  _globals['_SIPUSERDATA']._serialized_end=2608
  _globals['_SIPAGENTCONFIG']._serialized_start=2611
  _globals['_SIPAGENTCONFIG']._serialized_end=2956
  _globals['_NETWORKDIALPLAN']._serialized_start=2959
  _globals['_NETWORKDIALPLAN']._serialized_end=3116
  _globals['_USERNAMEANDPASSWORD']._serialized_start=3118
  _globals['_USERNAMEANDPASSWORD']._serialized_end=3165
  _globals['_SIPRESPONSETABLE']._serialized_start=3167
  _globals['_SIPRESPONSETABLE']._serialized_end=3245
  _globals['_DIALPLANTABLE']._serialized_start=3247
  _globals['_DIALPLANTABLE']._serialized_end=3351
  _globals['_VOIPFEATUREACCESSCODES']._serialized_start=3354
  _globals['_VOIPFEATUREACCESSCODES']._serialized_end=3711
  _globals['_VOIPAPPLICATIONSERVICEPROFILE']._serialized_start=3714
  _globals['_VOIPAPPLICATIONSERVICEPROFILE']._serialized_end=4033
# @@protoc_insertion_point(module_scope)
