# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/openolt.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from voltha_protos import tech_profile_pb2 as voltha__protos_dot_tech__profile__pb2
from voltha_protos import ext_config_pb2 as voltha__protos_dot_ext__config__pb2
from voltha_protos import extensions_pb2 as voltha__protos_dot_extensions__pb2
from voltha_protos import common_pb2 as voltha__protos_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bvoltha_protos/openolt.proto\x12\x07openolt\x1a\x1cgoogle/api/annotations.proto\x1a voltha_protos/tech_profile.proto\x1a\x1evoltha_protos/ext_config.proto\x1a\x1evoltha_protos/extensions.proto\x1a\x1avoltha_protos/common.proto\"\xde\x04\n\nIndication\x12)\n\x07olt_ind\x18\x01 \x01(\x0b\x32\x16.openolt.OltIndicationH\x00\x12+\n\x08intf_ind\x18\x02 \x01(\x0b\x32\x17.openolt.IntfIndicationH\x00\x12\x34\n\rintf_oper_ind\x18\x03 \x01(\x0b\x32\x1b.openolt.IntfOperIndicationH\x00\x12\x32\n\x0conu_disc_ind\x18\x04 \x01(\x0b\x32\x1a.openolt.OnuDiscIndicationH\x00\x12)\n\x07onu_ind\x18\x05 \x01(\x0b\x32\x16.openolt.OnuIndicationH\x00\x12+\n\x08omci_ind\x18\x06 \x01(\x0b\x32\x17.openolt.OmciIndicationH\x00\x12,\n\x07pkt_ind\x18\x07 \x01(\x0b\x32\x19.openolt.PacketIndicationH\x00\x12,\n\nport_stats\x18\x08 \x01(\x0b\x32\x16.common.PortStatisticsH\x00\x12-\n\nflow_stats\x18\t \x01(\x0b\x32\x17.openolt.FlowStatisticsH\x00\x12-\n\talarm_ind\x18\n \x01(\x0b\x32\x18.openolt.AlarmIndicationH\x00\x12:\n\x10onu_disabled_ind\x18\x0b \x01(\x0b\x32\x1e.openolt.OnuDisabledIndicationH\x00\x12\x38\n\x0fonu_enabled_ind\x18\x0c \x01(\x0b\x32\x1d.openolt.OnuEnabledIndicationH\x00\x42\x06\n\x04\x64\x61ta\"\xf5\n\n\x0f\x41larmIndication\x12)\n\x07los_ind\x18\x01 \x01(\x0b\x32\x16.openolt.LosIndicationH\x00\x12\x36\n\x0e\x64ying_gasp_ind\x18\x02 \x01(\x0b\x32\x1c.openolt.DyingGaspIndicationH\x00\x12\x34\n\ronu_alarm_ind\x18\x03 \x01(\x0b\x32\x1b.openolt.OnuAlarmIndicationH\x00\x12\x44\n\x14onu_startup_fail_ind\x18\x04 \x01(\x0b\x32$.openolt.OnuStartupFailureIndicationH\x00\x12\x45\n\x16onu_signal_degrade_ind\x18\x05 \x01(\x0b\x32#.openolt.OnuSignalDegradeIndicationH\x00\x12\x46\n\x17onu_drift_of_window_ind\x18\x06 \x01(\x0b\x32#.openolt.OnuDriftOfWindowIndicationH\x00\x12\x44\n\x11onu_loss_omci_ind\x18\x07 \x01(\x0b\x32\'.openolt.OnuLossOfOmciChannelIndicationH\x00\x12\x44\n\x14onu_signals_fail_ind\x18\x08 \x01(\x0b\x32$.openolt.OnuSignalsFailureIndicationH\x00\x12\x43\n\x0conu_tiwi_ind\x18\t \x01(\x0b\x32+.openolt.OnuTransmissionInterferenceWarningH\x00\x12J\n\x17onu_activation_fail_ind\x18\n \x01(\x0b\x32\'.openolt.OnuActivationFailureIndicationH\x00\x12I\n\x18onu_processing_error_ind\x18\x0b \x01(\x0b\x32%.openolt.OnuProcessingErrorIndicationH\x00\x12O\n\x19onu_loss_of_sync_fail_ind\x18\x0c \x01(\x0b\x32*.openolt.OnuLossOfKeySyncFailureIndicationH\x00\x12\x42\n\x15onu_itu_pon_stats_ind\x18\r \x01(\x0b\x32!.openolt.OnuItuPonStatsIndicationH\x00\x12Q\n\x1conu_deactivation_failure_ind\x18\x0e \x01(\x0b\x32).openolt.OnuDeactivationFailureIndicationH\x00\x12\x43\n\x15onu_remote_defect_ind\x18\x0f \x01(\x0b\x32\".openolt.OnuRemoteDefectIndicationH\x00\x12Y\n\x1conu_loss_gem_delineation_ind\x18\x10 \x01(\x0b\x32\x31.openolt.OnuLossOfGEMChannelDelineationIndicationH\x00\x12X\n onu_physical_equipment_error_ind\x18\x11 \x01(\x0b\x32,.openolt.OnuPhysicalEquipmentErrorIndicationH\x00\x12J\n\x13onu_loss_of_ack_ind\x18\x12 \x01(\x0b\x32+.openolt.OnuLossOfAcknowledgementIndicationH\x00\x12V\n\x1bonu_diff_reach_exceeded_ind\x18\x13 \x01(\x0b\x32/.openolt.OnuDifferentialReachExceededIndicationH\x00\x42\x06\n\x04\x64\x61ta\"#\n\rOltIndication\x12\x12\n\noper_state\x18\x01 \x01(\t\"5\n\x0eIntfIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x12\n\noper_state\x18\x02 \x01(\t\"R\n\x11OnuDiscIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12,\n\rserial_number\x18\x02 \x01(\x0b\x32\x15.openolt.SerialNumber\"\xd3\x03\n\rOnuIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x12\n\noper_state\x18\x03 \x01(\t\x12\x13\n\x0b\x61\x64min_state\x18\x05 \x01(\t\x12,\n\rserial_number\x18\x04 \x01(\x0b\x32\x15.openolt.SerialNumber\x12@\n\x0b\x66\x61il_reason\x18\x06 \x01(\x0e\x32+.openolt.OnuIndication.ActivationFailReason\"\x87\x02\n\x14\x41\x63tivationFailReason\x12#\n\x1fONU_ACTIVATION_FAIL_REASON_NONE\x10\x00\x12&\n\"ONU_ACTIVATION_FAIL_REASON_RANGING\x10\x01\x12\x36\n2ONU_ACTIVATION_FAIL_REASON_PASSWORD_AUTHENTICATION\x10\x02\x12\"\n\x1eONU_ACTIVATION_FAIL_REASON_LOS\x10\x03\x12!\n\x1dONU_ACTIVATION_FAIL_ONU_ALARM\x10\x04\x12#\n\x1fONU_ACTIVATION_FAIL_SWITCH_OVER\x10\x05\"f\n\x15OnuDisabledIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12,\n\rserial_number\x18\x04 \x01(\x0b\x32\x15.openolt.SerialNumber\"e\n\x14OnuEnabledIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12,\n\rserial_number\x18\x04 \x01(\x0b\x32\x15.openolt.SerialNumber\"\xb5\x03\n\x12IntfOperIndication\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0f\n\x07intf_id\x18\x02 \x01(\x07\x12\x12\n\noper_state\x18\x03 \x01(\t\x12\r\n\x05speed\x18\x04 \x01(\x07\x12\x12\n\ntechnology\x18\x05 \x01(\t\x12=\n\x06ranges\x18\x06 \x01(\x0b\x32-.openolt.IntfOperIndication.PONResourceRanges\x1a\x89\x02\n\x11PONResourceRanges\x12\x41\n\x05pools\x18\x03 \x03(\x0b\x32\x32.openolt.IntfOperIndication.PONResourceRanges.Pool\x1a\xb0\x01\n\x04Pool\x12I\n\x04type\x18\x01 \x01(\x0e\x32;.openolt.IntfOperIndication.PONResourceRanges.Pool.PoolType\x12\r\n\x05start\x18\x03 \x01(\x07\x12\x0b\n\x03\x65nd\x18\x04 \x01(\x07\"A\n\x08PoolType\x12\n\n\x06ONU_ID\x10\x00\x12\x0c\n\x08\x41LLOC_ID\x10\x01\x12\x0e\n\nGEMPORT_ID\x10\x02\x12\x0b\n\x07\x46LOW_ID\x10\x03\">\n\x0eOmciIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0b\n\x03pkt\x18\x03 \x01(\x0c\"\xa9\x01\n\x10PacketIndication\x12\x11\n\tintf_type\x18\x05 \x01(\t\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x08 \x01(\x07\x12\x0e\n\x06uni_id\x18\t \x01(\x07\x12\x12\n\ngemport_id\x18\x02 \x01(\x07\x12\x0f\n\x07\x66low_id\x18\x03 \x01(\x07\x12\x0f\n\x07port_no\x18\x06 \x01(\x07\x12\x0e\n\x06\x63ookie\x18\x07 \x01(\x06\x12\x0b\n\x03pkt\x18\x04 \x01(\x0c\"/\n\tInterface\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x11\n\tintf_type\x18\x02 \x01(\x07\"(\n\tHeartbeat\x12\x1b\n\x13heartbeat_signature\x18\x01 \x01(\x07\"z\n\x03Onu\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12,\n\rserial_number\x18\x03 \x01(\x0b\x32\x15.openolt.SerialNumber\x12\x0b\n\x03pir\x18\x04 \x01(\x07\x12\x17\n\x0fomcc_encryption\x18\x05 \x01(\x08\"v\n\x12OnuLogicalDistance\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12!\n\x19logical_onu_distance_zero\x18\x03 \x01(\x07\x12\x1c\n\x14logical_onu_distance\x18\x04 \x01(\x07\"7\n\x07OmciMsg\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0b\n\x03pkt\x18\x03 \x01(\x0c\"p\n\tOnuPacket\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0f\n\x07port_no\x18\x04 \x01(\x07\x12\x12\n\ngemport_id\x18\x05 \x01(\x07\x12\x10\n\x08\x61lloc_id\x18\x06 \x01(\x07\x12\x0b\n\x03pkt\x18\x03 \x01(\x0c\",\n\x0cUplinkPacket\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0b\n\x03pkt\x18\x02 \x01(\x0c\"\x81\x06\n\nDeviceInfo\x12\x0e\n\x06vendor\x18\x01 \x01(\t\x12\r\n\x05model\x18\x02 \x01(\t\x12\x18\n\x10hardware_version\x18\x03 \x01(\t\x12\x18\n\x10\x66irmware_version\x18\x04 \x01(\t\x12\x11\n\tdevice_id\x18\x10 \x01(\t\x12\x1c\n\x14\x64\x65vice_serial_number\x18\x11 \x01(\t\x12\x1c\n\x14previously_connected\x18\x13 \x01(\x08\x12\x11\n\tpon_ports\x18\x0c \x01(\x07\x12\x11\n\tnni_ports\x18\x14 \x01(\x07\x12\x38\n\x06ranges\x18\x0f \x03(\x0b\x32(.openolt.DeviceInfo.DeviceResourceRanges\x1a\xde\x03\n\x14\x44\x65viceResourceRanges\x12\x10\n\x08intf_ids\x18\x01 \x03(\x07\x12\x12\n\ntechnology\x18\x02 \x01(\t\x12<\n\x05pools\x18\x03 \x03(\x0b\x32-.openolt.DeviceInfo.DeviceResourceRanges.Pool\x1a\xe1\x02\n\x04Pool\x12\x44\n\x04type\x18\x01 \x01(\x0e\x32\x36.openolt.DeviceInfo.DeviceResourceRanges.Pool.PoolType\x12J\n\x07sharing\x18\x02 \x01(\x0e\x32\x39.openolt.DeviceInfo.DeviceResourceRanges.Pool.SharingType\x12\r\n\x05start\x18\x03 \x01(\x07\x12\x0b\n\x03\x65nd\x18\x04 \x01(\x07\"A\n\x08PoolType\x12\n\n\x06ONU_ID\x10\x00\x12\x0c\n\x08\x41LLOC_ID\x10\x01\x12\x0e\n\nGEMPORT_ID\x10\x02\x12\x0b\n\x07\x46LOW_ID\x10\x03\"h\n\x0bSharingType\x12\x16\n\x12\x44\x45\x44ICATED_PER_INTF\x10\x00\x12\x1f\n\x1bSHARED_BY_ALL_INTF_ALL_TECH\x10\x01\x12 \n\x1cSHARED_BY_ALL_INTF_SAME_TECH\x10\x02J\x04\x08\x05\x10\x0cJ\x04\x08\r\x10\x0eJ\x04\x08\x0e\x10\x0f\"\x8c\x02\n\nClassifier\x12\x0e\n\x06o_tpid\x18\x01 \x01(\x07\x12\r\n\x05o_vid\x18\x02 \x01(\x07\x12\x0e\n\x06i_tpid\x18\x03 \x01(\x07\x12\r\n\x05i_vid\x18\x04 \x01(\x07\x12\x0f\n\x07o_pbits\x18\x05 \x01(\x07\x12\x0f\n\x07i_pbits\x18\x06 \x01(\x07\x12\x10\n\x08\x65th_type\x18\x07 \x01(\x07\x12\x0f\n\x07\x64st_mac\x18\x08 \x01(\x0c\x12\x0f\n\x07src_mac\x18\t \x01(\x0c\x12\x10\n\x08ip_proto\x18\n \x01(\x07\x12\x0e\n\x06\x64st_ip\x18\x0b \x01(\x07\x12\x0e\n\x06src_ip\x18\x0c \x01(\x07\x12\x10\n\x08src_port\x18\r \x01(\x07\x12\x10\n\x08\x64st_port\x18\x0e \x01(\x07\x12\x14\n\x0cpkt_tag_type\x18\x0f \x01(\t\"\xf5\x01\n\tActionCmd\x12\x15\n\radd_outer_tag\x18\x01 \x01(\x08\x12\x18\n\x10remove_outer_tag\x18\x02 \x01(\x08\x12\x14\n\x0ctrap_to_host\x18\x03 \x01(\x08\x12\x1a\n\x12remark_outer_pbits\x18\x04 \x01(\x08\x12\x1a\n\x12remark_inner_pbits\x18\x05 \x01(\x08\x12\x15\n\radd_inner_tag\x18\x06 \x01(\x08\x12\x18\n\x10remove_inner_tag\x18\x07 \x01(\x08\x12\x1b\n\x13translate_inner_tag\x18\x08 \x01(\x08\x12\x1b\n\x13translate_outer_tag\x18\t \x01(\x08\"\x89\x01\n\x06\x41\x63tion\x12\x1f\n\x03\x63md\x18\x01 \x01(\x0b\x32\x12.openolt.ActionCmd\x12\r\n\x05o_vid\x18\x02 \x01(\x07\x12\x0f\n\x07o_pbits\x18\x03 \x01(\x07\x12\x0e\n\x06o_tpid\x18\x04 \x01(\x07\x12\r\n\x05i_vid\x18\x05 \x01(\x07\x12\x0f\n\x07i_pbits\x18\x06 \x01(\x07\x12\x0e\n\x06i_tpid\x18\x07 \x01(\x07\"\xdb\x04\n\x04\x46low\x12\x16\n\x0e\x61\x63\x63\x65ss_intf_id\x18\x01 \x01(\x0f\x12\x0e\n\x06onu_id\x18\x02 \x01(\x0f\x12\x0e\n\x06uni_id\x18\x0b \x01(\x0f\x12\x0f\n\x07\x66low_id\x18\x03 \x01(\x06\x12\x19\n\x11symmetric_flow_id\x18\x12 \x01(\x06\x12\x11\n\tflow_type\x18\x04 \x01(\t\x12\x10\n\x08\x61lloc_id\x18\n \x01(\x0f\x12\x17\n\x0fnetwork_intf_id\x18\x05 \x01(\x0f\x12\x12\n\ngemport_id\x18\x06 \x01(\x0f\x12\'\n\nclassifier\x18\x07 \x01(\x0b\x32\x13.openolt.Classifier\x12\x1f\n\x06\x61\x63tion\x18\x08 \x01(\x0b\x32\x0f.openolt.Action\x12\x10\n\x08priority\x18\t \x01(\x0f\x12\x0e\n\x06\x63ookie\x18\x0c \x01(\x06\x12\x0f\n\x07port_no\x18\r \x01(\x07\x12\x10\n\x08group_id\x18\x0e \x01(\x07\x12\x17\n\x0ftech_profile_id\x18\x0f \x01(\x07\x12\x16\n\x0ereplicate_flow\x18\x10 \x01(\x08\x12\x39\n\x0fpbit_to_gemport\x18\x11 \x03(\x0b\x32 .openolt.Flow.PbitToGemportEntry\x12\x37\n\x0egemport_to_aes\x18\x13 \x03(\x0b\x32\x1f.openolt.Flow.GemportToAesEntry\x1a\x34\n\x12PbitToGemportEntry\x12\x0b\n\x03key\x18\x01 \x01(\x07\x12\r\n\x05value\x18\x02 \x01(\x07:\x02\x38\x01\x1a\x33\n\x11GemportToAesEntry\x12\x0b\n\x03key\x18\x01 \x01(\x07\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\":\n\x0cSerialNumber\x12\x11\n\tvendor_id\x18\x01 \x01(\x0c\x12\x17\n\x0fvendor_specific\x18\x02 \x01(\x0c\"\xf5\x04\n\rOnuStatistics\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x16\n\x0epositive_drift\x18\x03 \x01(\x06\x12\x16\n\x0enegative_drift\x18\x04 \x01(\x06\x12 \n\x18\x64\x65limiter_miss_detection\x18\x05 \x01(\x06\x12\x12\n\nbip_errors\x18\x06 \x01(\x06\x12\x11\n\tbip_units\x18\x07 \x01(\x06\x12\x1d\n\x15\x66\x65\x63_corrected_symbols\x18\x08 \x01(\x06\x12\x1f\n\x17\x66\x65\x63_codewords_corrected\x18\t \x01(\x06\x12#\n\x1b\x66\x65\x63_codewords_uncorrectable\x18\n \x01(\x06\x12\x15\n\rfec_codewords\x18\x0b \x01(\x06\x12\x1b\n\x13\x66\x65\x63_corrected_units\x18\x0c \x01(\x06\x12\x17\n\x0fxgem_key_errors\x18\r \x01(\x06\x12\x11\n\txgem_loss\x18\x0e \x01(\x06\x12\x17\n\x0frx_ploams_error\x18\x0f \x01(\x06\x12\x1a\n\x12rx_ploams_non_idle\x18\x10 \x01(\x06\x12\x0f\n\x07rx_omci\x18\x11 \x01(\x06\x12!\n\x19rx_omci_packets_crc_error\x18\x12 \x01(\x06\x12\x10\n\x08rx_bytes\x18\x13 \x01(\x06\x12\x12\n\nrx_packets\x18\x14 \x01(\x06\x12\x10\n\x08tx_bytes\x18\x15 \x01(\x06\x12\x12\n\ntx_packets\x18\x16 \x01(\x06\x12\x14\n\x0c\x62\x65r_reported\x18\x17 \x01(\x06\x12\x13\n\x0blcdg_errors\x18\x18 \x01(\x06\x12\x12\n\nrdi_errors\x18\x19 \x01(\x06\x12\x11\n\ttimestamp\x18\x1a \x01(\x07\"\x97\x01\n\x11GemPortStatistics\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x12\n\ngemport_id\x18\x02 \x01(\x07\x12\x12\n\nrx_packets\x18\x03 \x01(\x06\x12\x10\n\x08rx_bytes\x18\x04 \x01(\x06\x12\x12\n\ntx_packets\x18\x05 \x01(\x06\x12\x10\n\x08tx_bytes\x18\x06 \x01(\x06\x12\x11\n\ttimestamp\x18\x1a \x01(\x07\"\x80\x01\n\x0e\x46lowStatistics\x12\x0f\n\x07\x66low_id\x18\x01 \x01(\x07\x12\x10\n\x08rx_bytes\x18\x02 \x01(\x06\x12\x12\n\nrx_packets\x18\x03 \x01(\x06\x12\x10\n\x08tx_bytes\x18\x08 \x01(\x06\x12\x12\n\ntx_packets\x18\t \x01(\x06\x12\x11\n\ttimestamp\x18\x10 \x01(\x07\"0\n\rLosIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06status\x18\x02 \x01(\t\"F\n\x13\x44yingGaspIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\"\xc1\x01\n\x12OnuAlarmIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x12\n\nlos_status\x18\x03 \x01(\t\x12\x12\n\nlob_status\x18\x04 \x01(\t\x12\x18\n\x10lopc_miss_status\x18\x05 \x01(\t\x12\x1d\n\x15lopc_mic_error_status\x18\x06 \x01(\t\x12\x13\n\x0blofi_status\x18\x07 \x01(\t\x12\x14\n\x0cloami_status\x18\x08 \x01(\t\"N\n\x1bOnuStartupFailureIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\"m\n\x1aOnuSignalDegradeIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x1e\n\x16inverse_bit_error_rate\x18\x04 \x01(\x07\"m\n\x1aOnuDriftOfWindowIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\r\n\x05\x64rift\x18\x04 \x01(\x07\x12\x0f\n\x07new_eqd\x18\x05 \x01(\x07\"Q\n\x1eOnuLossOfOmciChannelIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\"n\n\x1bOnuSignalsFailureIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x1e\n\x16inverse_bit_error_rate\x18\x04 \x01(\x07\"d\n\"OnuTransmissionInterferenceWarning\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\r\n\x05\x64rift\x18\x04 \x01(\x07\"V\n\x1eOnuActivationFailureIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x13\n\x0b\x66\x61il_reason\x18\x03 \x01(\x07\"T\n!OnuLossOfKeySyncFailureIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\"=\n\x12RdiErrorIndication\x12\x17\n\x0frdi_error_count\x18\x01 \x01(\x06\x12\x0e\n\x06status\x18\x02 \x01(\t\"z\n\x18OnuItuPonStatsIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x34\n\rrdi_error_ind\x18\x03 \x01(\x0b\x32\x1b.openolt.RdiErrorIndicationH\x00\x42\x07\n\x05stats\"?\n\x1cOnuProcessingErrorIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\"S\n OnuDeactivationFailureIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\"P\n\x19OnuRemoteDefectIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x12\n\nrdi_errors\x18\x03 \x01(\x06\"w\n(OnuLossOfGEMChannelDelineationIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x1a\n\x12\x64\x65lineation_errors\x18\x04 \x01(\x07\"V\n#OnuPhysicalEquipmentErrorIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\"U\n\"OnuLossOfAcknowledgementIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\"k\n&OnuDifferentialReachExceededIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x10\n\x08\x64istance\x18\x04 \x01(\x07\"\xc5\x01\n\x0bGroupMember\x12\x14\n\x0cinterface_id\x18\x01 \x01(\r\x12:\n\x0einterface_type\x18\x02 \x01(\x0e\x32\".openolt.GroupMember.InterfaceType\x12\x13\n\x0bgem_port_id\x18\x03 \x01(\r\x12\x10\n\x08priority\x18\x04 \x01(\r\"=\n\rInterfaceType\x12\x07\n\x03PON\x10\x00\x12\x10\n\x0c\x45PON_1G_PATH\x10\x01\x12\x11\n\rEPON_10G_PATH\x10\x02\"\xe3\x01\n\x05Group\x12\x10\n\x08group_id\x18\x01 \x01(\r\x12\x33\n\x07\x63ommand\x18\x02 \x01(\x0e\x32\".openolt.Group.GroupMembersCommand\x12%\n\x07members\x18\x03 \x03(\x0b\x32\x14.openolt.GroupMember\x12\x1f\n\x06\x61\x63tion\x18\x04 \x01(\x0b\x32\x0f.openolt.Action\"K\n\x13GroupMembersCommand\x12\x0f\n\x0b\x41\x44\x44_MEMBERS\x10\x00\x12\x12\n\x0eREMOVE_MEMBERS\x10\x01\x12\x0f\n\x0bSET_MEMBERS\x10\x02\"Q\n\nValueParam\x12\x19\n\x03onu\x18\x01 \x01(\x0b\x32\x0c.openolt.Onu\x12(\n\x05value\x18\x02 \x01(\x0e\x32\x19.extension.ValueType.Type\"\x90\x02\n\x0ePonRxPowerData\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x46\n\x0b\x66\x61il_reason\x18\x04 \x01(\x0e\x32\x31.openolt.PonRxPowerData.RssiMeasurementFailReason\x12\x19\n\x11rx_power_mean_dbm\x18\x05 \x01(\x01\"j\n\x19RssiMeasurementFailReason\x12\x14\n\x10\x46\x41IL_REASON_NONE\x10\x00\x12\x1c\n\x18\x46\x41IL_REASON_NO_DELIMITER\x10\x01\x12\x19\n\x15\x46\x41IL_REASON_NO_ACCESS\x10\x02\"H\n\x14OnuAllocIdStatistics\x12\x0e\n\x06intfId\x18\x01 \x01(\x07\x12\x0f\n\x07\x61llocId\x18\x02 \x01(\x07\x12\x0f\n\x07rxBytes\x18\x03 \x01(\x06\"\x82\x02\n\x07OnuInfo\x12\x0e\n\x06onu_id\x18\x01 \x01(\x07\x12(\n\x05state\x18\x02 \x01(\x0e\x32\x19.openolt.OnuInfo.OnuState\x12!\n\x04losi\x18\x03 \x01(\x0e\x32\x13.openolt.AlarmState\x12!\n\x04lofi\x18\x04 \x01(\x0e\x32\x13.openolt.AlarmState\x12\"\n\x05loami\x18\x05 \x01(\x0e\x32\x13.openolt.AlarmState\"S\n\x08OnuState\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x12\n\x0eNOT_CONFIGURED\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08INACTIVE\x10\x03\x12\x0c\n\x08\x44ISABLED\x10\x04\"\xd3\x01\n\x0bPonIntfInfo\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x30\n\x05state\x18\x03 \x01(\x0e\x32!.openolt.PonIntfInfo.PonIntfState\x12 \n\x03los\x18\x04 \x01(\x0e\x32\x13.openolt.AlarmState\"_\n\x0cPonIntfState\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x12\n\x0e\x41\x43TIVE_WORKING\x10\x01\x12\x12\n\x0e\x41\x43TIVE_STANDBY\x10\x02\x12\x0c\n\x08INACTIVE\x10\x03\x12\x0c\n\x08\x44ISABLED\x10\x04\"n\n\x1dInterfaceOnuSerialNumberOnuId\x12=\n\x12intf_id_serial_num\x18\x01 \x01(\x0b\x32!.openolt.InterfaceOnuSerialNumber\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\"]\n\x18InterfaceOnuSerialNumber\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x30\n\x11onu_serial_number\x18\x02 \x01(\x0b\x32\x15.openolt.SerialNumber\"\x07\n\x05\x45mpty*\x1d\n\nAlarmState\x12\x07\n\x03OFF\x10\x00\x12\x06\n\x02ON\x10\x01\x32\xa6\x1b\n\x07Openolt\x12\x44\n\nDisableOlt\x12\x0e.openolt.Empty\x1a\x0e.openolt.Empty\"\x16\x82\xd3\xe4\x93\x02\x10\"\x0b/v1/Disable:\x01*\x12\x46\n\x0bReenableOlt\x12\x0e.openolt.Empty\x1a\x0e.openolt.Empty\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0c/v1/Reenable:\x01*\x12\x45\n\x0b\x41\x63tivateOnu\x12\x0c.openolt.Onu\x1a\x0e.openolt.Empty\"\x18\x82\xd3\xe4\x93\x02\x12\"\r/v1/EnableOnu:\x01*\x12H\n\rDeactivateOnu\x12\x0c.openolt.Onu\x1a\x0e.openolt.Empty\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/v1/DisableOnu:\x01*\x12\x43\n\tDeleteOnu\x12\x0c.openolt.Onu\x1a\x0e.openolt.Empty\"\x18\x82\xd3\xe4\x93\x02\x12\"\r/v1/DeleteOnu:\x01*\x12I\n\nOmciMsgOut\x12\x10.openolt.OmciMsg\x1a\x0e.openolt.Empty\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/v1/OmciMsgOut:\x01*\x12O\n\x0cOnuPacketOut\x12\x12.openolt.OnuPacket\x1a\x0e.openolt.Empty\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x10/v1/OnuPacketOut:\x01*\x12X\n\x0fUplinkPacketOut\x12\x15.openolt.UplinkPacket\x1a\x0e.openolt.Empty\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x13/v1/UplinkPacketOut:\x01*\x12@\n\x07\x46lowAdd\x12\r.openolt.Flow\x1a\x0e.openolt.Empty\"\x16\x82\xd3\xe4\x93\x02\x10\"\x0b/v1/FlowAdd:\x01*\x12\x46\n\nFlowRemove\x12\r.openolt.Flow\x1a\x0e.openolt.Empty\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/v1/FlowRemove:\x01*\x12S\n\x0eHeartbeatCheck\x12\x0e.openolt.Empty\x1a\x12.openolt.Heartbeat\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/v1/HeartbeatCheck:\x01*\x12M\n\x0b\x45nablePonIf\x12\x12.openolt.Interface\x1a\x0e.openolt.Empty\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/EnablePonIf:\x01*\x12O\n\x0c\x44isablePonIf\x12\x12.openolt.Interface\x1a\x0e.openolt.Empty\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x10/v1/DisablePonIf:\x01*\x12R\n\rGetDeviceInfo\x12\x0e.openolt.Empty\x1a\x13.openolt.DeviceInfo\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/v1/GetDeviceInfo:\x01*\x12?\n\x06Reboot\x12\x0e.openolt.Empty\x1a\x0e.openolt.Empty\"\x15\x82\xd3\xe4\x93\x02\x0f\"\n/v1/Reboot:\x01*\x12U\n\x11\x43ollectStatistics\x12\x0e.openolt.Empty\x1a\x0e.openolt.Empty\" \x82\xd3\xe4\x93\x02\x1a\"\x15/v1/CollectStatistics:\x01*\x12Y\n\x10GetOnuStatistics\x12\x0c.openolt.Onu\x1a\x16.openolt.OnuStatistics\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/v1/GetOnuStatistics:\x01*\x12k\n\x14GetGemPortStatistics\x12\x12.openolt.OnuPacket\x1a\x1a.openolt.GemPortStatistics\"#\x82\xd3\xe4\x93\x02\x1d\"\x18/v1/GetGemPortStatistics:\x01*\x12r\n\x17\x43reateTrafficSchedulers\x12\x1f.tech_profile.TrafficSchedulers\x1a\x0e.openolt.Empty\"&\x82\xd3\xe4\x93\x02 \"\x1b/v1/CreateTrafficSchedulers:\x01*\x12r\n\x17RemoveTrafficSchedulers\x12\x1f.tech_profile.TrafficSchedulers\x1a\x0e.openolt.Empty\"&\x82\xd3\xe4\x93\x02 \"\x1b/v1/RemoveTrafficSchedulers:\x01*\x12\x66\n\x13\x43reateTrafficQueues\x12\x1b.tech_profile.TrafficQueues\x1a\x0e.openolt.Empty\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/v1/CreateTrafficQueues:\x01*\x12\x66\n\x13RemoveTrafficQueues\x12\x1b.tech_profile.TrafficQueues\x1a\x0e.openolt.Empty\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/v1/RemoveTrafficQueues:\x01*\x12;\n\x10\x45nableIndication\x12\x0e.openolt.Empty\x1a\x13.openolt.Indication\"\x00\x30\x01\x12]\n\x15PerformGroupOperation\x12\x0e.openolt.Group\x1a\x0e.openolt.Empty\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/v1/PerformGroupOperation:\x01*\x12I\n\x0b\x44\x65leteGroup\x12\x0e.openolt.Group\x1a\x0e.openolt.Empty\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/DeleteGroup:\x01*\x12W\n\x0bGetExtValue\x12\x13.openolt.ValueParam\x1a\x17.extension.ReturnValues\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/GetExtValue:\x01*\x12]\n\x11OnuItuPonAlarmSet\x12\x16.config.OnuItuPonAlarm\x1a\x0e.openolt.Empty\" \x82\xd3\xe4\x93\x02\x1a\"\x15/v1/OnuItuPonAlarmSet:\x01*\x12p\n\x19GetLogicalOnuDistanceZero\x12\x0c.openolt.Onu\x1a\x1b.openolt.OnuLogicalDistance\"(\x82\xd3\xe4\x93\x02\"\"\x1d/v1/GetLogicalOnuDistanceZero:\x01*\x12h\n\x15GetLogicalOnuDistance\x12\x0c.openolt.Onu\x1a\x1b.openolt.OnuLogicalDistance\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/v1/GetLogicalOnuDistance:\x01*\x12T\n\rGetPonRxPower\x12\x0c.openolt.Onu\x1a\x17.openolt.PonRxPowerData\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/v1/GetPonRxPower:\x01*\x12G\n\nGetOnuInfo\x12\x0c.openolt.Onu\x1a\x10.openolt.OnuInfo\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/v1/GetOnuInfo:\x01*\x12`\n\x13GetPonInterfaceInfo\x12\x12.openolt.Interface\x1a\x14.openolt.PonIntfInfo\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/v1/GetInterfaceInfo:\x01*\x12n\n\x14GetAllocIdStatistics\x12\x12.openolt.OnuPacket\x1a\x1d.openolt.OnuAllocIdStatistics\"#\x82\xd3\xe4\x93\x02\x1d\"\x18/v1/GetAllocIdStatistics:\x01*\x12g\n\x14GetPonPortStatistics\x12\x12.openolt.Interface\x1a\x16.common.PortStatistics\"#\x82\xd3\xe4\x93\x02\x1d\"\x18/v1/GetPonPortStatistics:\x01*\x12g\n\x14GetNniPortStatistics\x12\x12.openolt.Interface\x1a\x16.common.PortStatistics\"#\x82\xd3\xe4\x93\x02\x1d\"\x18/v1/GetNniPortStatistics:\x01*\x12\\\n\nDisableOnu\x12&.openolt.InterfaceOnuSerialNumberOnuId\x1a\x0e.openolt.Empty\"\x16\x82\xd3\xe4\x93\x02\x10\"\x0e/v1/DisableOnu\x12Z\n\tEnableOnu\x12&.openolt.InterfaceOnuSerialNumberOnuId\x1a\x0e.openolt.Empty\"\x15\x82\xd3\xe4\x93\x02\x0f\"\r/v1/EnableOnu\x12o\n\x16\x44isableOnuSerialNumber\x12!.openolt.InterfaceOnuSerialNumber\x1a\x0e.openolt.Empty\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/v1/DisableOnuSerialNumber\x12m\n\x15\x45nableOnuSerialNumber\x12!.openolt.InterfaceOnuSerialNumber\x1a\x0e.openolt.Empty\"!\x82\xd3\xe4\x93\x02\x1b\"\x19/v1/EnableOnuSerialNumberB]\n\x1borg.opencord.voltha.openoltB\rVolthaOpenOLTZ/github.com/opencord/voltha-protos/v5/go/openoltb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'voltha_protos.openolt_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033org.opencord.voltha.openoltB\rVolthaOpenOLTZ/github.com/opencord/voltha-protos/v5/go/openolt'
  _globals['_FLOW_PBITTOGEMPORTENTRY']._options = None
  _globals['_FLOW_PBITTOGEMPORTENTRY']._serialized_options = b'8\001'
  _globals['_FLOW_GEMPORTTOAESENTRY']._options = None
  _globals['_FLOW_GEMPORTTOAESENTRY']._serialized_options = b'8\001'
  _globals['_OPENOLT'].methods_by_name['DisableOlt']._options = None
  _globals['_OPENOLT'].methods_by_name['DisableOlt']._serialized_options = b'\202\323\344\223\002\020\"\013/v1/Disable:\001*'
  _globals['_OPENOLT'].methods_by_name['ReenableOlt']._options = None
  _globals['_OPENOLT'].methods_by_name['ReenableOlt']._serialized_options = b'\202\323\344\223\002\021\"\014/v1/Reenable:\001*'
  _globals['_OPENOLT'].methods_by_name['ActivateOnu']._options = None
  _globals['_OPENOLT'].methods_by_name['ActivateOnu']._serialized_options = b'\202\323\344\223\002\022\"\r/v1/EnableOnu:\001*'
  _globals['_OPENOLT'].methods_by_name['DeactivateOnu']._options = None
  _globals['_OPENOLT'].methods_by_name['DeactivateOnu']._serialized_options = b'\202\323\344\223\002\023\"\016/v1/DisableOnu:\001*'
  _globals['_OPENOLT'].methods_by_name['DeleteOnu']._options = None
  _globals['_OPENOLT'].methods_by_name['DeleteOnu']._serialized_options = b'\202\323\344\223\002\022\"\r/v1/DeleteOnu:\001*'
  _globals['_OPENOLT'].methods_by_name['OmciMsgOut']._options = None
  _globals['_OPENOLT'].methods_by_name['OmciMsgOut']._serialized_options = b'\202\323\344\223\002\023\"\016/v1/OmciMsgOut:\001*'
  _globals['_OPENOLT'].methods_by_name['OnuPacketOut']._options = None
  _globals['_OPENOLT'].methods_by_name['OnuPacketOut']._serialized_options = b'\202\323\344\223\002\025\"\020/v1/OnuPacketOut:\001*'
  _globals['_OPENOLT'].methods_by_name['UplinkPacketOut']._options = None
  _globals['_OPENOLT'].methods_by_name['UplinkPacketOut']._serialized_options = b'\202\323\344\223\002\030\"\023/v1/UplinkPacketOut:\001*'
  _globals['_OPENOLT'].methods_by_name['FlowAdd']._options = None
  _globals['_OPENOLT'].methods_by_name['FlowAdd']._serialized_options = b'\202\323\344\223\002\020\"\013/v1/FlowAdd:\001*'
  _globals['_OPENOLT'].methods_by_name['FlowRemove']._options = None
  _globals['_OPENOLT'].methods_by_name['FlowRemove']._serialized_options = b'\202\323\344\223\002\023\"\016/v1/FlowRemove:\001*'
  _globals['_OPENOLT'].methods_by_name['HeartbeatCheck']._options = None
  _globals['_OPENOLT'].methods_by_name['HeartbeatCheck']._serialized_options = b'\202\323\344\223\002\027\"\022/v1/HeartbeatCheck:\001*'
  _globals['_OPENOLT'].methods_by_name['EnablePonIf']._options = None
  _globals['_OPENOLT'].methods_by_name['EnablePonIf']._serialized_options = b'\202\323\344\223\002\024\"\017/v1/EnablePonIf:\001*'
  _globals['_OPENOLT'].methods_by_name['DisablePonIf']._options = None
  _globals['_OPENOLT'].methods_by_name['DisablePonIf']._serialized_options = b'\202\323\344\223\002\025\"\020/v1/DisablePonIf:\001*'
  _globals['_OPENOLT'].methods_by_name['GetDeviceInfo']._options = None
  _globals['_OPENOLT'].methods_by_name['GetDeviceInfo']._serialized_options = b'\202\323\344\223\002\026\"\021/v1/GetDeviceInfo:\001*'
  _globals['_OPENOLT'].methods_by_name['Reboot']._options = None
  _globals['_OPENOLT'].methods_by_name['Reboot']._serialized_options = b'\202\323\344\223\002\017\"\n/v1/Reboot:\001*'
  _globals['_OPENOLT'].methods_by_name['CollectStatistics']._options = None
  _globals['_OPENOLT'].methods_by_name['CollectStatistics']._serialized_options = b'\202\323\344\223\002\032\"\025/v1/CollectStatistics:\001*'
  _globals['_OPENOLT'].methods_by_name['GetOnuStatistics']._options = None
  _globals['_OPENOLT'].methods_by_name['GetOnuStatistics']._serialized_options = b'\202\323\344\223\002\031\"\024/v1/GetOnuStatistics:\001*'
  _globals['_OPENOLT'].methods_by_name['GetGemPortStatistics']._options = None
  _globals['_OPENOLT'].methods_by_name['GetGemPortStatistics']._serialized_options = b'\202\323\344\223\002\035\"\030/v1/GetGemPortStatistics:\001*'
  _globals['_OPENOLT'].methods_by_name['CreateTrafficSchedulers']._options = None
  _globals['_OPENOLT'].methods_by_name['CreateTrafficSchedulers']._serialized_options = b'\202\323\344\223\002 \"\033/v1/CreateTrafficSchedulers:\001*'
  _globals['_OPENOLT'].methods_by_name['RemoveTrafficSchedulers']._options = None
  _globals['_OPENOLT'].methods_by_name['RemoveTrafficSchedulers']._serialized_options = b'\202\323\344\223\002 \"\033/v1/RemoveTrafficSchedulers:\001*'
  _globals['_OPENOLT'].methods_by_name['CreateTrafficQueues']._options = None
  _globals['_OPENOLT'].methods_by_name['CreateTrafficQueues']._serialized_options = b'\202\323\344\223\002\034\"\027/v1/CreateTrafficQueues:\001*'
  _globals['_OPENOLT'].methods_by_name['RemoveTrafficQueues']._options = None
  _globals['_OPENOLT'].methods_by_name['RemoveTrafficQueues']._serialized_options = b'\202\323\344\223\002\034\"\027/v1/RemoveTrafficQueues:\001*'
  _globals['_OPENOLT'].methods_by_name['PerformGroupOperation']._options = None
  _globals['_OPENOLT'].methods_by_name['PerformGroupOperation']._serialized_options = b'\202\323\344\223\002\036\"\031/v1/PerformGroupOperation:\001*'
  _globals['_OPENOLT'].methods_by_name['DeleteGroup']._options = None
  _globals['_OPENOLT'].methods_by_name['DeleteGroup']._serialized_options = b'\202\323\344\223\002\024\"\017/v1/DeleteGroup:\001*'
  _globals['_OPENOLT'].methods_by_name['GetExtValue']._options = None
  _globals['_OPENOLT'].methods_by_name['GetExtValue']._serialized_options = b'\202\323\344\223\002\024\"\017/v1/GetExtValue:\001*'
  _globals['_OPENOLT'].methods_by_name['OnuItuPonAlarmSet']._options = None
  _globals['_OPENOLT'].methods_by_name['OnuItuPonAlarmSet']._serialized_options = b'\202\323\344\223\002\032\"\025/v1/OnuItuPonAlarmSet:\001*'
  _globals['_OPENOLT'].methods_by_name['GetLogicalOnuDistanceZero']._options = None
  _globals['_OPENOLT'].methods_by_name['GetLogicalOnuDistanceZero']._serialized_options = b'\202\323\344\223\002\"\"\035/v1/GetLogicalOnuDistanceZero:\001*'
  _globals['_OPENOLT'].methods_by_name['GetLogicalOnuDistance']._options = None
  _globals['_OPENOLT'].methods_by_name['GetLogicalOnuDistance']._serialized_options = b'\202\323\344\223\002\036\"\031/v1/GetLogicalOnuDistance:\001*'
  _globals['_OPENOLT'].methods_by_name['GetPonRxPower']._options = None
  _globals['_OPENOLT'].methods_by_name['GetPonRxPower']._serialized_options = b'\202\323\344\223\002\026\"\021/v1/GetPonRxPower:\001*'
  _globals['_OPENOLT'].methods_by_name['GetOnuInfo']._options = None
  _globals['_OPENOLT'].methods_by_name['GetOnuInfo']._serialized_options = b'\202\323\344\223\002\023\"\016/v1/GetOnuInfo:\001*'
  _globals['_OPENOLT'].methods_by_name['GetPonInterfaceInfo']._options = None
  _globals['_OPENOLT'].methods_by_name['GetPonInterfaceInfo']._serialized_options = b'\202\323\344\223\002\031\"\024/v1/GetInterfaceInfo:\001*'
  _globals['_OPENOLT'].methods_by_name['GetAllocIdStatistics']._options = None
  _globals['_OPENOLT'].methods_by_name['GetAllocIdStatistics']._serialized_options = b'\202\323\344\223\002\035\"\030/v1/GetAllocIdStatistics:\001*'
  _globals['_OPENOLT'].methods_by_name['GetPonPortStatistics']._options = None
  _globals['_OPENOLT'].methods_by_name['GetPonPortStatistics']._serialized_options = b'\202\323\344\223\002\035\"\030/v1/GetPonPortStatistics:\001*'
  _globals['_OPENOLT'].methods_by_name['GetNniPortStatistics']._options = None
  _globals['_OPENOLT'].methods_by_name['GetNniPortStatistics']._serialized_options = b'\202\323\344\223\002\035\"\030/v1/GetNniPortStatistics:\001*'
  _globals['_OPENOLT'].methods_by_name['DisableOnu']._options = None
  _globals['_OPENOLT'].methods_by_name['DisableOnu']._serialized_options = b'\202\323\344\223\002\020\"\016/v1/DisableOnu'
  _globals['_OPENOLT'].methods_by_name['EnableOnu']._options = None
  _globals['_OPENOLT'].methods_by_name['EnableOnu']._serialized_options = b'\202\323\344\223\002\017\"\r/v1/EnableOnu'
  _globals['_OPENOLT'].methods_by_name['DisableOnuSerialNumber']._options = None
  _globals['_OPENOLT'].methods_by_name['DisableOnuSerialNumber']._serialized_options = b'\202\323\344\223\002\034\"\032/v1/DisableOnuSerialNumber'
  _globals['_OPENOLT'].methods_by_name['EnableOnuSerialNumber']._options = None
  _globals['_OPENOLT'].methods_by_name['EnableOnuSerialNumber']._serialized_options = b'\202\323\344\223\002\033\"\031/v1/EnableOnuSerialNumber'
  _globals['_ALARMSTATE']._serialized_start=10768
  _globals['_ALARMSTATE']._serialized_end=10797
  _globals['_INDICATION']._serialized_start=197
  _globals['_INDICATION']._serialized_end=803
  _globals['_ALARMINDICATION']._serialized_start=806
  _globals['_ALARMINDICATION']._serialized_end=2203
  _globals['_OLTINDICATION']._serialized_start=2205
  _globals['_OLTINDICATION']._serialized_end=2240
  _globals['_INTFINDICATION']._serialized_start=2242
  _globals['_INTFINDICATION']._serialized_end=2295
  _globals['_ONUDISCINDICATION']._serialized_start=2297
  _globals['_ONUDISCINDICATION']._serialized_end=2379
  _globals['_ONUINDICATION']._serialized_start=2382
  _globals['_ONUINDICATION']._serialized_end=2849
  _globals['_ONUINDICATION_ACTIVATIONFAILREASON']._serialized_start=2586
  _globals['_ONUINDICATION_ACTIVATIONFAILREASON']._serialized_end=2849
  _globals['_ONUDISABLEDINDICATION']._serialized_start=2851
  _globals['_ONUDISABLEDINDICATION']._serialized_end=2953
  _globals['_ONUENABLEDINDICATION']._serialized_start=2955
  _globals['_ONUENABLEDINDICATION']._serialized_end=3056
  _globals['_INTFOPERINDICATION']._serialized_start=3059
  _globals['_INTFOPERINDICATION']._serialized_end=3496
  _globals['_INTFOPERINDICATION_PONRESOURCERANGES']._serialized_start=3231
  _globals['_INTFOPERINDICATION_PONRESOURCERANGES']._serialized_end=3496
  _globals['_INTFOPERINDICATION_PONRESOURCERANGES_POOL']._serialized_start=3320
  _globals['_INTFOPERINDICATION_PONRESOURCERANGES_POOL']._serialized_end=3496
  _globals['_INTFOPERINDICATION_PONRESOURCERANGES_POOL_POOLTYPE']._serialized_start=3431
  _globals['_INTFOPERINDICATION_PONRESOURCERANGES_POOL_POOLTYPE']._serialized_end=3496
  _globals['_OMCIINDICATION']._serialized_start=3498
  _globals['_OMCIINDICATION']._serialized_end=3560
  _globals['_PACKETINDICATION']._serialized_start=3563
  _globals['_PACKETINDICATION']._serialized_end=3732
  _globals['_INTERFACE']._serialized_start=3734
  _globals['_INTERFACE']._serialized_end=3781
  _globals['_HEARTBEAT']._serialized_start=3783
  _globals['_HEARTBEAT']._serialized_end=3823
  _globals['_ONU']._serialized_start=3825
  _globals['_ONU']._serialized_end=3947
  _globals['_ONULOGICALDISTANCE']._serialized_start=3949
  _globals['_ONULOGICALDISTANCE']._serialized_end=4067
  _globals['_OMCIMSG']._serialized_start=4069
  _globals['_OMCIMSG']._serialized_end=4124
  _globals['_ONUPACKET']._serialized_start=4126
  _globals['_ONUPACKET']._serialized_end=4238
  _globals['_UPLINKPACKET']._serialized_start=4240
  _globals['_UPLINKPACKET']._serialized_end=4284
  _globals['_DEVICEINFO']._serialized_start=4287
  _globals['_DEVICEINFO']._serialized_end=5056
  _globals['_DEVICEINFO_DEVICERESOURCERANGES']._serialized_start=4560
  _globals['_DEVICEINFO_DEVICERESOURCERANGES']._serialized_end=5038
  _globals['_DEVICEINFO_DEVICERESOURCERANGES_POOL']._serialized_start=4685
  _globals['_DEVICEINFO_DEVICERESOURCERANGES_POOL']._serialized_end=5038
  _globals['_DEVICEINFO_DEVICERESOURCERANGES_POOL_POOLTYPE']._serialized_start=3431
  _globals['_DEVICEINFO_DEVICERESOURCERANGES_POOL_POOLTYPE']._serialized_end=3496
  _globals['_DEVICEINFO_DEVICERESOURCERANGES_POOL_SHARINGTYPE']._serialized_start=4934
  _globals['_DEVICEINFO_DEVICERESOURCERANGES_POOL_SHARINGTYPE']._serialized_end=5038
  _globals['_CLASSIFIER']._serialized_start=5059
  _globals['_CLASSIFIER']._serialized_end=5327
  _globals['_ACTIONCMD']._serialized_start=5330
  _globals['_ACTIONCMD']._serialized_end=5575
  _globals['_ACTION']._serialized_start=5578
  _globals['_ACTION']._serialized_end=5715
  _globals['_FLOW']._serialized_start=5718
  _globals['_FLOW']._serialized_end=6321
  _globals['_FLOW_PBITTOGEMPORTENTRY']._serialized_start=6216
  _globals['_FLOW_PBITTOGEMPORTENTRY']._serialized_end=6268
  _globals['_FLOW_GEMPORTTOAESENTRY']._serialized_start=6270
  _globals['_FLOW_GEMPORTTOAESENTRY']._serialized_end=6321
  _globals['_SERIALNUMBER']._serialized_start=6323
  _globals['_SERIALNUMBER']._serialized_end=6381
  _globals['_ONUSTATISTICS']._serialized_start=6384
  _globals['_ONUSTATISTICS']._serialized_end=7013
  _globals['_GEMPORTSTATISTICS']._serialized_start=7016
  _globals['_GEMPORTSTATISTICS']._serialized_end=7167
  _globals['_FLOWSTATISTICS']._serialized_start=7170
  _globals['_FLOWSTATISTICS']._serialized_end=7298
  _globals['_LOSINDICATION']._serialized_start=7300
  _globals['_LOSINDICATION']._serialized_end=7348
  _globals['_DYINGGASPINDICATION']._serialized_start=7350
  _globals['_DYINGGASPINDICATION']._serialized_end=7420
  _globals['_ONUALARMINDICATION']._serialized_start=7423
  _globals['_ONUALARMINDICATION']._serialized_end=7616
  _globals['_ONUSTARTUPFAILUREINDICATION']._serialized_start=7618
  _globals['_ONUSTARTUPFAILUREINDICATION']._serialized_end=7696
  _globals['_ONUSIGNALDEGRADEINDICATION']._serialized_start=7698
  _globals['_ONUSIGNALDEGRADEINDICATION']._serialized_end=7807
  _globals['_ONUDRIFTOFWINDOWINDICATION']._serialized_start=7809
  _globals['_ONUDRIFTOFWINDOWINDICATION']._serialized_end=7918
  _globals['_ONULOSSOFOMCICHANNELINDICATION']._serialized_start=7920
  _globals['_ONULOSSOFOMCICHANNELINDICATION']._serialized_end=8001
  _globals['_ONUSIGNALSFAILUREINDICATION']._serialized_start=8003
  _globals['_ONUSIGNALSFAILUREINDICATION']._serialized_end=8113
  _globals['_ONUTRANSMISSIONINTERFERENCEWARNING']._serialized_start=8115
  _globals['_ONUTRANSMISSIONINTERFERENCEWARNING']._serialized_end=8215
  _globals['_ONUACTIVATIONFAILUREINDICATION']._serialized_start=8217
  _globals['_ONUACTIVATIONFAILUREINDICATION']._serialized_end=8303
  _globals['_ONULOSSOFKEYSYNCFAILUREINDICATION']._serialized_start=8305
  _globals['_ONULOSSOFKEYSYNCFAILUREINDICATION']._serialized_end=8389
  _globals['_RDIERRORINDICATION']._serialized_start=8391
  _globals['_RDIERRORINDICATION']._serialized_end=8452
  _globals['_ONUITUPONSTATSINDICATION']._serialized_start=8454
  _globals['_ONUITUPONSTATSINDICATION']._serialized_end=8576
  _globals['_ONUPROCESSINGERRORINDICATION']._serialized_start=8578
  _globals['_ONUPROCESSINGERRORINDICATION']._serialized_end=8641
  _globals['_ONUDEACTIVATIONFAILUREINDICATION']._serialized_start=8643
  _globals['_ONUDEACTIVATIONFAILUREINDICATION']._serialized_end=8726
  _globals['_ONUREMOTEDEFECTINDICATION']._serialized_start=8728
  _globals['_ONUREMOTEDEFECTINDICATION']._serialized_end=8808
  _globals['_ONULOSSOFGEMCHANNELDELINEATIONINDICATION']._serialized_start=8810
  _globals['_ONULOSSOFGEMCHANNELDELINEATIONINDICATION']._serialized_end=8929
  _globals['_ONUPHYSICALEQUIPMENTERRORINDICATION']._serialized_start=8931
  _globals['_ONUPHYSICALEQUIPMENTERRORINDICATION']._serialized_end=9017
  _globals['_ONULOSSOFACKNOWLEDGEMENTINDICATION']._serialized_start=9019
  _globals['_ONULOSSOFACKNOWLEDGEMENTINDICATION']._serialized_end=9104
  _globals['_ONUDIFFERENTIALREACHEXCEEDEDINDICATION']._serialized_start=9106
  _globals['_ONUDIFFERENTIALREACHEXCEEDEDINDICATION']._serialized_end=9213
  _globals['_GROUPMEMBER']._serialized_start=9216
  _globals['_GROUPMEMBER']._serialized_end=9413
  _globals['_GROUPMEMBER_INTERFACETYPE']._serialized_start=9352
  _globals['_GROUPMEMBER_INTERFACETYPE']._serialized_end=9413
  _globals['_GROUP']._serialized_start=9416
  _globals['_GROUP']._serialized_end=9643
  _globals['_GROUP_GROUPMEMBERSCOMMAND']._serialized_start=9568
  _globals['_GROUP_GROUPMEMBERSCOMMAND']._serialized_end=9643
  _globals['_VALUEPARAM']._serialized_start=9645
  _globals['_VALUEPARAM']._serialized_end=9726
  _globals['_PONRXPOWERDATA']._serialized_start=9729
  _globals['_PONRXPOWERDATA']._serialized_end=10001
  _globals['_PONRXPOWERDATA_RSSIMEASUREMENTFAILREASON']._serialized_start=9895
  _globals['_PONRXPOWERDATA_RSSIMEASUREMENTFAILREASON']._serialized_end=10001
  _globals['_ONUALLOCIDSTATISTICS']._serialized_start=10003
  _globals['_ONUALLOCIDSTATISTICS']._serialized_end=10075
  _globals['_ONUINFO']._serialized_start=10078
  _globals['_ONUINFO']._serialized_end=10336
  _globals['_ONUINFO_ONUSTATE']._serialized_start=10253
  _globals['_ONUINFO_ONUSTATE']._serialized_end=10336
  _globals['_PONINTFINFO']._serialized_start=10339
  _globals['_PONINTFINFO']._serialized_end=10550
  _globals['_PONINTFINFO_PONINTFSTATE']._serialized_start=10455
  _globals['_PONINTFINFO_PONINTFSTATE']._serialized_end=10550
  _globals['_INTERFACEONUSERIALNUMBERONUID']._serialized_start=10552
  _globals['_INTERFACEONUSERIALNUMBERONUID']._serialized_end=10662
  _globals['_INTERFACEONUSERIALNUMBER']._serialized_start=10664
  _globals['_INTERFACEONUSERIALNUMBER']._serialized_end=10757
  _globals['_EMPTY']._serialized_start=10759
  _globals['_EMPTY']._serialized_end=10766
  _globals['_OPENOLT']._serialized_start=10800
  _globals['_OPENOLT']._serialized_end=14294
# @@protoc_insertion_point(module_scope)
