# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/core_services.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from voltha_protos import core_adapter_pb2 as voltha__protos_dot_core__adapter__pb2
from voltha_protos import common_pb2 as voltha__protos_dot_common__pb2
from voltha_protos import device_pb2 as voltha__protos_dot_device__pb2
from voltha_protos import health_pb2 as voltha__protos_dot_health__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!voltha_protos/core_services.proto\x12\x0c\x63ore_service\x1a\x1bgoogle/protobuf/empty.proto\x1a voltha_protos/core_adapter.proto\x1a\x1avoltha_protos/common.proto\x1a\x1avoltha_protos/device.proto\x1a\x1avoltha_protos/health.proto2\xfd\x0b\n\x0b\x43oreService\x12?\n\x0fGetHealthStatus\x12\x12.common.Connection\x1a\x14.health.HealthStatus(\x01\x30\x01\x12L\n\x0fRegisterAdapter\x12!.core_adapter.AdapterRegistration\x1a\x16.google.protobuf.Empty\x12\x36\n\x0c\x44\x65viceUpdate\x12\x0e.device.Device\x1a\x16.google.protobuf.Empty\x12\x33\n\x0bPortCreated\x12\x0c.device.Port\x1a\x16.google.protobuf.Empty\x12I\n\x10PortsStateUpdate\x12\x1d.core_adapter.PortStateFilter\x1a\x16.google.protobuf.Empty\x12\x34\n\x0e\x44\x65leteAllPorts\x12\n.common.ID\x1a\x16.google.protobuf.Empty\x12\x37\n\rGetDevicePort\x12\x18.core_adapter.PortFilter\x1a\x0c.device.Port\x12,\n\x0fListDevicePorts\x12\n.common.ID\x1a\r.device.Ports\x12L\n\x11\x44\x65viceStateUpdate\x12\x1f.core_adapter.DeviceStateFilter\x1a\x16.google.protobuf.Empty\x12\x41\n\x14\x44\x65vicePMConfigUpdate\x12\x11.device.PmConfigs\x1a\x16.google.protobuf.Empty\x12\x44\n\x13\x43hildDeviceDetected\x12\x1d.core_adapter.DeviceDiscovery\x1a\x0e.device.Device\x12\x36\n\x10\x43hildDevicesLost\x12\n.common.ID\x1a\x16.google.protobuf.Empty\x12:\n\x14\x43hildDevicesDetected\x12\n.common.ID\x1a\x16.google.protobuf.Empty\x12\'\n\tGetDevice\x12\n.common.ID\x1a\x0e.device.Device\x12\x41\n\x0eGetChildDevice\x12\x1f.core_adapter.ChildDeviceFilter\x1a\x0e.device.Device\x12.\n\x0fGetChildDevices\x12\n.common.ID\x1a\x0f.device.Devices\x12>\n\x0cSendPacketIn\x12\x16.core_adapter.PacketIn\x1a\x16.google.protobuf.Empty\x12H\n\x12\x44\x65viceReasonUpdate\x12\x1a.core_adapter.DeviceReason\x1a\x16.google.protobuf.Empty\x12\x42\n\x0fPortStateUpdate\x12\x17.core_adapter.PortState\x1a\x16.google.protobuf.Empty\x12;\n\x15ReconcileChildDevices\x12\n.common.ID\x1a\x16.google.protobuf.Empty\x12M\n\x1eGetChildDeviceWithProxyAddress\x12\x1b.device.Device.ProxyAddress\x1a\x0e.device.Device\x12\x33\n\x08GetPorts\x12\x18.core_adapter.PortFilter\x1a\r.device.Ports\x12N\n\x13\x43hildrenStateUpdate\x12\x1f.core_adapter.DeviceStateFilter\x1a\x16.google.protobuf.Empty\x12\x44\n\x13UpdateImageDownload\x12\x15.device.ImageDownload\x1a\x16.google.protobuf.EmptyBk\n org.opencord.voltha.core_serviceB\x11VolthaCoreServiceZ4github.com/opencord/voltha-protos/v5/go/core_serviceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'voltha_protos.core_services_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n org.opencord.voltha.core_serviceB\021VolthaCoreServiceZ4github.com/opencord/voltha-protos/v5/go/core_service'
  _globals['_CORESERVICE']._serialized_start=199
  _globals['_CORESERVICE']._serialized_end=1732
# @@protoc_insertion_point(module_scope)
