# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/core_adapter.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from voltha_protos import common_pb2 as voltha__protos_dot_common__pb2
from voltha_protos import voltha_pb2 as voltha__protos_dot_voltha__pb2
try:
  voltha__protos_dot_common__pb2 = voltha__protos_dot_voltha__pb2.voltha__protos_dot_common__pb2
except AttributeError:
  voltha__protos_dot_common__pb2 = voltha__protos_dot_voltha__pb2.voltha_protos.common_pb2
from voltha_protos import openflow_13_pb2 as voltha__protos_dot_openflow__13__pb2
from voltha_protos import adapter_pb2 as voltha__protos_dot_adapter__pb2
from voltha_protos import device_pb2 as voltha__protos_dot_device__pb2
from voltha_protos import extensions_pb2 as voltha__protos_dot_extensions__pb2
from voltha_protos import omci_test_pb2 as voltha__protos_dot_omci__test__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n voltha_protos/core_adapter.proto\x12\x0c\x63ore_adapter\x1a\x1avoltha_protos/common.proto\x1a\x1avoltha_protos/voltha.proto\x1a\x1fvoltha_protos/openflow_13.proto\x1a\x1bvoltha_protos/adapter.proto\x1a\x1avoltha_protos/device.proto\x1a\x1evoltha_protos/extensions.proto\x1a\x1dvoltha_protos/omci_test.proto\"]\n\x13\x41\x64\x61pterRegistration\x12!\n\x07\x61\x64\x61pter\x18\x01 \x01(\x0b\x32\x10.adapter.Adapter\x12#\n\x06\x64Types\x18\x02 \x01(\x0b\x32\x13.device.DeviceTypes\"u\n\x11\x43hildDeviceFilter\x12\x11\n\tparent_id\x18\x01 \x01(\t\x12\x15\n\rserial_number\x18\x02 \x01(\t\x12\x13\n\x06onu_id\x18\x03 \x01(\rH\x00\x88\x01\x01\x12\x16\n\x0eparent_port_no\x18\x04 \x01(\rB\t\n\x07_onu_id\"W\n\nPortFilter\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\r\x12(\n\tport_type\x18\x03 \x01(\x0e\x32\x15.device.Port.PortType\"\xa5\x01\n\x0f\x44\x65viceDiscovery\x12\x11\n\tparent_id\x18\x01 \x01(\t\x12\x16\n\x0eparent_port_no\x18\x02 \x01(\r\x12\x19\n\x11\x63hild_device_type\x18\x03 \x01(\t\x12\x12\n\nchannel_id\x18\x04 \x01(\r\x12\x11\n\tvendor_id\x18\x05 \x01(\t\x12\x15\n\rserial_number\x18\x06 \x01(\t\x12\x0e\n\x06onu_id\x18\x07 \x01(\r\"\xa1\x01\n\x11\x44\x65viceStateFilter\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x18\n\x10parent_device_id\x18\x02 \x01(\t\x12-\n\x0boper_status\x18\x03 \x01(\x0e\x32\x18.common.OperStatus.Types\x12\x30\n\x0b\x63onn_status\x18\x04 \x01(\x0e\x32\x1b.common.ConnectStatus.Types\"\x88\x01\n\tPortState\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12(\n\tport_type\x18\x02 \x01(\x0e\x32\x15.device.Port.PortType\x12\x0f\n\x07port_no\x18\x03 \x01(\r\x12-\n\x0boper_status\x18\x04 \x01(\x0e\x32\x18.common.OperStatus.Types\"m\n\x0fPortStateFilter\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x18\n\x10port_type_filter\x18\x02 \x01(\r\x12-\n\x0boper_status\x18\x04 \x01(\x0e\x32\x18.common.OperStatus.Types\";\n\x08PacketIn\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\r\x12\x0e\n\x06packet\x18\x03 \x01(\x0c\"c\n\tPacketOut\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x16\n\x0e\x65gress_port_no\x18\x02 \x01(\r\x12+\n\x06packet\x18\x03 \x01(\x0b\x32\x1b.openflow_13.ofp_packet_out\"1\n\x0c\x44\x65viceReason\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"\xa9\x01\n\tBulkFlows\x12\x1e\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x0e.device.Device\x12!\n\x05\x66lows\x18\x02 \x01(\x0b\x32\x12.openflow_13.Flows\x12\'\n\x06groups\x18\x03 \x01(\x0b\x32\x17.openflow_13.FlowGroups\x12\x30\n\rflow_metadata\x18\x04 \x01(\x0b\x32\x19.openflow_13.FlowMetadata\"\xbc\x01\n\x10IncrementalFlows\x12\x1e\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x0e.device.Device\x12\'\n\x05\x66lows\x18\x02 \x01(\x0b\x32\x18.openflow_13.FlowChanges\x12-\n\x06groups\x18\x03 \x01(\x0b\x32\x1d.openflow_13.FlowGroupChanges\x12\x30\n\rflow_metadata\x18\x04 \x01(\x0b\x32\x19.openflow_13.FlowMetadata\"I\n\rPmConfigsInfo\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12%\n\npm_configs\x18\x02 \x01(\x0b\x32\x11.device.PmConfigs\"r\n\x10SwitchCapability\x12#\n\x04\x64\x65sc\x18\x01 \x01(\x0b\x32\x15.openflow_13.ofp_desc\x12\x39\n\x0fswitch_features\x18\x02 \x01(\x0b\x32 .openflow_13.ofp_switch_features\"\\\n\x14ImageDownloadMessage\x12\x1e\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x0e.device.Device\x12$\n\x05image\x18\x02 \x01(\x0b\x32\x15.device.ImageDownload\"R\n\x08OMCITest\x12\x1e\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x0e.device.Device\x12&\n\x07request\x18\x02 \x01(\x0b\x32\x15.omci.OmciTestRequest\"e\n\x14SimulateAlarmMessage\x12\x1e\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x0e.device.Device\x12-\n\x07request\x18\x02 \x01(\x0b\x32\x1c.device.SimulateAlarmRequest\"\x90\x01\n\x12GetExtValueMessage\x12%\n\rparent_device\x18\x01 \x01(\x0b\x32\x0e.device.Device\x12$\n\x0c\x63hild_device\x18\x02 \x01(\x0b\x32\x0e.device.Device\x12-\n\nvalue_type\x18\x03 \x01(\x0e\x32\x19.extension.ValueType.Type\"X\n\x12SetExtValueMessage\x12\x1e\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x0e.device.Device\x12\"\n\x05value\x18\x03 \x01(\x0b\x32\x13.extension.ValueSetBX\n org.opencord.voltha.core_adapterZ4github.com/opencord/voltha-protos/v5/go/core_adapterb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'voltha_protos.core_adapter_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n org.opencord.voltha.core_adapterZ4github.com/opencord/voltha-protos/v5/go/core_adapter'
  _globals['_ADAPTERREGISTRATION']._serialized_start=259
  _globals['_ADAPTERREGISTRATION']._serialized_end=352
  _globals['_CHILDDEVICEFILTER']._serialized_start=354
  _globals['_CHILDDEVICEFILTER']._serialized_end=471
  _globals['_PORTFILTER']._serialized_start=473
  _globals['_PORTFILTER']._serialized_end=560
  _globals['_DEVICEDISCOVERY']._serialized_start=563
  _globals['_DEVICEDISCOVERY']._serialized_end=728
  _globals['_DEVICESTATEFILTER']._serialized_start=731
  _globals['_DEVICESTATEFILTER']._serialized_end=892
  _globals['_PORTSTATE']._serialized_start=895
  _globals['_PORTSTATE']._serialized_end=1031
  _globals['_PORTSTATEFILTER']._serialized_start=1033
  _globals['_PORTSTATEFILTER']._serialized_end=1142
  _globals['_PACKETIN']._serialized_start=1144
  _globals['_PACKETIN']._serialized_end=1203
  _globals['_PACKETOUT']._serialized_start=1205
  _globals['_PACKETOUT']._serialized_end=1304
  _globals['_DEVICEREASON']._serialized_start=1306
  _globals['_DEVICEREASON']._serialized_end=1355
  _globals['_BULKFLOWS']._serialized_start=1358
  _globals['_BULKFLOWS']._serialized_end=1527
  _globals['_INCREMENTALFLOWS']._serialized_start=1530
  _globals['_INCREMENTALFLOWS']._serialized_end=1718
  _globals['_PMCONFIGSINFO']._serialized_start=1720
  _globals['_PMCONFIGSINFO']._serialized_end=1793
  _globals['_SWITCHCAPABILITY']._serialized_start=1795
  _globals['_SWITCHCAPABILITY']._serialized_end=1909
  _globals['_IMAGEDOWNLOADMESSAGE']._serialized_start=1911
  _globals['_IMAGEDOWNLOADMESSAGE']._serialized_end=2003
  _globals['_OMCITEST']._serialized_start=2005
  _globals['_OMCITEST']._serialized_end=2087
  _globals['_SIMULATEALARMMESSAGE']._serialized_start=2089
  _globals['_SIMULATEALARMMESSAGE']._serialized_end=2190
  _globals['_GETEXTVALUEMESSAGE']._serialized_start=2193
  _globals['_GETEXTVALUEMESSAGE']._serialized_end=2337
  _globals['_SETEXTVALUEMESSAGE']._serialized_start=2339
  _globals['_SETEXTVALUEMESSAGE']._serialized_end=2427
# @@protoc_insertion_point(module_scope)
