# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/omci_alarm_db.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!voltha_protos/omci_alarm_db.proto\x12\x04omci\"1\n\x12\x41larmAttributeData\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"y\n\x11\x41larmInstanceData\x12\x13\n\x0binstance_id\x18\x01 \x01(\r\x12\x0f\n\x07\x63reated\x18\x02 \x01(\t\x12\x10\n\x08modified\x18\x03 \x01(\t\x12,\n\nattributes\x18\x04 \x03(\x0b\x32\x18.omci.AlarmAttributeData\"N\n\x0e\x41larmClassData\x12\x10\n\x08\x63lass_id\x18\x01 \x01(\r\x12*\n\tinstances\x18\x02 \x03(\x0b\x32\x17.omci.AlarmInstanceData\"4\n\x12\x41larmManagedEntity\x12\x10\n\x08\x63lass_id\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\"(\n\x10\x41larmMessageType\x12\x14\n\x0cmessage_type\x18\x01 \x01(\r\"\x85\x02\n\x0f\x41larmDeviceData\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x0f\n\x07\x63reated\x18\x02 \x01(\t\x12\x1b\n\x13last_alarm_sequence\x18\x03 \x01(\r\x12\x16\n\x0elast_sync_time\x18\x04 \x01(\t\x12\x0f\n\x07version\x18\x05 \x01(\r\x12%\n\x07\x63lasses\x18\x06 \x03(\x0b\x32\x14.omci.AlarmClassData\x12\x32\n\x10managed_entities\x18\x07 \x03(\x0b\x32\x18.omci.AlarmManagedEntity\x12-\n\rmessage_types\x18\x08 \x03(\x0b\x32\x16.omci.AlarmMessageType\"?\n\x16\x41larmOpenOmciEventType\"%\n\x11OpenOmciEventType\x12\x10\n\x0cstate_change\x10\x00\"`\n\x12\x41larmOpenOmciEvent\x12<\n\x04type\x18\x01 \x01(\x0e\x32..omci.AlarmOpenOmciEventType.OpenOmciEventType\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\tBH\n\x18org.opencord.voltha.omciZ,github.com/opencord/voltha-protos/v5/go/omcib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'voltha_protos.omci_alarm_db_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\030org.opencord.voltha.omciZ,github.com/opencord/voltha-protos/v5/go/omci'
  _globals['_ALARMATTRIBUTEDATA']._serialized_start=43
  _globals['_ALARMATTRIBUTEDATA']._serialized_end=92
  _globals['_ALARMINSTANCEDATA']._serialized_start=94
  _globals['_ALARMINSTANCEDATA']._serialized_end=215
  _globals['_ALARMCLASSDATA']._serialized_start=217
  _globals['_ALARMCLASSDATA']._serialized_end=295
  _globals['_ALARMMANAGEDENTITY']._serialized_start=297
  _globals['_ALARMMANAGEDENTITY']._serialized_end=349
  _globals['_ALARMMESSAGETYPE']._serialized_start=351
  _globals['_ALARMMESSAGETYPE']._serialized_end=391
  _globals['_ALARMDEVICEDATA']._serialized_start=394
  _globals['_ALARMDEVICEDATA']._serialized_end=655
  _globals['_ALARMOPENOMCIEVENTTYPE']._serialized_start=657
  _globals['_ALARMOPENOMCIEVENTTYPE']._serialized_end=720
  _globals['_ALARMOPENOMCIEVENTTYPE_OPENOMCIEVENTTYPE']._serialized_start=683
  _globals['_ALARMOPENOMCIEVENTTYPE_OPENOMCIEVENTTYPE']._serialized_end=720
  _globals['_ALARMOPENOMCIEVENT']._serialized_start=722
  _globals['_ALARMOPENOMCIEVENT']._serialized_end=818
# @@protoc_insertion_point(module_scope)
