# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/core.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18voltha_protos/core.proto\x12\x04\x63ore\"\x87\x02\n\x14\x44\x65viceTransientState\x12\x39\n\x0ftransient_state\x18\x01 \x01(\x0e\x32 .core.DeviceTransientState.Types\"\xb3\x01\n\x05Types\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03\x41NY\x10\x01\x12\x12\n\x0e\x46ORCE_DELETING\x10\x02\x12\x19\n\x15\x44\x45LETING_FROM_ADAPTER\x10\x03\x12\"\n\x1e\x44\x45LETING_POST_ADAPTER_RESPONSE\x10\x04\x12\x11\n\rDELETE_FAILED\x10\x05\x12\x19\n\x15RECONCILE_IN_PROGRESS\x10\x06\x12\x16\n\x12REBOOT_IN_PROGRESS\x10\x07\x42H\n\x18org.opencord.voltha.coreZ,github.com/opencord/voltha-protos/v5/go/coreb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'voltha_protos.core_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\030org.opencord.voltha.coreZ,github.com/opencord/voltha-protos/v5/go/core'
  _globals['_DEVICETRANSIENTSTATE']._serialized_start=35
  _globals['_DEVICETRANSIENTSTATE']._serialized_end=298
  _globals['_DEVICETRANSIENTSTATE_TYPES']._serialized_start=119
  _globals['_DEVICETRANSIENTSTATE_TYPES']._serialized_end=298
# @@protoc_insertion_point(module_scope)
