# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/adapter_service.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from voltha_protos import common_pb2 as voltha__protos_dot_common__pb2
from voltha_protos import core_adapter_pb2 as voltha__protos_dot_core__adapter__pb2
from voltha_protos import device_pb2 as voltha__protos_dot_device__pb2
from voltha_protos import extensions_pb2 as voltha__protos_dot_extensions__pb2
from voltha_protos import health_pb2 as voltha__protos_dot_health__pb2
from voltha_protos import voltha_pb2 as voltha__protos_dot_voltha__pb2
try:
  voltha__protos_dot_common__pb2 = voltha__protos_dot_voltha__pb2.voltha__protos_dot_common__pb2
except AttributeError:
  voltha__protos_dot_common__pb2 = voltha__protos_dot_voltha__pb2.voltha_protos.common_pb2
from voltha_protos import omci_test_pb2 as voltha__protos_dot_omci__test__pb2
from voltha_protos import events_pb2 as voltha__protos_dot_events__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#voltha_protos/adapter_service.proto\x12\x0f\x61\x64\x61pter_service\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1avoltha_protos/common.proto\x1a voltha_protos/core_adapter.proto\x1a\x1avoltha_protos/device.proto\x1a\x1evoltha_protos/extensions.proto\x1a\x1avoltha_protos/health.proto\x1a\x1avoltha_protos/voltha.proto\x1a\x1dvoltha_protos/omci_test.proto\x1a\x1avoltha_protos/events.proto2\xf2\x15\n\x0e\x41\x64\x61pterService\x12?\n\x0fGetHealthStatus\x12\x12.common.Connection\x1a\x14.health.HealthStatus(\x01\x30\x01\x12\x35\n\x0b\x41\x64optDevice\x12\x0e.device.Device\x1a\x16.google.protobuf.Empty\x12\x39\n\x0fReconcileDevice\x12\x0e.device.Device\x1a\x16.google.protobuf.Empty\x12\x36\n\x0c\x44\x65leteDevice\x12\x0e.device.Device\x1a\x16.google.protobuf.Empty\x12\x37\n\rDisableDevice\x12\x0e.device.Device\x1a\x16.google.protobuf.Empty\x12\x38\n\x0eReEnableDevice\x12\x0e.device.Device\x1a\x16.google.protobuf.Empty\x12\x36\n\x0cRebootDevice\x12\x0e.device.Device\x1a\x16.google.protobuf.Empty\x12\x38\n\x0eSelfTestDevice\x12\x0e.device.Device\x1a\x16.google.protobuf.Empty\x12\x42\n\x10GetOfpDeviceInfo\x12\x0e.device.Device\x1a\x1e.core_adapter.SwitchCapability\x12\x39\n\x0f\x43hildDeviceLost\x12\x0e.device.Device\x1a\x16.google.protobuf.Empty\x12\x32\n\nEnablePort\x12\x0c.device.Port\x1a\x16.google.protobuf.Empty\x12\x33\n\x0b\x44isablePort\x12\x0c.device.Port\x1a\x16.google.protobuf.Empty\x12\x42\n\x0fUpdateFlowsBulk\x12\x17.core_adapter.BulkFlows\x1a\x16.google.protobuf.Empty\x12R\n\x18UpdateFlowsIncrementally\x12\x1e.core_adapter.IncrementalFlows\x1a\x16.google.protobuf.Empty\x12@\n\rSendPacketOut\x12\x17.core_adapter.PacketOut\x1a\x16.google.protobuf.Empty\x12\x45\n\x0eUpdatePmConfig\x12\x1b.core_adapter.PmConfigsInfo\x1a\x16.google.protobuf.Empty\x12S\n\x10\x44ownloadOnuImage\x12\".device.DeviceImageDownloadRequest\x1a\x1b.device.DeviceImageResponse\x12L\n\x11GetOnuImageStatus\x12\x1a.device.DeviceImageRequest\x1a\x1b.device.DeviceImageResponse\x12O\n\x14\x41\x62ortOnuImageUpgrade\x12\x1a.device.DeviceImageRequest\x1a\x1b.device.DeviceImageResponse\x12-\n\x0cGetOnuImages\x12\n.common.ID\x1a\x11.device.OnuImages\x12K\n\x10\x41\x63tivateOnuImage\x12\x1a.device.DeviceImageRequest\x1a\x1b.device.DeviceImageResponse\x12I\n\x0e\x43ommitOnuImage\x12\x1a.device.DeviceImageRequest\x1a\x1b.device.DeviceImageResponse\x12O\n\rDownloadImage\x12\".core_adapter.ImageDownloadMessage\x1a\x15.device.ImageDownload\"\x03\x88\x02\x01\x12X\n\x16GetImageDownloadStatus\x12\".core_adapter.ImageDownloadMessage\x1a\x15.device.ImageDownload\"\x03\x88\x02\x01\x12U\n\x13\x43\x61ncelImageDownload\x12\".core_adapter.ImageDownloadMessage\x1a\x15.device.ImageDownload\"\x03\x88\x02\x01\x12U\n\x13\x41\x63tivateImageUpdate\x12\".core_adapter.ImageDownloadMessage\x1a\x15.device.ImageDownload\"\x03\x88\x02\x01\x12S\n\x11RevertImageUpdate\x12\".core_adapter.ImageDownloadMessage\x1a\x15.device.ImageDownload\"\x03\x88\x02\x01\x12;\n\rStartOmciTest\x12\x16.core_adapter.OMCITest\x1a\x12.omci.TestResponse\x12J\n\rSimulateAlarm\x12\".core_adapter.SimulateAlarmMessage\x1a\x15.common.OperationResp\x12;\n\rSuppressEvent\x12\x12.event.EventFilter\x1a\x16.google.protobuf.Empty\x12=\n\x0fUnSuppressEvent\x12\x12.event.EventFilter\x1a\x16.google.protobuf.Empty\x12H\n\x0bGetExtValue\x12 .core_adapter.GetExtValueMessage\x1a\x17.extension.ReturnValues\x12G\n\x0bSetExtValue\x12 .core_adapter.SetExtValueMessage\x1a\x16.google.protobuf.Empty\x12U\n\x0eGetSingleValue\x12 .extension.SingleGetValueRequest\x1a!.extension.SingleGetValueResponse\x12U\n\x0eSetSingleValue\x12 .extension.SingleSetValueRequest\x1a!.extension.SingleSetValueResponse\x12:\n\x10\x44isableOnuDevice\x12\x0e.device.Device\x1a\x16.google.protobuf.Empty\x12\x39\n\x0f\x45nableOnuDevice\x12\x0e.device.Device\x1a\x16.google.protobuf.Empty\x12Q\n\x16\x44isableOnuSerialNumber\x12\x1f.device.OnuSerialNumberOnOLTPon\x1a\x16.google.protobuf.Empty\x12P\n\x15\x45nableOnuSerialNumber\x12\x1f.device.OnuSerialNumberOnOLTPon\x1a\x16.google.protobuf.Empty\x12<\n\x0cUpdateDevice\x12\x14.device.UpdateDevice\x1a\x16.google.protobuf.EmptyBt\n#org.opencord.voltha.adapter_serviceB\x14VolthaAdapterServiceZ7github.com/opencord/voltha-protos/v5/go/adapter_serviceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'voltha_protos.adapter_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#org.opencord.voltha.adapter_serviceB\024VolthaAdapterServiceZ7github.com/opencord/voltha-protos/v5/go/adapter_service'
  _globals['_ADAPTERSERVICE'].methods_by_name['DownloadImage']._options = None
  _globals['_ADAPTERSERVICE'].methods_by_name['DownloadImage']._serialized_options = b'\210\002\001'
  _globals['_ADAPTERSERVICE'].methods_by_name['GetImageDownloadStatus']._options = None
  _globals['_ADAPTERSERVICE'].methods_by_name['GetImageDownloadStatus']._serialized_options = b'\210\002\001'
  _globals['_ADAPTERSERVICE'].methods_by_name['CancelImageDownload']._options = None
  _globals['_ADAPTERSERVICE'].methods_by_name['CancelImageDownload']._serialized_options = b'\210\002\001'
  _globals['_ADAPTERSERVICE'].methods_by_name['ActivateImageUpdate']._options = None
  _globals['_ADAPTERSERVICE'].methods_by_name['ActivateImageUpdate']._serialized_options = b'\210\002\001'
  _globals['_ADAPTERSERVICE'].methods_by_name['RevertImageUpdate']._options = None
  _globals['_ADAPTERSERVICE'].methods_by_name['RevertImageUpdate']._serialized_options = b'\210\002\001'
  _globals['_ADAPTERSERVICE']._serialized_start=323
  _globals['_ADAPTERSERVICE']._serialized_end=3125
# @@protoc_insertion_point(module_scope)
