# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/omci_test.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dvoltha_protos/omci_test.proto\x12\x04omci\"+\n\x0fOmciTestRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04uuid\x18\x02 \x01(\t\"u\n\x0cTestResponse\x12\x35\n\x06result\x18\x01 \x01(\x0e\x32%.omci.TestResponse.TestResponseResult\".\n\x12TestResponseResult\x12\x0b\n\x07SUCCESS\x10\x00\x12\x0b\n\x07\x46\x41ILURE\x10\x01\x42H\n\x18org.opencord.voltha.omciZ,github.com/opencord/voltha-protos/v5/go/omcib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'voltha_protos.omci_test_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\030org.opencord.voltha.omciZ,github.com/opencord/voltha-protos/v5/go/omci'
  _globals['_OMCITESTREQUEST']._serialized_start=39
  _globals['_OMCITESTREQUEST']._serialized_end=82
  _globals['_TESTRESPONSE']._serialized_start=84
  _globals['_TESTRESPONSE']._serialized_end=201
  _globals['_TESTRESPONSE_TESTRESPONSERESULT']._serialized_start=155
  _globals['_TESTRESPONSE_TESTRESPONSERESULT']._serialized_end=201
# @@protoc_insertion_point(module_scope)
