# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/voip_user_profile.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%voltha_protos/voip_user_profile.proto\x12\x11voip_user_profile\x1a\x1cgoogle/api/annotations.proto\"b\n\x16VoipUserProfileRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\x12;\n\x0fvoipUserProfile\x18\x02 \x01(\x0b\x32\".voip_user_profile.VoipUserProfile\"\xa7\x01\n\x0fVoipUserProfile\x12\x1c\n\x14voipSystemProfileKey\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\x12\x0e\n\x06\x64omain\x18\x04 \x01(\t\x12\r\n\x05proxy\x18\x05 \x01(\t\x12\x0c\n\x04port\x18\x06 \x01(\r\x12\x16\n\x0esipDisplayName\x18\x07 \x01(\t\x12\r\n\x05realm\x18\x08 \x01(\tBb\n%org.opencord.voltha.voip_user_profileZ9github.com/opencord/voltha-protos/v5/go/voip_user_profileb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'voltha_protos.voip_user_profile_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%org.opencord.voltha.voip_user_profileZ9github.com/opencord/voltha-protos/v5/go/voip_user_profile'
  _globals['_VOIPUSERPROFILEREQUEST']._serialized_start=90
  _globals['_VOIPUSERPROFILEREQUEST']._serialized_end=188
  _globals['_VOIPUSERPROFILE']._serialized_start=191
  _globals['_VOIPUSERPROFILE']._serialized_end=358
# @@protoc_insertion_point(module_scope)
