# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/ext_config.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1evoltha_protos/ext_config.proto\x12\x06\x63onfig\"S\n\x0b\x41larmConfig\x12:\n\x18onu_itu_pon_alarm_config\x18\x01 \x01(\x0b\x32\x16.config.OnuItuPonAlarmH\x00\x42\x08\n\x06\x63onfig\"\xb9\x07\n\x0eOnuItuPonAlarm\x12\x0e\n\x06pon_ni\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x30\n\x08\x61larm_id\x18\x03 \x01(\x0e\x32\x1e.config.OnuItuPonAlarm.AlarmID\x12Q\n\x19\x61larm_reporting_condition\x18\x04 \x01(\x0e\x32..config.OnuItuPonAlarm.AlarmReportingCondition\x12K\n\x15rate_threshold_config\x18\x05 \x01(\x0b\x32*.config.OnuItuPonAlarm.RateThresholdConfigH\x00\x12\x43\n\x11rate_range_config\x18\x06 \x01(\x0b\x32&.config.OnuItuPonAlarm.RateRangeConfigH\x00\x12M\n\x16value_threshold_config\x18\x07 \x01(\x0b\x32+.config.OnuItuPonAlarm.ValueThresholdConfigH\x00\x1a=\n\x08SoakTime\x12\x18\n\x10\x61\x63tive_soak_time\x18\x01 \x01(\x07\x12\x17\n\x0f\x63lear_soak_time\x18\x02 \x01(\x07\x1a\x88\x01\n\x13RateThresholdConfig\x12\x1d\n\x15rate_threshold_rising\x18\x01 \x01(\x06\x12\x1e\n\x16rate_threshold_falling\x18\x02 \x01(\x06\x12\x32\n\tsoak_time\x18\x03 \x01(\x0b\x32\x1f.config.OnuItuPonAlarm.SoakTime\x1ay\n\x0fRateRangeConfig\x12\x18\n\x10rate_range_lower\x18\x01 \x01(\x06\x12\x18\n\x10rate_range_upper\x18\x02 \x01(\x06\x12\x32\n\tsoak_time\x18\x03 \x01(\x0b\x32\x1f.config.OnuItuPonAlarm.SoakTime\x1a\x63\n\x14ValueThresholdConfig\x12\x17\n\x0fthreshold_limit\x18\x01 \x01(\x06\x12\x32\n\tsoak_time\x18\x02 \x01(\x0b\x32\x1f.config.OnuItuPonAlarm.SoakTime\"\x19\n\x07\x41larmID\x12\x0e\n\nRDI_ERRORS\x10\x00\"R\n\x17\x41larmReportingCondition\x12\x12\n\x0eRATE_THRESHOLD\x10\x00\x12\x0e\n\nRATE_RANGE\x10\x01\x12\x13\n\x0fVALUE_THRESHOLD\x10\x02\x42\x08\n\x06\x63onfigBI\n\x13org.opencord.volthaZ2github.com/opencord/voltha-protos/v5/go/ext/configb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'voltha_protos.ext_config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023org.opencord.volthaZ2github.com/opencord/voltha-protos/v5/go/ext/config'
  _globals['_ALARMCONFIG']._serialized_start=42
  _globals['_ALARMCONFIG']._serialized_end=125
  _globals['_ONUITUPONALARM']._serialized_start=128
  _globals['_ONUITUPONALARM']._serialized_end=1081
  _globals['_ONUITUPONALARM_SOAKTIME']._serialized_start=536
  _globals['_ONUITUPONALARM_SOAKTIME']._serialized_end=597
  _globals['_ONUITUPONALARM_RATETHRESHOLDCONFIG']._serialized_start=600
  _globals['_ONUITUPONALARM_RATETHRESHOLDCONFIG']._serialized_end=736
  _globals['_ONUITUPONALARM_RATERANGECONFIG']._serialized_start=738
  _globals['_ONUITUPONALARM_RATERANGECONFIG']._serialized_end=859
  _globals['_ONUITUPONALARM_VALUETHRESHOLDCONFIG']._serialized_start=861
  _globals['_ONUITUPONALARM_VALUETHRESHOLDCONFIG']._serialized_end=960
  _globals['_ONUITUPONALARM_ALARMID']._serialized_start=962
  _globals['_ONUITUPONALARM_ALARMID']._serialized_end=987
  _globals['_ONUITUPONALARM_ALARMREPORTINGCONDITION']._serialized_start=989
  _globals['_ONUITUPONALARM_ALARMREPORTINGCONDITION']._serialized_end=1071
# @@protoc_insertion_point(module_scope)
