# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/common.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1avoltha_protos/common.proto\x12\x06\x63ommon\"\x12\n\x03Key\x12\x0b\n\x03key\x18\x01 \x01(\t\"\x10\n\x02ID\x12\n\n\x02id\x18\x01 \x01(\t\" \n\x03IDs\x12\x19\n\x05items\x18\x01 \x03(\x0b\x32\n.common.ID\"P\n\nConnection\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\x13\n\x0b\x63ontextInfo\x18\x02 \x01(\t\x12\x1b\n\x13keep_alive_interval\x18\x03 \x01(\x03\"h\n\nAdminState\"Z\n\x05Types\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x12\n\x0ePREPROVISIONED\x10\x01\x12\x0b\n\x07\x45NABLED\x10\x02\x12\x0c\n\x08\x44ISABLED\x10\x03\x12\x15\n\x11\x44OWNLOADING_IMAGE\x10\x04\"\x9f\x01\n\nOperStatus\"\x90\x01\n\x05Types\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0e\n\nDISCOVERED\x10\x01\x12\x0e\n\nACTIVATING\x10\x02\x12\x0b\n\x07TESTING\x10\x03\x12\n\n\x06\x41\x43TIVE\x10\x04\x12\n\n\x06\x46\x41ILED\x10\x05\x12\x0f\n\x0bRECONCILING\x10\x06\x12\x16\n\x12RECONCILING_FAILED\x10\x07\x12\x0c\n\x08REBOOTED\x10\x08\"E\n\rConnectStatus\"4\n\x05Types\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0f\n\x0bUNREACHABLE\x10\x01\x12\r\n\tREACHABLE\x10\x02\"\xdc\x01\n\rOperationResp\x12\x37\n\x04\x63ode\x18\x01 \x01(\x0e\x32).common.OperationResp.OperationReturnCode\x12\x17\n\x0f\x61\x64\x64itional_info\x18\x02 \x01(\t\"y\n\x13OperationReturnCode\x12\x15\n\x11OPERATION_SUCCESS\x10\x00\x12\x15\n\x11OPERATION_FAILURE\x10\x01\x12\x19\n\x15OPERATION_UNSUPPORTED\x10\x02\x12\x19\n\x15OPERATION_IN_PROGRESS\x10\x03\"\x9e\x0e\n\x0ePortStatistics\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x10\n\x08rx_bytes\x18\x02 \x01(\x06\x12\x16\n\nrx_packets\x18\x03 \x01(\x06\x42\x02\x18\x01\x12\x1c\n\x10rx_ucast_packets\x18\x04 \x01(\x06\x42\x02\x18\x01\x12\x1c\n\x10rx_mcast_packets\x18\x05 \x01(\x06\x42\x02\x18\x01\x12\x1c\n\x10rx_bcast_packets\x18\x06 \x01(\x06\x42\x02\x18\x01\x12\x1c\n\x10rx_error_packets\x18\x07 \x01(\x06\x42\x02\x18\x01\x12\x11\n\trx_frames\x18\x11 \x01(\x06\x12\x14\n\x0crx_frames_64\x18\x12 \x01(\x06\x12\x18\n\x10rx_frames_65_127\x18\x13 \x01(\x06\x12\x19\n\x11rx_frames_128_255\x18\x14 \x01(\x06\x12\x19\n\x11rx_frames_256_511\x18\x15 \x01(\x06\x12\x1a\n\x12rx_frames_512_1023\x18\x16 \x01(\x06\x12\x1b\n\x13rx_frames_1024_1518\x18\x17 \x01(\x06\x12\x1b\n\x13rx_frames_1519_2047\x18\x18 \x01(\x06\x12\x1b\n\x13rx_frames_2048_4095\x18\x19 \x01(\x06\x12\x1b\n\x13rx_frames_4096_9216\x18\x1a \x01(\x06\x12\x1c\n\x14rx_frames_9217_16383\x18\x1b \x01(\x06\x12\x15\n\rrx_crc_errors\x18\x0e \x01(\x06\x12\x1a\n\x12rxUndersizePackets\x18\' \x01(\x06\x12\x19\n\x11rxOversizePackets\x18( \x01(\x06\x12\r\n\x05rxGem\x18+ \x01(\x06\x12\x14\n\x0crxGemDropped\x18, \x01(\x06\x12\x11\n\trxGemIdle\x18- \x01(\x06\x12\x16\n\x0erxGemCorrected\x18. \x01(\x06\x12\x14\n\x0crxGemIllegal\x18/ \x01(\x06\x12\x17\n\x0frxFragmentError\x18\x30 \x01(\x06\x12\x18\n\x10rxPacketsDropped\x18\x31 \x01(\x06\x12\x1f\n\x17rxCpuOmciPacketsDropped\x18\x32 \x01(\x06\x12\r\n\x05rxCpu\x18\x33 \x01(\x06\x12\x0e\n\x06rxOmci\x18\x34 \x01(\x06\x12\x1d\n\x15rxOmciPacketsCrcError\x18\x35 \x01(\x06\x12\x19\n\x11rxFcsErrorPackets\x18> \x01(\x06\x12\x10\n\x08tx_bytes\x18\x08 \x01(\x06\x12\x16\n\ntx_packets\x18\t \x01(\x06\x42\x02\x18\x01\x12\x1c\n\x10tx_ucast_packets\x18\n \x01(\x06\x42\x02\x18\x01\x12\x1c\n\x10tx_mcast_packets\x18\x0b \x01(\x06\x42\x02\x18\x01\x12\x1c\n\x10tx_bcast_packets\x18\x0c \x01(\x06\x42\x02\x18\x01\x12\x1c\n\x10tx_error_packets\x18\r \x01(\x06\x42\x02\x18\x01\x12\x11\n\ttx_frames\x18\x1c \x01(\x06\x12\x14\n\x0ctx_frames_64\x18\x1d \x01(\x06\x12\x18\n\x10tx_frames_65_127\x18\x1e \x01(\x06\x12\x19\n\x11tx_frames_128_255\x18\x1f \x01(\x06\x12\x19\n\x11tx_frames_256_511\x18  \x01(\x06\x12\x1a\n\x12tx_frames_512_1023\x18! \x01(\x06\x12\x1b\n\x13tx_frames_1024_1518\x18\" \x01(\x06\x12\x1b\n\x13tx_frames_1519_2047\x18# \x01(\x06\x12\x1b\n\x13tx_frames_2048_4095\x18$ \x01(\x06\x12\x1b\n\x13tx_frames_4096_9216\x18% \x01(\x06\x12\x1c\n\x14tx_frames_9217_16383\x18& \x01(\x06\x12\x1a\n\x12txUndersizePackets\x18) \x01(\x06\x12\x19\n\x11txOversizePackets\x18* \x01(\x06\x12\r\n\x05txGem\x18\x36 \x01(\x06\x12\r\n\x05txCpu\x18\x37 \x01(\x06\x12\x0e\n\x06txOmci\x18\x38 \x01(\x06\x12\x1e\n\x16txDroppedIllegalLength\x18\x39 \x01(\x06\x12\x19\n\x11txDroppedTpidMiss\x18: \x01(\x06\x12\x18\n\x10txDroppedVidMiss\x18; \x01(\x06\x12\x16\n\x0etxDroppedTotal\x18< \x01(\x06\x12\x12\n\nbip_errors\x18\x0f \x01(\x06\x12\x11\n\tbip_units\x18= \x01(\x06\x12\x11\n\ttimestamp\x18\x10 \x01(\x07\x12\x17\n\x0frx_ucast_frames\x18? \x01(\x06\x12\x17\n\x0frx_mcast_frames\x18@ \x01(\x06\x12\x17\n\x0frx_bcast_frames\x18\x41 \x01(\x06\x12\x17\n\x0frx_error_frames\x18\x42 \x01(\x06\x12\x17\n\x0frx_right_frames\x18\x43 \x01(\x06\x12\x17\n\x0ftx_ucast_frames\x18\x44 \x01(\x06\x12\x17\n\x0ftx_mcast_frames\x18\x45 \x01(\x06\x12\x17\n\x0ftx_bcast_frames\x18\x46 \x01(\x06\x12\x17\n\x0ftx_error_frames\x18G \x01(\x06\x12\x1b\n\x13rx_discarded_frames\x18H \x01(\x06*\x1c\n\x0cTestModeKeys\x12\x0c\n\x08\x61pi_test\x10\x00\x42\x45\n\x13org.opencord.volthaZ.github.com/opencord/voltha-protos/v5/go/commonb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'voltha_protos.common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023org.opencord.volthaZ.github.com/opencord/voltha-protos/v5/go/common'
  _globals['_PORTSTATISTICS'].fields_by_name['rx_packets']._options = None
  _globals['_PORTSTATISTICS'].fields_by_name['rx_packets']._serialized_options = b'\030\001'
  _globals['_PORTSTATISTICS'].fields_by_name['rx_ucast_packets']._options = None
  _globals['_PORTSTATISTICS'].fields_by_name['rx_ucast_packets']._serialized_options = b'\030\001'
  _globals['_PORTSTATISTICS'].fields_by_name['rx_mcast_packets']._options = None
  _globals['_PORTSTATISTICS'].fields_by_name['rx_mcast_packets']._serialized_options = b'\030\001'
  _globals['_PORTSTATISTICS'].fields_by_name['rx_bcast_packets']._options = None
  _globals['_PORTSTATISTICS'].fields_by_name['rx_bcast_packets']._serialized_options = b'\030\001'
  _globals['_PORTSTATISTICS'].fields_by_name['rx_error_packets']._options = None
  _globals['_PORTSTATISTICS'].fields_by_name['rx_error_packets']._serialized_options = b'\030\001'
  _globals['_PORTSTATISTICS'].fields_by_name['tx_packets']._options = None
  _globals['_PORTSTATISTICS'].fields_by_name['tx_packets']._serialized_options = b'\030\001'
  _globals['_PORTSTATISTICS'].fields_by_name['tx_ucast_packets']._options = None
  _globals['_PORTSTATISTICS'].fields_by_name['tx_ucast_packets']._serialized_options = b'\030\001'
  _globals['_PORTSTATISTICS'].fields_by_name['tx_mcast_packets']._options = None
  _globals['_PORTSTATISTICS'].fields_by_name['tx_mcast_packets']._serialized_options = b'\030\001'
  _globals['_PORTSTATISTICS'].fields_by_name['tx_bcast_packets']._options = None
  _globals['_PORTSTATISTICS'].fields_by_name['tx_bcast_packets']._serialized_options = b'\030\001'
  _globals['_PORTSTATISTICS'].fields_by_name['tx_error_packets']._options = None
  _globals['_PORTSTATISTICS'].fields_by_name['tx_error_packets']._serialized_options = b'\030\001'
  _globals['_TESTMODEKEYS']._serialized_start=2579
  _globals['_TESTMODEKEYS']._serialized_end=2607
  _globals['_KEY']._serialized_start=38
  _globals['_KEY']._serialized_end=56
  _globals['_ID']._serialized_start=58
  _globals['_ID']._serialized_end=74
  _globals['_IDS']._serialized_start=76
  _globals['_IDS']._serialized_end=108
  _globals['_CONNECTION']._serialized_start=110
  _globals['_CONNECTION']._serialized_end=190
  _globals['_ADMINSTATE']._serialized_start=192
  _globals['_ADMINSTATE']._serialized_end=296
  _globals['_ADMINSTATE_TYPES']._serialized_start=206
  _globals['_ADMINSTATE_TYPES']._serialized_end=296
  _globals['_OPERSTATUS']._serialized_start=299
  _globals['_OPERSTATUS']._serialized_end=458
  _globals['_OPERSTATUS_TYPES']._serialized_start=314
  _globals['_OPERSTATUS_TYPES']._serialized_end=458
  _globals['_CONNECTSTATUS']._serialized_start=460
  _globals['_CONNECTSTATUS']._serialized_end=529
  _globals['_CONNECTSTATUS_TYPES']._serialized_start=477
  _globals['_CONNECTSTATUS_TYPES']._serialized_end=529
  _globals['_OPERATIONRESP']._serialized_start=532
  _globals['_OPERATIONRESP']._serialized_end=752
  _globals['_OPERATIONRESP_OPERATIONRETURNCODE']._serialized_start=631
  _globals['_OPERATIONRESP_OPERATIONRETURNCODE']._serialized_end=752
  _globals['_PORTSTATISTICS']._serialized_start=755
  _globals['_PORTSTATISTICS']._serialized_end=2577
# @@protoc_insertion_point(module_scope)
