# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/voltha.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from voltha_protos import common_pb2 as voltha__protos_dot_common__pb2
from voltha_protos import health_pb2 as voltha__protos_dot_health__pb2
from voltha_protos import logical_device_pb2 as voltha__protos_dot_logical__device__pb2
from voltha_protos import device_pb2 as voltha__protos_dot_device__pb2
from voltha_protos import adapter_pb2 as voltha__protos_dot_adapter__pb2
from voltha_protos import openflow_13_pb2 as voltha__protos_dot_openflow__13__pb2
from voltha_protos import events_pb2 as voltha__protos_dot_events__pb2
from voltha_protos import extensions_pb2 as voltha__protos_dot_extensions__pb2
from voltha_protos import voip_system_profile_pb2 as voltha__protos_dot_voip__system__profile__pb2
from voltha_protos import voip_user_profile_pb2 as voltha__protos_dot_voip__user__profile__pb2
from voltha_protos import omci_mib_db_pb2 as voltha__protos_dot_omci__mib__db__pb2
from voltha_protos import omci_alarm_db_pb2 as voltha__protos_dot_omci__alarm__db__pb2
from voltha_protos import omci_test_pb2 as voltha__protos_dot_omci__test__pb2

from voltha_protos.common_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1avoltha_protos/voltha.proto\x12\x06voltha\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1avoltha_protos/common.proto\x1a\x1avoltha_protos/health.proto\x1a\"voltha_protos/logical_device.proto\x1a\x1avoltha_protos/device.proto\x1a\x1bvoltha_protos/adapter.proto\x1a\x1fvoltha_protos/openflow_13.proto\x1a\x1avoltha_protos/events.proto\x1a\x1evoltha_protos/extensions.proto\x1a\'voltha_protos/voip_system_profile.proto\x1a%voltha_protos/voip_user_profile.proto\x1a\x1fvoltha_protos/omci_mib_db.proto\x1a!voltha_protos/omci_alarm_db.proto\x1a\x1dvoltha_protos/omci_test.proto\"I\n\x0c\x43oreInstance\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\x12$\n\x06health\x18\x02 \x01(\x0b\x32\x14.health.HealthStatus\"4\n\rCoreInstances\x12#\n\x05items\x18\x01 \x03(\x0b\x32\x14.voltha.CoreInstance\"\xd5\x02\n\x06Voltha\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\"\n\x08\x61\x64\x61pters\x18\x02 \x03(\x0b\x32\x10.adapter.Adapter\x12\x36\n\x0flogical_devices\x18\x03 \x03(\x0b\x32\x1d.logical_device.LogicalDevice\x12\x1f\n\x07\x64\x65vices\x18\x04 \x03(\x0b\x32\x0e.device.Device\x12(\n\x0c\x64\x65vice_types\x18\x05 \x03(\x0b\x32\x12.device.DeviceType\x12)\n\revent_filters\x18\x07 \x03(\x0b\x32\x12.event.EventFilter\x12.\n\x11omci_mib_database\x18\x1c \x03(\x0b\x32\x13.omci.MibDeviceData\x12\x32\n\x13omci_alarm_database\x18\x1d \x03(\x0b\x32\x15.omci.AlarmDeviceDataJ\x04\x08\x06\x10\x07\x32\xbb;\n\rVolthaService\x12\x44\n\tGetVoltha\x12\x16.google.protobuf.Empty\x1a\x0e.voltha.Voltha\"\x0f\x82\xd3\xe4\x93\x02\t\x12\x07/api/v1\x12]\n\x11ListCoreInstances\x12\x16.google.protobuf.Empty\x1a\x15.voltha.CoreInstances\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/api/v1/instances\x12S\n\x0fGetCoreInstance\x12\n.common.ID\x1a\x14.voltha.CoreInstance\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/api/v1/instances/{id}\x12S\n\x0cListAdapters\x12\x16.google.protobuf.Empty\x1a\x11.adapter.Adapters\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/api/v1/adapters\x12m\n\x12ListLogicalDevices\x12\x16.google.protobuf.Empty\x1a\x1e.logical_device.LogicalDevices\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/api/v1/logical_devices\x12\x63\n\x10GetLogicalDevice\x12\n.common.ID\x1a\x1d.logical_device.LogicalDevice\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/api/v1/logical_devices/{id}\x12n\n\x16ListLogicalDevicePorts\x12\n.common.ID\x1a\x1c.logical_device.LogicalPorts\"*\x82\xd3\xe4\x93\x02$\x12\"/api/v1/logical_devices/{id}/ports\x12\x88\x01\n\x14GetLogicalDevicePort\x12\x1d.logical_device.LogicalPortId\x1a\x1b.logical_device.LogicalPort\"4\x82\xd3\xe4\x93\x02.\x12,/api/v1/logical_devices/{id}/ports/{port_id}\x12\x8d\x01\n\x17\x45nableLogicalDevicePort\x12\x1d.logical_device.LogicalPortId\x1a\x16.google.protobuf.Empty\";\x82\xd3\xe4\x93\x02\x35\"3/api/v1/logical_devices/{id}/ports/{port_id}/enable\x12\x8f\x01\n\x18\x44isableLogicalDevicePort\x12\x1d.logical_device.LogicalPortId\x1a\x16.google.protobuf.Empty\"<\x82\xd3\xe4\x93\x02\x36\"4/api/v1/logical_devices/{id}/ports/{port_id}/disable\x12\x64\n\x16ListLogicalDeviceFlows\x12\n.common.ID\x1a\x12.openflow_13.Flows\"*\x82\xd3\xe4\x93\x02$\x12\"/api/v1/logical_devices/{id}/flows\x12\x83\x01\n\x1cUpdateLogicalDeviceFlowTable\x12\x1c.openflow_13.FlowTableUpdate\x1a\x16.google.protobuf.Empty\"-\x82\xd3\xe4\x93\x02\'\"\"/api/v1/logical_devices/{id}/flows:\x01*\x12\x84\x01\n\x1dUpdateLogicalDeviceMeterTable\x12\x1b.openflow_13.MeterModUpdate\x1a\x16.google.protobuf.Empty\".\x82\xd3\xe4\x93\x02(\"#/api/v1/logical_devices/{id}/meters:\x01*\x12g\n\x17ListLogicalDeviceMeters\x12\n.common.ID\x1a\x13.openflow_13.Meters\"+\x82\xd3\xe4\x93\x02%\x12#/api/v1/logical_devices/{id}/meters\x12t\n\x1bListLogicalDeviceFlowGroups\x12\n.common.ID\x1a\x17.openflow_13.FlowGroups\"0\x82\xd3\xe4\x93\x02*\x12(/api/v1/logical_devices/{id}/flow_groups\x12\x93\x01\n!UpdateLogicalDeviceFlowGroupTable\x12!.openflow_13.FlowGroupTableUpdate\x1a\x16.google.protobuf.Empty\"3\x82\xd3\xe4\x93\x02-\"(/api/v1/logical_devices/{id}/flow_groups:\x01*\x12O\n\x0bListDevices\x12\x16.google.protobuf.Empty\x1a\x0f.device.Devices\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/api/v1/devices\x12O\n\rListDeviceIds\x12\x16.google.protobuf.Empty\x1a\x0b.common.IDs\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/api/v1/deviceids\x12U\n\x10ReconcileDevices\x12\x0b.common.IDs\x1a\x16.google.protobuf.Empty\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/api/v1/deviceids:\x01*\x12\x45\n\tGetDevice\x12\n.common.ID\x1a\x0e.device.Device\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/api/v1/devices/{id}\x12J\n\x0c\x43reateDevice\x12\x0e.device.Device\x1a\x0e.device.Device\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/api/v1/devices:\x01*\x12W\n\x0c\x45nableDevice\x12\n.common.ID\x1a\x16.google.protobuf.Empty\"#\x82\xd3\xe4\x93\x02\x1d\"\x1b/api/v1/devices/{id}/enable\x12Y\n\rDisableDevice\x12\n.common.ID\x1a\x16.google.protobuf.Empty\"$\x82\xd3\xe4\x93\x02\x1e\"\x1c/api/v1/devices/{id}/disable\x12W\n\x0cRebootDevice\x12\n.common.ID\x1a\x16.google.protobuf.Empty\"#\x82\xd3\xe4\x93\x02\x1d\"\x1b/api/v1/devices/{id}/reboot\x12W\n\x0c\x44\x65leteDevice\x12\n.common.ID\x1a\x16.google.protobuf.Empty\"#\x82\xd3\xe4\x93\x02\x1d*\x1b/api/v1/devices/{id}/delete\x12\x62\n\x11\x46orceDeleteDevice\x12\n.common.ID\x1a\x16.google.protobuf.Empty\")\x82\xd3\xe4\x93\x02#*!/api/v1/devices/{id}/force_delete\x12x\n\rDownloadImage\x12\x15.device.ImageDownload\x1a\x15.common.OperationResp\"9\x88\x02\x01\x82\xd3\xe4\x93\x02\x30\"+/api/v1/devices/{id}/image_downloads/{name}:\x01*\x12\x85\x01\n\x16GetImageDownloadStatus\x12\x15.device.ImageDownload\x1a\x15.device.ImageDownload\"=\x88\x02\x01\x82\xd3\xe4\x93\x02\x34\x12\x32/api/v1/devices/{id}/image_downloads/{name}/status\x12x\n\x10GetImageDownload\x12\x15.device.ImageDownload\x1a\x15.device.ImageDownload\"6\x88\x02\x01\x82\xd3\xe4\x93\x02-\x12+/api/v1/devices/{id}/image_downloads/{name}\x12i\n\x12ListImageDownloads\x12\n.common.ID\x1a\x16.device.ImageDownloads\"/\x88\x02\x01\x82\xd3\xe4\x93\x02&\x12$/api/v1/devices/{id}/image_downloads\x12{\n\x13\x43\x61ncelImageDownload\x12\x15.device.ImageDownload\x1a\x15.common.OperationResp\"6\x88\x02\x01\x82\xd3\xe4\x93\x02-*+/api/v1/devices/{id}/image_downloads/{name}\x12\x8b\x01\n\x13\x41\x63tivateImageUpdate\x12\x15.device.ImageDownload\x1a\x15.common.OperationResp\"F\x88\x02\x01\x82\xd3\xe4\x93\x02=\"8/api/v1/devices/{id}/image_downloads/{name}/image_update:\x01*\x12\x89\x01\n\x11RevertImageUpdate\x12\x15.device.ImageDownload\x1a\x15.common.OperationResp\"F\x88\x02\x01\x82\xd3\xe4\x93\x02=\"8/api/v1/devices/{id}/image_downloads/{name}/image_revert:\x01*\x12\x88\x01\n\x15\x44ownloadImageToDevice\x12\".device.DeviceImageDownloadRequest\x1a\x1b.device.DeviceImageResponse\".\x82\xd3\xe4\x93\x02(\x12&/api/v1/devices/images/download_images\x12w\n\x0eGetImageStatus\x12\x1a.device.DeviceImageRequest\x1a\x1b.device.DeviceImageResponse\",\x82\xd3\xe4\x93\x02&\x12$/api/v1/devices/images/images_status\x12\x89\x01\n\x19\x41\x62ortImageUpgradeToDevice\x12\x1a.device.DeviceImageRequest\x1a\x1b.device.DeviceImageResponse\"3\x82\xd3\xe4\x93\x02-\x12+/api/v1/devices/images/abort_upgrade_images\x12V\n\x0cGetOnuImages\x12\n.common.ID\x1a\x11.device.OnuImages\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/api/v1/devices/{id}/onu_images\x12{\n\rActivateImage\x12\x1a.device.DeviceImageRequest\x1a\x1b.device.DeviceImageResponse\"1\x82\xd3\xe4\x93\x02+\"&/api/v1/devices/images/activate_images:\x01*\x12w\n\x0b\x43ommitImage\x12\x1a.device.DeviceImageRequest\x1a\x1b.device.DeviceImageResponse\"/\x82\xd3\xe4\x93\x02)\"$/api/v1/devices/images/commit_images:\x01*\x12P\n\x0fListDevicePorts\x12\n.common.ID\x1a\r.device.Ports\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/api/v1/devices/{id}/ports\x12]\n\x13ListDevicePmConfigs\x12\n.common.ID\x1a\x11.device.PmConfigs\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/api/v1/devices/{id}/pm_configs\x12n\n\x15UpdateDevicePmConfigs\x12\x11.device.PmConfigs\x1a\x16.google.protobuf.Empty\"*\x82\xd3\xe4\x93\x02$\"\x1f/api/v1/devices/{id}/pm_configs:\x01*\x12U\n\x0fListDeviceFlows\x12\n.common.ID\x1a\x12.openflow_13.Flows\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/api/v1/devices/{id}/flows\x12\x65\n\x14ListDeviceFlowGroups\x12\n.common.ID\x1a\x17.openflow_13.FlowGroups\"(\x82\xd3\xe4\x93\x02\"\x12 /api/v1/devices/{id}/flow_groups\x12\\\n\x0fListDeviceTypes\x12\x16.google.protobuf.Empty\x1a\x13.device.DeviceTypes\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/api/v1/device_types\x12R\n\rGetDeviceType\x12\n.common.ID\x1a\x12.device.DeviceType\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/api/v1/device_types/{id}\x12\x46\n\x10StreamPacketsOut\x12\x16.openflow_13.PacketOut\x1a\x16.google.protobuf.Empty\"\x00(\x01\x12\x45\n\x10ReceivePacketsIn\x12\x16.google.protobuf.Empty\x1a\x15.openflow_13.PacketIn\"\x00\x30\x01\x12K\n\x13ReceiveChangeEvents\x12\x16.google.protobuf.Empty\x1a\x18.openflow_13.ChangeEvent\"\x00\x30\x01\x12]\n\x11\x43reateEventFilter\x12\x12.event.EventFilter\x1a\x12.event.EventFilter\" \x82\xd3\xe4\x93\x02\x1a\"\x15/api/v1/event_filters:\x01*\x12U\n\x0eGetEventFilter\x12\n.common.ID\x1a\x13.event.EventFilters\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/api/v1/event_filters/{id}\x12\x62\n\x11UpdateEventFilter\x12\x12.event.EventFilter\x1a\x12.event.EventFilter\"%\x82\xd3\xe4\x93\x02\x1f\x1a\x1a/api/v1/event_filters/{id}:\x01*\x12\x63\n\x11\x44\x65leteEventFilter\x12\x12.event.EventFilter\x1a\x16.google.protobuf.Empty\"\"\x82\xd3\xe4\x93\x02\x1c*\x1a/api/v1/event_filters/{id}\x12^\n\x10ListEventFilters\x12\x16.google.protobuf.Empty\x1a\x13.event.EventFilters\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/api/v1/event_filters\x12L\n\tGetImages\x12\n.common.ID\x1a\x0e.device.Images\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/api/v1/devices/{id}/images\x12X\n\x08SelfTest\x12\n.common.ID\x1a\x18.device.SelfTestResponse\"&\x82\xd3\xe4\x93\x02 \"\x1e/api/v1/devices/{id}/self_test\x12V\n\x10GetMibDeviceData\x12\n.common.ID\x1a\x13.omci.MibDeviceData\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/api/v1/openomci/{id}/mib\x12\\\n\x12GetAlarmDeviceData\x12\n.common.ID\x1a\x15.omci.AlarmDeviceData\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/api/v1/openomci/{id}/alarm\x12s\n\rSimulateAlarm\x12\x1c.device.SimulateAlarmRequest\x1a\x15.common.OperationResp\"-\x82\xd3\xe4\x93\x02\'\"\"/api/v1/devices/{id}/simulate_larm:\x01*\x12M\n\nEnablePort\x12\x0c.device.Port\x1a\x16.google.protobuf.Empty\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/v1/EnablePort:\x01*\x12O\n\x0b\x44isablePort\x12\x0c.device.Port\x1a\x16.google.protobuf.Empty\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/DisablePort:\x01*\x12^\n\x0bGetExtValue\x12\x19.extension.ValueSpecifier\x1a\x17.extension.ReturnValues\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/api/v1/GetExtValue\x12W\n\x0bSetExtValue\x12\x13.extension.ValueSet\x1a\x16.google.protobuf.Empty\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/api/v1/SetExtValue\x12\x64\n\x13StartOmciTestAction\x12\x15.omci.OmciTestRequest\x1a\x12.omci.TestResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/api/v1/start_omci_test:\x01*\x12\x85\x01\n\x14PutVoipSystemProfile\x12-.voip_system_profile.VoipSystemProfileRequest\x1a\x16.google.protobuf.Empty\"&\x82\xd3\xe4\x93\x02 \"\x1b/api/v1/voip_system_profile:\x01*\x12p\n\x17\x44\x65leteVoipSystemProfile\x12\x0b.common.Key\x1a\x16.google.protobuf.Empty\"0\x82\xd3\xe4\x93\x02**(/api/v1/voip_system_profile/{key}/delete\x12}\n\x12PutVoipUserProfile\x12).voip_user_profile.VoipUserProfileRequest\x1a\x16.google.protobuf.Empty\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/api/v1/voip_user_profile:\x01*\x12l\n\x15\x44\x65leteVoipUserProfile\x12\x0b.common.Key\x1a\x16.google.protobuf.Empty\".\x82\xd3\xe4\x93\x02(*&/api/v1/voip_user_profile/{key}/delete\x12Z\n\x10\x44isableOnuDevice\x12\n.common.ID\x1a\x16.google.protobuf.Empty\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/api/v1/disable_onu_device\x12X\n\x0f\x45nableOnuDevice\x12\n.common.ID\x1a\x16.google.protobuf.Empty\"!\x82\xd3\xe4\x93\x02\x1b\"\x19/api/v1/enable_onu_device\x12|\n\x16\x44isableOnuSerialNumber\x12\x1f.device.OnuSerialNumberOnOLTPon\x1a\x16.google.protobuf.Empty\")\x82\xd3\xe4\x93\x02#\"!/api/v1/disable_onu_serial_number\x12z\n\x15\x45nableOnuSerialNumber\x12\x1f.device.OnuSerialNumberOnOLTPon\x1a\x16.google.protobuf.Empty\"(\x82\xd3\xe4\x93\x02\"\" /api/v1/enable_onu_serial_number\x12[\n\x0cUpdateDevice\x12\x14.device.UpdateDevice\x1a\x16.google.protobuf.Empty\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x15/api/v1/update_deviceBl\n\x13org.opencord.volthaB\x0cVolthaProtosZ.github.com/opencord/voltha-protos/v5/go/voltha\xaa\x02\x16Opencord.Voltha.VolthaP\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'voltha_protos.voltha_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023org.opencord.volthaB\014VolthaProtosZ.github.com/opencord/voltha-protos/v5/go/voltha\252\002\026Opencord.Voltha.Voltha'
  _globals['_VOLTHASERVICE'].methods_by_name['GetVoltha']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['GetVoltha']._serialized_options = b'\202\323\344\223\002\t\022\007/api/v1'
  _globals['_VOLTHASERVICE'].methods_by_name['ListCoreInstances']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['ListCoreInstances']._serialized_options = b'\202\323\344\223\002\023\022\021/api/v1/instances'
  _globals['_VOLTHASERVICE'].methods_by_name['GetCoreInstance']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['GetCoreInstance']._serialized_options = b'\202\323\344\223\002\030\022\026/api/v1/instances/{id}'
  _globals['_VOLTHASERVICE'].methods_by_name['ListAdapters']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['ListAdapters']._serialized_options = b'\202\323\344\223\002\022\022\020/api/v1/adapters'
  _globals['_VOLTHASERVICE'].methods_by_name['ListLogicalDevices']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['ListLogicalDevices']._serialized_options = b'\202\323\344\223\002\031\022\027/api/v1/logical_devices'
  _globals['_VOLTHASERVICE'].methods_by_name['GetLogicalDevice']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['GetLogicalDevice']._serialized_options = b'\202\323\344\223\002\036\022\034/api/v1/logical_devices/{id}'
  _globals['_VOLTHASERVICE'].methods_by_name['ListLogicalDevicePorts']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['ListLogicalDevicePorts']._serialized_options = b'\202\323\344\223\002$\022\"/api/v1/logical_devices/{id}/ports'
  _globals['_VOLTHASERVICE'].methods_by_name['GetLogicalDevicePort']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['GetLogicalDevicePort']._serialized_options = b'\202\323\344\223\002.\022,/api/v1/logical_devices/{id}/ports/{port_id}'
  _globals['_VOLTHASERVICE'].methods_by_name['EnableLogicalDevicePort']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['EnableLogicalDevicePort']._serialized_options = b'\202\323\344\223\0025\"3/api/v1/logical_devices/{id}/ports/{port_id}/enable'
  _globals['_VOLTHASERVICE'].methods_by_name['DisableLogicalDevicePort']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['DisableLogicalDevicePort']._serialized_options = b'\202\323\344\223\0026\"4/api/v1/logical_devices/{id}/ports/{port_id}/disable'
  _globals['_VOLTHASERVICE'].methods_by_name['ListLogicalDeviceFlows']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['ListLogicalDeviceFlows']._serialized_options = b'\202\323\344\223\002$\022\"/api/v1/logical_devices/{id}/flows'
  _globals['_VOLTHASERVICE'].methods_by_name['UpdateLogicalDeviceFlowTable']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['UpdateLogicalDeviceFlowTable']._serialized_options = b'\202\323\344\223\002\'\"\"/api/v1/logical_devices/{id}/flows:\001*'
  _globals['_VOLTHASERVICE'].methods_by_name['UpdateLogicalDeviceMeterTable']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['UpdateLogicalDeviceMeterTable']._serialized_options = b'\202\323\344\223\002(\"#/api/v1/logical_devices/{id}/meters:\001*'
  _globals['_VOLTHASERVICE'].methods_by_name['ListLogicalDeviceMeters']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['ListLogicalDeviceMeters']._serialized_options = b'\202\323\344\223\002%\022#/api/v1/logical_devices/{id}/meters'
  _globals['_VOLTHASERVICE'].methods_by_name['ListLogicalDeviceFlowGroups']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['ListLogicalDeviceFlowGroups']._serialized_options = b'\202\323\344\223\002*\022(/api/v1/logical_devices/{id}/flow_groups'
  _globals['_VOLTHASERVICE'].methods_by_name['UpdateLogicalDeviceFlowGroupTable']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['UpdateLogicalDeviceFlowGroupTable']._serialized_options = b'\202\323\344\223\002-\"(/api/v1/logical_devices/{id}/flow_groups:\001*'
  _globals['_VOLTHASERVICE'].methods_by_name['ListDevices']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['ListDevices']._serialized_options = b'\202\323\344\223\002\021\022\017/api/v1/devices'
  _globals['_VOLTHASERVICE'].methods_by_name['ListDeviceIds']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['ListDeviceIds']._serialized_options = b'\202\323\344\223\002\023\022\021/api/v1/deviceids'
  _globals['_VOLTHASERVICE'].methods_by_name['ReconcileDevices']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['ReconcileDevices']._serialized_options = b'\202\323\344\223\002\026\"\021/api/v1/deviceids:\001*'
  _globals['_VOLTHASERVICE'].methods_by_name['GetDevice']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['GetDevice']._serialized_options = b'\202\323\344\223\002\026\022\024/api/v1/devices/{id}'
  _globals['_VOLTHASERVICE'].methods_by_name['CreateDevice']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['CreateDevice']._serialized_options = b'\202\323\344\223\002\024\"\017/api/v1/devices:\001*'
  _globals['_VOLTHASERVICE'].methods_by_name['EnableDevice']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['EnableDevice']._serialized_options = b'\202\323\344\223\002\035\"\033/api/v1/devices/{id}/enable'
  _globals['_VOLTHASERVICE'].methods_by_name['DisableDevice']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['DisableDevice']._serialized_options = b'\202\323\344\223\002\036\"\034/api/v1/devices/{id}/disable'
  _globals['_VOLTHASERVICE'].methods_by_name['RebootDevice']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['RebootDevice']._serialized_options = b'\202\323\344\223\002\035\"\033/api/v1/devices/{id}/reboot'
  _globals['_VOLTHASERVICE'].methods_by_name['DeleteDevice']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['DeleteDevice']._serialized_options = b'\202\323\344\223\002\035*\033/api/v1/devices/{id}/delete'
  _globals['_VOLTHASERVICE'].methods_by_name['ForceDeleteDevice']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['ForceDeleteDevice']._serialized_options = b'\202\323\344\223\002#*!/api/v1/devices/{id}/force_delete'
  _globals['_VOLTHASERVICE'].methods_by_name['DownloadImage']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['DownloadImage']._serialized_options = b'\210\002\001\202\323\344\223\0020\"+/api/v1/devices/{id}/image_downloads/{name}:\001*'
  _globals['_VOLTHASERVICE'].methods_by_name['GetImageDownloadStatus']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['GetImageDownloadStatus']._serialized_options = b'\210\002\001\202\323\344\223\0024\0222/api/v1/devices/{id}/image_downloads/{name}/status'
  _globals['_VOLTHASERVICE'].methods_by_name['GetImageDownload']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['GetImageDownload']._serialized_options = b'\210\002\001\202\323\344\223\002-\022+/api/v1/devices/{id}/image_downloads/{name}'
  _globals['_VOLTHASERVICE'].methods_by_name['ListImageDownloads']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['ListImageDownloads']._serialized_options = b'\210\002\001\202\323\344\223\002&\022$/api/v1/devices/{id}/image_downloads'
  _globals['_VOLTHASERVICE'].methods_by_name['CancelImageDownload']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['CancelImageDownload']._serialized_options = b'\210\002\001\202\323\344\223\002-*+/api/v1/devices/{id}/image_downloads/{name}'
  _globals['_VOLTHASERVICE'].methods_by_name['ActivateImageUpdate']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['ActivateImageUpdate']._serialized_options = b'\210\002\001\202\323\344\223\002=\"8/api/v1/devices/{id}/image_downloads/{name}/image_update:\001*'
  _globals['_VOLTHASERVICE'].methods_by_name['RevertImageUpdate']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['RevertImageUpdate']._serialized_options = b'\210\002\001\202\323\344\223\002=\"8/api/v1/devices/{id}/image_downloads/{name}/image_revert:\001*'
  _globals['_VOLTHASERVICE'].methods_by_name['DownloadImageToDevice']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['DownloadImageToDevice']._serialized_options = b'\202\323\344\223\002(\022&/api/v1/devices/images/download_images'
  _globals['_VOLTHASERVICE'].methods_by_name['GetImageStatus']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['GetImageStatus']._serialized_options = b'\202\323\344\223\002&\022$/api/v1/devices/images/images_status'
  _globals['_VOLTHASERVICE'].methods_by_name['AbortImageUpgradeToDevice']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['AbortImageUpgradeToDevice']._serialized_options = b'\202\323\344\223\002-\022+/api/v1/devices/images/abort_upgrade_images'
  _globals['_VOLTHASERVICE'].methods_by_name['GetOnuImages']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['GetOnuImages']._serialized_options = b'\202\323\344\223\002!\022\037/api/v1/devices/{id}/onu_images'
  _globals['_VOLTHASERVICE'].methods_by_name['ActivateImage']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['ActivateImage']._serialized_options = b'\202\323\344\223\002+\"&/api/v1/devices/images/activate_images:\001*'
  _globals['_VOLTHASERVICE'].methods_by_name['CommitImage']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['CommitImage']._serialized_options = b'\202\323\344\223\002)\"$/api/v1/devices/images/commit_images:\001*'
  _globals['_VOLTHASERVICE'].methods_by_name['ListDevicePorts']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['ListDevicePorts']._serialized_options = b'\202\323\344\223\002\034\022\032/api/v1/devices/{id}/ports'
  _globals['_VOLTHASERVICE'].methods_by_name['ListDevicePmConfigs']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['ListDevicePmConfigs']._serialized_options = b'\202\323\344\223\002!\022\037/api/v1/devices/{id}/pm_configs'
  _globals['_VOLTHASERVICE'].methods_by_name['UpdateDevicePmConfigs']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['UpdateDevicePmConfigs']._serialized_options = b'\202\323\344\223\002$\"\037/api/v1/devices/{id}/pm_configs:\001*'
  _globals['_VOLTHASERVICE'].methods_by_name['ListDeviceFlows']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['ListDeviceFlows']._serialized_options = b'\202\323\344\223\002\034\022\032/api/v1/devices/{id}/flows'
  _globals['_VOLTHASERVICE'].methods_by_name['ListDeviceFlowGroups']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['ListDeviceFlowGroups']._serialized_options = b'\202\323\344\223\002\"\022 /api/v1/devices/{id}/flow_groups'
  _globals['_VOLTHASERVICE'].methods_by_name['ListDeviceTypes']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['ListDeviceTypes']._serialized_options = b'\202\323\344\223\002\026\022\024/api/v1/device_types'
  _globals['_VOLTHASERVICE'].methods_by_name['GetDeviceType']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['GetDeviceType']._serialized_options = b'\202\323\344\223\002\033\022\031/api/v1/device_types/{id}'
  _globals['_VOLTHASERVICE'].methods_by_name['CreateEventFilter']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['CreateEventFilter']._serialized_options = b'\202\323\344\223\002\032\"\025/api/v1/event_filters:\001*'
  _globals['_VOLTHASERVICE'].methods_by_name['GetEventFilter']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['GetEventFilter']._serialized_options = b'\202\323\344\223\002\034\022\032/api/v1/event_filters/{id}'
  _globals['_VOLTHASERVICE'].methods_by_name['UpdateEventFilter']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['UpdateEventFilter']._serialized_options = b'\202\323\344\223\002\037\032\032/api/v1/event_filters/{id}:\001*'
  _globals['_VOLTHASERVICE'].methods_by_name['DeleteEventFilter']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['DeleteEventFilter']._serialized_options = b'\202\323\344\223\002\034*\032/api/v1/event_filters/{id}'
  _globals['_VOLTHASERVICE'].methods_by_name['ListEventFilters']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['ListEventFilters']._serialized_options = b'\202\323\344\223\002\027\022\025/api/v1/event_filters'
  _globals['_VOLTHASERVICE'].methods_by_name['GetImages']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['GetImages']._serialized_options = b'\202\323\344\223\002\035\022\033/api/v1/devices/{id}/images'
  _globals['_VOLTHASERVICE'].methods_by_name['SelfTest']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['SelfTest']._serialized_options = b'\202\323\344\223\002 \"\036/api/v1/devices/{id}/self_test'
  _globals['_VOLTHASERVICE'].methods_by_name['GetMibDeviceData']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['GetMibDeviceData']._serialized_options = b'\202\323\344\223\002\033\022\031/api/v1/openomci/{id}/mib'
  _globals['_VOLTHASERVICE'].methods_by_name['GetAlarmDeviceData']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['GetAlarmDeviceData']._serialized_options = b'\202\323\344\223\002\035\022\033/api/v1/openomci/{id}/alarm'
  _globals['_VOLTHASERVICE'].methods_by_name['SimulateAlarm']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['SimulateAlarm']._serialized_options = b'\202\323\344\223\002\'\"\"/api/v1/devices/{id}/simulate_larm:\001*'
  _globals['_VOLTHASERVICE'].methods_by_name['EnablePort']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['EnablePort']._serialized_options = b'\202\323\344\223\002\023\"\016/v1/EnablePort:\001*'
  _globals['_VOLTHASERVICE'].methods_by_name['DisablePort']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['DisablePort']._serialized_options = b'\202\323\344\223\002\024\"\017/v1/DisablePort:\001*'
  _globals['_VOLTHASERVICE'].methods_by_name['GetExtValue']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['GetExtValue']._serialized_options = b'\202\323\344\223\002\025\022\023/api/v1/GetExtValue'
  _globals['_VOLTHASERVICE'].methods_by_name['SetExtValue']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['SetExtValue']._serialized_options = b'\202\323\344\223\002\025\022\023/api/v1/SetExtValue'
  _globals['_VOLTHASERVICE'].methods_by_name['StartOmciTestAction']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['StartOmciTestAction']._serialized_options = b'\202\323\344\223\002\034\"\027/api/v1/start_omci_test:\001*'
  _globals['_VOLTHASERVICE'].methods_by_name['PutVoipSystemProfile']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['PutVoipSystemProfile']._serialized_options = b'\202\323\344\223\002 \"\033/api/v1/voip_system_profile:\001*'
  _globals['_VOLTHASERVICE'].methods_by_name['DeleteVoipSystemProfile']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['DeleteVoipSystemProfile']._serialized_options = b'\202\323\344\223\002**(/api/v1/voip_system_profile/{key}/delete'
  _globals['_VOLTHASERVICE'].methods_by_name['PutVoipUserProfile']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['PutVoipUserProfile']._serialized_options = b'\202\323\344\223\002\036\"\031/api/v1/voip_user_profile:\001*'
  _globals['_VOLTHASERVICE'].methods_by_name['DeleteVoipUserProfile']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['DeleteVoipUserProfile']._serialized_options = b'\202\323\344\223\002(*&/api/v1/voip_user_profile/{key}/delete'
  _globals['_VOLTHASERVICE'].methods_by_name['DisableOnuDevice']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['DisableOnuDevice']._serialized_options = b'\202\323\344\223\002\034\"\032/api/v1/disable_onu_device'
  _globals['_VOLTHASERVICE'].methods_by_name['EnableOnuDevice']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['EnableOnuDevice']._serialized_options = b'\202\323\344\223\002\033\"\031/api/v1/enable_onu_device'
  _globals['_VOLTHASERVICE'].methods_by_name['DisableOnuSerialNumber']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['DisableOnuSerialNumber']._serialized_options = b'\202\323\344\223\002#\"!/api/v1/disable_onu_serial_number'
  _globals['_VOLTHASERVICE'].methods_by_name['EnableOnuSerialNumber']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['EnableOnuSerialNumber']._serialized_options = b'\202\323\344\223\002\"\" /api/v1/enable_onu_serial_number'
  _globals['_VOLTHASERVICE'].methods_by_name['UpdateDevice']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['UpdateDevice']._serialized_options = b'\202\323\344\223\002\027\"\025/api/v1/update_device'
  _globals['_COREINSTANCE']._serialized_start=518
  _globals['_COREINSTANCE']._serialized_end=591
  _globals['_COREINSTANCES']._serialized_start=593
  _globals['_COREINSTANCES']._serialized_end=645
  _globals['_VOLTHA']._serialized_start=648
  _globals['_VOLTHA']._serialized_end=989
  _globals['_VOLTHASERVICE']._serialized_start=992
  _globals['_VOLTHASERVICE']._serialized_end=8603
# @@protoc_insertion_point(module_scope)
