# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/ietf_interfaces.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#voltha_protos/ietf_interfaces.proto\x12\x04ietf\"5\n\nInterfaces\x12\'\n\x0e\x61ll_interfaces\x18\x01 \x03(\x0b\x32\x0f.ietf.Interface\"\xda\x01\n\tInterface\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x04 \x01(\x08\x12J\n\x18link_up_down_trap_enable\x18\x05 \x01(\x0e\x32(.ietf.Interface.LinkUpDownTrapEnableType\"?\n\x18LinkUpDownTrapEnableType\x12\x11\n\rTRAP_DISABLED\x10\x00\x12\x10\n\x0cTRAP_ENABLED\x10\x01\">\n\x0fInterfacesState\x12+\n\rall_interfacs\x18\x01 \x03(\x0b\x32\x14.ietf.InterfaceState\"\xd5\x03\n\x0eInterfaceState\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12:\n\x0c\x61\x64min_status\x18\x03 \x01(\x0e\x32$.ietf.InterfaceState.AdminStatusType\x12\x38\n\x0boper_status\x18\x04 \x01(\x0e\x32#.ietf.InterfaceState.OperStatusType\x12\x13\n\x0blast_change\x18\x05 \x01(\t\x12\x10\n\x08if_index\x18\x06 \x01(\x05\x12\x14\n\x0cphys_address\x18\x07 \x01(\t\x12\x17\n\x0fhigher_layer_if\x18\x08 \x03(\t\x12\x16\n\x0elower_layer_if\x18\t \x03(\t\x12\r\n\x05speed\x18\n \x01(\x04\"B\n\x0f\x41\x64minStatusType\x12\x0e\n\nADMIN_DOWN\x10\x00\x12\x11\n\rADMIN_TESTING\x10\x01\x12\x0c\n\x08\x41\x44MIN_UP\x10\x02\"p\n\x0eOperStatusType\x12\x0b\n\x07\x44ORMANT\x10\x00\x12\x14\n\x10LOWER_LAYER_DOWN\x10\x01\x12\x0b\n\x07UNKNOWN\x10\x02\x12\x0b\n\x07TESTING\x10\x03\x12\x06\n\x02UP\x10\x04\x12\x08\n\x04\x44OWN\x10\x05\x12\x0f\n\x0bNOT_PRESENT\x10\x06\x42H\n\x18org.opencord.voltha.ietfZ,github.com/opencord/voltha-protos/v5/go/ietfb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'voltha_protos.ietf_interfaces_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\030org.opencord.voltha.ietfZ,github.com/opencord/voltha-protos/v5/go/ietf'
  _globals['_INTERFACES']._serialized_start=45
  _globals['_INTERFACES']._serialized_end=98
  _globals['_INTERFACE']._serialized_start=101
  _globals['_INTERFACE']._serialized_end=319
  _globals['_INTERFACE_LINKUPDOWNTRAPENABLETYPE']._serialized_start=256
  _globals['_INTERFACE_LINKUPDOWNTRAPENABLETYPE']._serialized_end=319
  _globals['_INTERFACESSTATE']._serialized_start=321
  _globals['_INTERFACESSTATE']._serialized_end=383
  _globals['_INTERFACESTATE']._serialized_start=386
  _globals['_INTERFACESTATE']._serialized_end=855
  _globals['_INTERFACESTATE_ADMINSTATUSTYPE']._serialized_start=675
  _globals['_INTERFACESTATE_ADMINSTATUSTYPE']._serialized_end=741
  _globals['_INTERFACESTATE_OPERSTATUSTYPE']._serialized_start=743
  _globals['_INTERFACESTATE_OPERSTATUSTYPE']._serialized_end=855
# @@protoc_insertion_point(module_scope)
