# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/adapter.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bvoltha_protos/adapter.proto\x12\x07\x61\x64\x61pter\x1a\x19google/protobuf/any.proto\"@\n\rAdapterConfig\x12/\n\x11\x61\x64\x64itional_config\x18@ \x01(\x0b\x32\x14.google.protobuf.Any\"\x9b\x02\n\x07\x41\x64\x61pter\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06vendor\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12&\n\x06\x63onfig\x18\x10 \x01(\x0b\x32\x16.adapter.AdapterConfig\x12\x34\n\x16\x61\x64\x64itional_description\x18@ \x01(\x0b\x32\x14.google.protobuf.Any\x12\x1a\n\x12logical_device_ids\x18\x04 \x03(\t\x12\x1a\n\x12last_communication\x18\x05 \x01(\x03\x12\x16\n\x0e\x63urrentReplica\x18\x06 \x01(\x05\x12\x15\n\rtotalReplicas\x18\x07 \x01(\x05\x12\x10\n\x08\x65ndpoint\x18\x08 \x01(\t\x12\x0c\n\x04type\x18\t \x01(\t\"+\n\x08\x41\x64\x61pters\x12\x1f\n\x05items\x18\x01 \x03(\x0b\x32\x10.adapter.AdapterB\\\n\x1borg.opencord.voltha.adapterB\rVolthaAdapterZ.github.com/opencord/voltha-protos/v5/go/volthab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'voltha_protos.adapter_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033org.opencord.voltha.adapterB\rVolthaAdapterZ.github.com/opencord/voltha-protos/v5/go/voltha'
  _globals['_ADAPTERCONFIG']._serialized_start=67
  _globals['_ADAPTERCONFIG']._serialized_end=131
  _globals['_ADAPTER']._serialized_start=134
  _globals['_ADAPTER']._serialized_end=417
  _globals['_ADAPTERS']._serialized_start=419
  _globals['_ADAPTERS']._serialized_end=462
# @@protoc_insertion_point(module_scope)
