# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/logical_device.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from voltha_protos import openflow_13_pb2 as voltha__protos_dot_openflow__13__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"voltha_protos/logical_device.proto\x12\x0elogical_device\x1a\x1cgoogle/api/annotations.proto\x1a\x1fvoltha_protos/openflow_13.proto\",\n\rLogicalPortId\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07port_id\x18\x02 \x01(\t\"\xb5\x01\n\x0bLogicalPort\x12\n\n\x02id\x18\x01 \x01(\t\x12\'\n\x08ofp_port\x18\x02 \x01(\x0b\x32\x15.openflow_13.ofp_port\x12\x11\n\tdevice_id\x18\x03 \x01(\t\x12\x16\n\x0e\x64\x65vice_port_no\x18\x04 \x01(\r\x12\x11\n\troot_port\x18\x05 \x01(\x08\x12\x33\n\x0eofp_port_stats\x18\x06 \x01(\x0b\x32\x1b.openflow_13.ofp_port_stats\":\n\x0cLogicalPorts\x12*\n\x05items\x18\x01 \x03(\x0b\x32\x1b.logical_device.LogicalPort\"\xa8\x01\n\rLogicalDevice\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x61tapath_id\x18\x02 \x01(\x04\x12#\n\x04\x64\x65sc\x18\x03 \x01(\x0b\x32\x15.openflow_13.ofp_desc\x12\x39\n\x0fswitch_features\x18\x04 \x01(\x0b\x32 .openflow_13.ofp_switch_features\x12\x16\n\x0eroot_device_id\x18\x05 \x01(\t\">\n\x0eLogicalDevices\x12,\n\x05items\x18\x01 \x03(\x0b\x32\x1d.logical_device.LogicalDeviceBe\n\"org.opencord.voltha.logical_deviceB\x0fOFLogicalDeviceZ.github.com/opencord/voltha-protos/v5/go/volthab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'voltha_protos.logical_device_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"org.opencord.voltha.logical_deviceB\017OFLogicalDeviceZ.github.com/opencord/voltha-protos/v5/go/voltha'
  _globals['_LOGICALPORTID']._serialized_start=117
  _globals['_LOGICALPORTID']._serialized_end=161
  _globals['_LOGICALPORT']._serialized_start=164
  _globals['_LOGICALPORT']._serialized_end=345
  _globals['_LOGICALPORTS']._serialized_start=347
  _globals['_LOGICALPORTS']._serialized_end=405
  _globals['_LOGICALDEVICE']._serialized_start=408
  _globals['_LOGICALDEVICE']._serialized_end=576
  _globals['_LOGICALDEVICES']._serialized_start=578
  _globals['_LOGICALDEVICES']._serialized_end=640
# @@protoc_insertion_point(module_scope)
