# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/events.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from voltha_protos import common_pb2 as voltha__protos_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1avoltha_protos/events.proto\x12\x05\x65vent\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1avoltha_protos/common.proto\"\x9e\x01\n\x12\x45ventFilterRuleKey\"\x87\x01\n\x13\x45ventFilterRuleType\x12\x0e\n\nfilter_all\x10\x00\x12\x0c\n\x08\x63\x61tegory\x10\x01\x12\x10\n\x0csub_category\x10\x02\x12\x12\n\x0ekpi_event_type\x10\x03\x12\x15\n\x11\x63onfig_event_type\x10\x04\x12\x15\n\x11\x64\x65vice_event_type\x10\x05\"\\\n\x0f\x45ventFilterRule\x12:\n\x03key\x18\x01 \x01(\x0e\x32-.event.EventFilterRuleKey.EventFilterRuleType\x12\r\n\x05value\x18\x02 \x01(\t\"w\n\x0b\x45ventFilter\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06\x65nable\x18\x02 \x01(\x08\x12\x11\n\tdevice_id\x18\x03 \x01(\t\x12\x12\n\nevent_type\x18\x04 \x01(\t\x12%\n\x05rules\x18\x05 \x03(\x0b\x32\x16.event.EventFilterRule\"3\n\x0c\x45ventFilters\x12#\n\x07\x66ilters\x18\x01 \x03(\x0b\x32\x12.event.EventFilter\";\n\x0f\x43onfigEventType\"(\n\x05Types\x12\x07\n\x03\x61\x64\x64\x10\x00\x12\n\n\x06remove\x10\x01\x12\n\n\x06update\x10\x02\"U\n\x0b\x43onfigEvent\x12*\n\x04type\x18\x01 \x01(\x0e\x32\x1c.event.ConfigEventType.Types\x12\x0c\n\x04hash\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\t\"*\n\x0cKpiEventType\"\x1a\n\x05Types\x12\t\n\x05slice\x10\x00\x12\x06\n\x02ts\x10\x01\"\xdf\x01\n\x0eMetricMetaData\x12\r\n\x05title\x18\x01 \x01(\t\x12\n\n\x02ts\x18\x02 \x01(\x01\x12\x19\n\x11logical_device_id\x18\x03 \x01(\t\x12\x11\n\tserial_no\x18\x04 \x01(\t\x12\x11\n\tdevice_id\x18\x05 \x01(\t\x12\x33\n\x07\x63ontext\x18\x06 \x03(\x0b\x32\".event.MetricMetaData.ContextEntry\x12\x0c\n\x04uuid\x18\x07 \x01(\t\x1a.\n\x0c\x43ontextEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"y\n\x10MetricValuePairs\x12\x35\n\x07metrics\x18\x01 \x03(\x0b\x32$.event.MetricValuePairs.MetricsEntry\x1a.\n\x0cMetricsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\"\xa4\x01\n\x11MetricInformation\x12\'\n\x08metadata\x18\x01 \x01(\x0b\x32\x15.event.MetricMetaData\x12\x36\n\x07metrics\x18\x02 \x03(\x0b\x32%.event.MetricInformation.MetricsEntry\x1a.\n\x0cMetricsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\"\xa8\x01\n\x13MetricInformation64\x12\'\n\x08metadata\x18\x01 \x01(\x0b\x32\x15.event.MetricMetaData\x12\x38\n\x07metrics\x18\x02 \x03(\x0b\x32\'.event.MetricInformation64.MetricsEntry\x1a.\n\x0cMetricsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\"\xba\x01\n\x08KpiEvent\x12\'\n\x04type\x18\x01 \x01(\x0e\x32\x19.event.KpiEventType.Types\x12\n\n\x02ts\x18\x02 \x01(\x02\x12/\n\x08prefixes\x18\x03 \x03(\x0b\x32\x1d.event.KpiEvent.PrefixesEntry\x1aH\n\rPrefixesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.event.MetricValuePairs:\x02\x38\x01\"n\n\tKpiEvent2\x12\'\n\x04type\x18\x01 \x01(\x0e\x32\x19.event.KpiEventType.Types\x12\n\n\x02ts\x18\x02 \x01(\x01\x12,\n\nslice_data\x18\x03 \x03(\x0b\x32\x18.event.MetricInformation\"p\n\tKpiEvent3\x12\'\n\x04type\x18\x01 \x01(\x0e\x32\x19.event.KpiEventType.Types\x12\n\n\x02ts\x18\x02 \x01(\x01\x12.\n\nslice_data\x18\x03 \x03(\x0b\x32\x1a.event.MetricInformation64\"\xb4\x01\n\x0b\x44\x65viceEvent\x12\x13\n\x0bresource_id\x18\x01 \x01(\t\x12\x19\n\x11\x64\x65vice_event_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x30\n\x07\x63ontext\x18\x04 \x03(\x0b\x32\x1f.event.DeviceEvent.ContextEntry\x1a.\n\x0c\x43ontextEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x80\x02\n\x08RPCEvent\x12\x0b\n\x03rpc\x18\x01 \x01(\t\x12\x14\n\x0coperation_id\x18\x02 \x01(\t\x12\x0f\n\x07service\x18\x03 \x01(\t\x12\x10\n\x08stack_id\x18\x04 \x01(\t\x12\x13\n\x0bresource_id\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12-\n\x07\x63ontext\x18\x07 \x03(\x0b\x32\x1c.event.RPCEvent.ContextEntry\x12%\n\x06status\x18\x08 \x01(\x0b\x32\x15.common.OperationResp\x1a.\n\x0c\x43ontextEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"v\n\rEventCategory\"e\n\x05Types\x12\x11\n\rCOMMUNICATION\x10\x00\x12\x0f\n\x0b\x45NVIRONMENT\x10\x01\x12\r\n\tEQUIPMENT\x10\x02\x12\x0b\n\x07SERVICE\x10\x03\x12\x0e\n\nPROCESSING\x10\x04\x12\x0c\n\x08SECURITY\x10\x05\"R\n\x10\x45ventSubCategory\">\n\x05Types\x12\x07\n\x03PON\x10\x00\x12\x07\n\x03OLT\x10\x01\x12\x07\n\x03ONT\x10\x02\x12\x07\n\x03ONU\x10\x03\x12\x07\n\x03NNI\x10\x04\x12\x08\n\x04NONE\x10\x05\"v\n\tEventType\"i\n\x05Types\x12\x10\n\x0c\x43ONFIG_EVENT\x10\x00\x12\r\n\tKPI_EVENT\x10\x01\x12\x0e\n\nKPI_EVENT2\x10\x02\x12\x10\n\x0c\x44\x45VICE_EVENT\x10\x03\x12\r\n\tRPC_EVENT\x10\x04\x12\x0e\n\nKPI_EVENT3\x10\x05\"\x98\x02\n\x0b\x45ventHeader\x12\n\n\x02id\x18\x01 \x01(\t\x12,\n\x08\x63\x61tegory\x18\x02 \x01(\x0e\x32\x1a.event.EventCategory.Types\x12\x33\n\x0csub_category\x18\x03 \x01(\x0e\x32\x1d.event.EventSubCategory.Types\x12$\n\x04type\x18\x04 \x01(\x0e\x32\x16.event.EventType.Types\x12\x14\n\x0ctype_version\x18\x05 \x01(\t\x12-\n\traised_ts\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0breported_ts\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xad\x02\n\x05\x45vent\x12\"\n\x06header\x18\x01 \x01(\x0b\x32\x12.event.EventHeader\x12*\n\x0c\x63onfig_event\x18\x02 \x01(\x0b\x32\x12.event.ConfigEventH\x00\x12$\n\tkpi_event\x18\x03 \x01(\x0b\x32\x0f.event.KpiEventH\x00\x12&\n\nkpi_event2\x18\x04 \x01(\x0b\x32\x10.event.KpiEvent2H\x00\x12*\n\x0c\x64\x65vice_event\x18\x05 \x01(\x0b\x32\x12.event.DeviceEventH\x00\x12$\n\trpc_event\x18\x06 \x01(\x0b\x32\x0f.event.RPCEventH\x00\x12&\n\nkpi_event3\x18\x07 \x01(\x0b\x32\x10.event.KpiEvent3H\x00\x42\x0c\n\nevent_typeBL\n\x1aorg.opencord.voltha.eventsZ.github.com/opencord/voltha-protos/v5/go/volthab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'voltha_protos.events_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032org.opencord.voltha.eventsZ.github.com/opencord/voltha-protos/v5/go/voltha'
  _globals['_METRICMETADATA_CONTEXTENTRY']._options = None
  _globals['_METRICMETADATA_CONTEXTENTRY']._serialized_options = b'8\001'
  _globals['_METRICVALUEPAIRS_METRICSENTRY']._options = None
  _globals['_METRICVALUEPAIRS_METRICSENTRY']._serialized_options = b'8\001'
  _globals['_METRICINFORMATION_METRICSENTRY']._options = None
  _globals['_METRICINFORMATION_METRICSENTRY']._serialized_options = b'8\001'
  _globals['_METRICINFORMATION64_METRICSENTRY']._options = None
  _globals['_METRICINFORMATION64_METRICSENTRY']._serialized_options = b'8\001'
  _globals['_KPIEVENT_PREFIXESENTRY']._options = None
  _globals['_KPIEVENT_PREFIXESENTRY']._serialized_options = b'8\001'
  _globals['_DEVICEEVENT_CONTEXTENTRY']._options = None
  _globals['_DEVICEEVENT_CONTEXTENTRY']._serialized_options = b'8\001'
  _globals['_RPCEVENT_CONTEXTENTRY']._options = None
  _globals['_RPCEVENT_CONTEXTENTRY']._serialized_options = b'8\001'
  _globals['_EVENTFILTERRULEKEY']._serialized_start=129
  _globals['_EVENTFILTERRULEKEY']._serialized_end=287
  _globals['_EVENTFILTERRULEKEY_EVENTFILTERRULETYPE']._serialized_start=152
  _globals['_EVENTFILTERRULEKEY_EVENTFILTERRULETYPE']._serialized_end=287
  _globals['_EVENTFILTERRULE']._serialized_start=289
  _globals['_EVENTFILTERRULE']._serialized_end=381
  _globals['_EVENTFILTER']._serialized_start=383
  _globals['_EVENTFILTER']._serialized_end=502
  _globals['_EVENTFILTERS']._serialized_start=504
  _globals['_EVENTFILTERS']._serialized_end=555
  _globals['_CONFIGEVENTTYPE']._serialized_start=557
  _globals['_CONFIGEVENTTYPE']._serialized_end=616
  _globals['_CONFIGEVENTTYPE_TYPES']._serialized_start=576
  _globals['_CONFIGEVENTTYPE_TYPES']._serialized_end=616
  _globals['_CONFIGEVENT']._serialized_start=618
  _globals['_CONFIGEVENT']._serialized_end=703
  _globals['_KPIEVENTTYPE']._serialized_start=705
  _globals['_KPIEVENTTYPE']._serialized_end=747
  _globals['_KPIEVENTTYPE_TYPES']._serialized_start=721
  _globals['_KPIEVENTTYPE_TYPES']._serialized_end=747
  _globals['_METRICMETADATA']._serialized_start=750
  _globals['_METRICMETADATA']._serialized_end=973
  _globals['_METRICMETADATA_CONTEXTENTRY']._serialized_start=927
  _globals['_METRICMETADATA_CONTEXTENTRY']._serialized_end=973
  _globals['_METRICVALUEPAIRS']._serialized_start=975
  _globals['_METRICVALUEPAIRS']._serialized_end=1096
  _globals['_METRICVALUEPAIRS_METRICSENTRY']._serialized_start=1050
  _globals['_METRICVALUEPAIRS_METRICSENTRY']._serialized_end=1096
  _globals['_METRICINFORMATION']._serialized_start=1099
  _globals['_METRICINFORMATION']._serialized_end=1263
  _globals['_METRICINFORMATION_METRICSENTRY']._serialized_start=1050
  _globals['_METRICINFORMATION_METRICSENTRY']._serialized_end=1096
  _globals['_METRICINFORMATION64']._serialized_start=1266
  _globals['_METRICINFORMATION64']._serialized_end=1434
  _globals['_METRICINFORMATION64_METRICSENTRY']._serialized_start=1388
  _globals['_METRICINFORMATION64_METRICSENTRY']._serialized_end=1434
  _globals['_KPIEVENT']._serialized_start=1437
  _globals['_KPIEVENT']._serialized_end=1623
  _globals['_KPIEVENT_PREFIXESENTRY']._serialized_start=1551
  _globals['_KPIEVENT_PREFIXESENTRY']._serialized_end=1623
  _globals['_KPIEVENT2']._serialized_start=1625
  _globals['_KPIEVENT2']._serialized_end=1735
  _globals['_KPIEVENT3']._serialized_start=1737
  _globals['_KPIEVENT3']._serialized_end=1849
  _globals['_DEVICEEVENT']._serialized_start=1852
  _globals['_DEVICEEVENT']._serialized_end=2032
  _globals['_DEVICEEVENT_CONTEXTENTRY']._serialized_start=927
  _globals['_DEVICEEVENT_CONTEXTENTRY']._serialized_end=973
  _globals['_RPCEVENT']._serialized_start=2035
  _globals['_RPCEVENT']._serialized_end=2291
  _globals['_RPCEVENT_CONTEXTENTRY']._serialized_start=927
  _globals['_RPCEVENT_CONTEXTENTRY']._serialized_end=973
  _globals['_EVENTCATEGORY']._serialized_start=2293
  _globals['_EVENTCATEGORY']._serialized_end=2411
  _globals['_EVENTCATEGORY_TYPES']._serialized_start=2310
  _globals['_EVENTCATEGORY_TYPES']._serialized_end=2411
  _globals['_EVENTSUBCATEGORY']._serialized_start=2413
  _globals['_EVENTSUBCATEGORY']._serialized_end=2495
  _globals['_EVENTSUBCATEGORY_TYPES']._serialized_start=2433
  _globals['_EVENTSUBCATEGORY_TYPES']._serialized_end=2495
  _globals['_EVENTTYPE']._serialized_start=2497
  _globals['_EVENTTYPE']._serialized_end=2615
  _globals['_EVENTTYPE_TYPES']._serialized_start=2510
  _globals['_EVENTTYPE_TYPES']._serialized_end=2615
  _globals['_EVENTHEADER']._serialized_start=2618
  _globals['_EVENTHEADER']._serialized_end=2898
  _globals['_EVENT']._serialized_start=2901
  _globals['_EVENT']._serialized_end=3202
# @@protoc_insertion_point(module_scope)
