# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/omci_mib_db.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fvoltha_protos/omci_mib_db.proto\x12\x04omci\"/\n\x10MibAttributeData\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"u\n\x0fMibInstanceData\x12\x13\n\x0binstance_id\x18\x01 \x01(\r\x12\x0f\n\x07\x63reated\x18\x02 \x01(\t\x12\x10\n\x08modified\x18\x03 \x01(\t\x12*\n\nattributes\x18\x04 \x03(\x0b\x32\x16.omci.MibAttributeData\"J\n\x0cMibClassData\x12\x10\n\x08\x63lass_id\x18\x01 \x01(\r\x12(\n\tinstances\x18\x02 \x03(\x0b\x32\x15.omci.MibInstanceData\"/\n\rManagedEntity\x12\x10\n\x08\x63lass_id\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\"#\n\x0bMessageType\x12\x14\n\x0cmessage_type\x18\x01 \x01(\r\"\xf1\x01\n\rMibDeviceData\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x0f\n\x07\x63reated\x18\x02 \x01(\t\x12\x16\n\x0elast_sync_time\x18\x03 \x01(\t\x12\x15\n\rmib_data_sync\x18\x04 \x01(\r\x12\x0f\n\x07version\x18\x05 \x01(\r\x12#\n\x07\x63lasses\x18\x06 \x03(\x0b\x32\x12.omci.MibClassData\x12-\n\x10managed_entities\x18\x07 \x03(\x0b\x32\x13.omci.ManagedEntity\x12(\n\rmessage_types\x18\x08 \x03(\x0b\x32\x11.omci.MessageType\".\n\x11OpenOmciEventType\"\x19\n\x05Types\x12\x10\n\x0cstate_change\x10\x00\"J\n\rOpenOmciEvent\x12+\n\x04type\x18\x01 \x01(\x0e\x32\x1d.omci.OpenOmciEventType.Types\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\tBH\n\x18org.opencord.voltha.omciZ,github.com/opencord/voltha-protos/v5/go/omcib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'voltha_protos.omci_mib_db_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\030org.opencord.voltha.omciZ,github.com/opencord/voltha-protos/v5/go/omci'
  _globals['_MIBATTRIBUTEDATA']._serialized_start=41
  _globals['_MIBATTRIBUTEDATA']._serialized_end=88
  _globals['_MIBINSTANCEDATA']._serialized_start=90
  _globals['_MIBINSTANCEDATA']._serialized_end=207
  _globals['_MIBCLASSDATA']._serialized_start=209
  _globals['_MIBCLASSDATA']._serialized_end=283
  _globals['_MANAGEDENTITY']._serialized_start=285
  _globals['_MANAGEDENTITY']._serialized_end=332
  _globals['_MESSAGETYPE']._serialized_start=334
  _globals['_MESSAGETYPE']._serialized_end=369
  _globals['_MIBDEVICEDATA']._serialized_start=372
  _globals['_MIBDEVICEDATA']._serialized_end=613
  _globals['_OPENOMCIEVENTTYPE']._serialized_start=615
  _globals['_OPENOMCIEVENTTYPE']._serialized_end=661
  _globals['_OPENOMCIEVENTTYPE_TYPES']._serialized_start=636
  _globals['_OPENOMCIEVENTTYPE_TYPES']._serialized_end=661
  _globals['_OPENOMCIEVENT']._serialized_start=663
  _globals['_OPENOMCIEVENT']._serialized_end=737
# @@protoc_insertion_point(module_scope)
