# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/tech_profile.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n voltha_protos/tech_profile.proto\x12\x0ctech_profile\x1a\x1cgoogle/api/annotations.proto\"\xc8\x01\n\x0fSchedulerConfig\x12*\n\tdirection\x18\x01 \x01(\x0e\x32\x17.tech_profile.Direction\x12\x31\n\radditional_bw\x18\x02 \x01(\x0e\x32\x1a.tech_profile.AdditionalBW\x12\x10\n\x08priority\x18\x03 \x01(\x07\x12\x0e\n\x06weight\x18\x04 \x01(\x07\x12\x34\n\x0csched_policy\x18\x05 \x01(\x0e\x32\x1e.tech_profile.SchedulingPolicy\"\x95\x01\n\x12TrafficShapingInfo\x12\x0b\n\x03\x63ir\x18\x01 \x01(\x07\x12\x0b\n\x03\x63\x62s\x18\x02 \x01(\x07\x12\x0b\n\x03pir\x18\x03 \x01(\x07\x12\x0b\n\x03pbs\x18\x04 \x01(\x07\x12\x0b\n\x03gir\x18\x05 \x01(\x07\x12>\n\nadd_bw_ind\x18\x06 \x01(\x0e\x32*.tech_profile.InferredAdditionBWIndication\"\xdb\x01\n\x10TrafficScheduler\x12*\n\tdirection\x18\x01 \x01(\x0e\x32\x17.tech_profile.Direction\x12\x10\n\x08\x61lloc_id\x18\x02 \x01(\x07\x12\x30\n\tscheduler\x18\x03 \x01(\x0b\x32\x1d.tech_profile.SchedulerConfig\x12>\n\x14traffic_shaping_info\x18\x04 \x01(\x0b\x32 .tech_profile.TrafficShapingInfo\x12\x17\n\x0ftech_profile_id\x18\x05 \x01(\x07\"\x8d\x01\n\x11TrafficSchedulers\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06uni_id\x18\x04 \x01(\x07\x12\x0f\n\x07port_no\x18\x05 \x01(\x07\x12\x36\n\x0etraffic_scheds\x18\x03 \x03(\x0b\x32\x1e.tech_profile.TrafficScheduler\"+\n\x15TailDropDiscardConfig\x12\x12\n\nqueue_size\x18\x01 \x01(\x07\"Y\n\x10RedDiscardConfig\x12\x15\n\rmin_threshold\x18\x01 \x01(\x07\x12\x15\n\rmax_threshold\x18\x02 \x01(\x07\x12\x17\n\x0fmax_probability\x18\x03 \x01(\x07\"\x9f\x01\n\x11WRedDiscardConfig\x12-\n\x05green\x18\x01 \x01(\x0b\x32\x1e.tech_profile.RedDiscardConfig\x12.\n\x06yellow\x18\x02 \x01(\x0b\x32\x1e.tech_profile.RedDiscardConfig\x12+\n\x03red\x18\x03 \x01(\x0b\x32\x1e.tech_profile.RedDiscardConfig\"\x9d\x02\n\rDiscardConfig\x12\x33\n\x0e\x64iscard_policy\x18\x01 \x01(\x0e\x32\x1b.tech_profile.DiscardPolicy\x12G\n\x18tail_drop_discard_config\x18\x02 \x01(\x0b\x32#.tech_profile.TailDropDiscardConfigH\x00\x12<\n\x12red_discard_config\x18\x03 \x01(\x0b\x32\x1e.tech_profile.RedDiscardConfigH\x00\x12>\n\x13wred_discard_config\x18\x04 \x01(\x0b\x32\x1f.tech_profile.WRedDiscardConfigH\x00\x42\x10\n\x0e\x64iscard_config\"\xba\x02\n\x0cTrafficQueue\x12*\n\tdirection\x18\x01 \x01(\x0e\x32\x17.tech_profile.Direction\x12\x12\n\ngemport_id\x18\x02 \x01(\x07\x12\x10\n\x08pbit_map\x18\x03 \x01(\t\x12\x16\n\x0e\x61\x65s_encryption\x18\x04 \x01(\x08\x12\x34\n\x0csched_policy\x18\x05 \x01(\x0e\x32\x1e.tech_profile.SchedulingPolicy\x12\x10\n\x08priority\x18\x06 \x01(\x07\x12\x0e\n\x06weight\x18\x07 \x01(\x07\x12\x33\n\x0e\x64iscard_policy\x18\x08 \x01(\x0e\x32\x1b.tech_profile.DiscardPolicy\x12\x33\n\x0e\x64iscard_config\x18\t \x01(\x0b\x32\x1b.tech_profile.DiscardConfig\"\xb7\x01\n\rTrafficQueues\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06uni_id\x18\x04 \x01(\x07\x12\x0f\n\x07port_no\x18\x05 \x01(\x07\x12\x32\n\x0etraffic_queues\x18\x06 \x03(\x0b\x32\x1a.tech_profile.TrafficQueue\x12\x17\n\x0ftech_profile_id\x18\x07 \x01(\x07\x12\x17\n\x0fnetwork_intf_id\x18\x08 \x01(\x07\"I\n\x0fInstanceControl\x12\x0b\n\x03onu\x18\x01 \x01(\t\x12\x0b\n\x03uni\x18\x02 \x01(\t\x12\x1c\n\x14max_gem_payload_size\x18\x03 \x01(\t\"\xa7\x01\n\x0bQThresholds\x12\x14\n\x0cq_threshold1\x18\x01 \x01(\r\x12\x14\n\x0cq_threshold2\x18\x02 \x01(\r\x12\x14\n\x0cq_threshold3\x18\x03 \x01(\r\x12\x14\n\x0cq_threshold4\x18\x04 \x01(\r\x12\x14\n\x0cq_threshold5\x18\x05 \x01(\r\x12\x14\n\x0cq_threshold6\x18\x06 \x01(\r\x12\x14\n\x0cq_threshold7\x18\x07 \x01(\r\"\xe2\x03\n\x11GemPortAttributes\x12\x12\n\ngemport_id\x18\x01 \x01(\x07\x12\x12\n\nmax_q_size\x18\x02 \x01(\t\x12\x10\n\x08pbit_map\x18\x03 \x01(\t\x12\x16\n\x0e\x61\x65s_encryption\x18\x04 \x01(\t\x12\x39\n\x11scheduling_policy\x18\x05 \x01(\x0e\x32\x1e.tech_profile.SchedulingPolicy\x12\x12\n\npriority_q\x18\x06 \x01(\x07\x12\x0e\n\x06weight\x18\x07 \x01(\x07\x12\x33\n\x0e\x64iscard_policy\x18\x08 \x01(\x0e\x32\x1b.tech_profile.DiscardPolicy\x12\x36\n\x0e\x64iscard_config\x18\t \x01(\x0b\x32\x1e.tech_profile.RedDiscardConfig\x12\x36\n\x11\x64iscard_config_v2\x18\x0e \x01(\x0b\x32\x1b.tech_profile.DiscardConfig\x12\x14\n\x0cis_multicast\x18\n \x01(\t\x12\x18\n\x10multicast_gem_id\x18\x0b \x01(\x07\x12#\n\x1b\x64ynamic_access_control_list\x18\x0c \x01(\t\x12\"\n\x1astatic_access_control_list\x18\r \x01(\t\"\xe0\x01\n\x13SchedulerAttributes\x12*\n\tdirection\x18\x01 \x01(\x0e\x32\x17.tech_profile.Direction\x12\x10\n\x08\x61lloc_id\x18\x02 \x01(\r\x12\x31\n\radditional_bw\x18\x03 \x01(\x0e\x32\x1a.tech_profile.AdditionalBW\x12\x10\n\x08priority\x18\x04 \x01(\x07\x12\x0e\n\x06weight\x18\x05 \x01(\x07\x12\x36\n\x0eq_sched_policy\x18\x06 \x01(\x0e\x32\x1e.tech_profile.SchedulingPolicy\"\xc4\x04\n\x13\x45PONQueueAttributes\x12\x12\n\nmax_q_size\x18\x01 \x01(\t\x12\x10\n\x08pbit_map\x18\x02 \x01(\t\x12\x12\n\ngemport_id\x18\x03 \x01(\r\x12\x16\n\x0e\x61\x65s_encryption\x18\x04 \x01(\t\x12\x14\n\x0ctraffic_type\x18\x05 \x01(\t\x12\x1e\n\x16unsolicited_grant_size\x18\x06 \x01(\r\x12\x18\n\x10nominal_interval\x18\x07 \x01(\r\x12\x1d\n\x15tolerated_poll_jitter\x18\x08 \x01(\r\x12#\n\x1brequest_transmission_policy\x18\t \x01(\r\x12\x12\n\nnum_q_sets\x18\n \x01(\r\x12/\n\x0cq_thresholds\x18\x0b \x01(\x0b\x32\x19.tech_profile.QThresholds\x12\x39\n\x11scheduling_policy\x18\x0c \x01(\x0e\x32\x1e.tech_profile.SchedulingPolicy\x12\x12\n\npriority_q\x18\r \x01(\r\x12\x0e\n\x06weight\x18\x0e \x01(\r\x12\x33\n\x0e\x64iscard_policy\x18\x0f \x01(\x0e\x32\x1b.tech_profile.DiscardPolicy\x12\x36\n\x0e\x64iscard_config\x18\x10 \x01(\x0b\x32\x1e.tech_profile.RedDiscardConfig\x12\x36\n\x11\x64iscard_config_v2\x18\x11 \x01(\x0b\x32\x1b.tech_profile.DiscardConfig\"\x9c\x03\n\x0bTechProfile\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\r\x12\x14\n\x0cprofile_type\x18\x03 \x01(\t\x12\x15\n\rnum_gem_ports\x18\x04 \x01(\r\x12\x37\n\x10instance_control\x18\x05 \x01(\x0b\x32\x1d.tech_profile.InstanceControl\x12\x37\n\x0cus_scheduler\x18\x06 \x01(\x0b\x32!.tech_profile.SchedulerAttributes\x12\x37\n\x0c\x64s_scheduler\x18\x07 \x01(\x0b\x32!.tech_profile.SchedulerAttributes\x12I\n upstream_gem_port_attribute_list\x18\x08 \x03(\x0b\x32\x1f.tech_profile.GemPortAttributes\x12K\n\"downstream_gem_port_attribute_list\x18\t \x03(\x0b\x32\x1f.tech_profile.GemPortAttributes\"\xc2\x02\n\x0f\x45ponTechProfile\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\r\x12\x14\n\x0cprofile_type\x18\x03 \x01(\t\x12\x15\n\rnum_gem_ports\x18\x04 \x01(\r\x12\x37\n\x10instance_control\x18\x05 \x01(\x0b\x32\x1d.tech_profile.InstanceControl\x12\x14\n\x0cpackage_type\x18\x06 \x01(\t\x12H\n\x1dupstream_queue_attribute_list\x18\x07 \x03(\x0b\x32!.tech_profile.EPONQueueAttributes\x12J\n\x1f\x64ownstream_queue_attribute_list\x18\x08 \x03(\x0b\x32!.tech_profile.EPONQueueAttributes\"\xc3\x03\n\x13TechProfileInstance\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\r\x12\x1d\n\x15subscriber_identifier\x18\x03 \x01(\t\x12\x14\n\x0cprofile_type\x18\x04 \x01(\t\x12\x15\n\rnum_gem_ports\x18\x05 \x01(\r\x12\x37\n\x10instance_control\x18\x06 \x01(\x0b\x32\x1d.tech_profile.InstanceControl\x12\x37\n\x0cus_scheduler\x18\x07 \x01(\x0b\x32!.tech_profile.SchedulerAttributes\x12\x37\n\x0c\x64s_scheduler\x18\x08 \x01(\x0b\x32!.tech_profile.SchedulerAttributes\x12I\n upstream_gem_port_attribute_list\x18\t \x03(\x0b\x32\x1f.tech_profile.GemPortAttributes\x12K\n\"downstream_gem_port_attribute_list\x18\n \x03(\x0b\x32\x1f.tech_profile.GemPortAttributes\"\xfb\x02\n\x17\x45ponTechProfileInstance\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\r\x12\x1d\n\x15subscriber_identifier\x18\x03 \x01(\t\x12\x14\n\x0cprofile_type\x18\x04 \x01(\t\x12\x15\n\rnum_gem_ports\x18\x05 \x01(\r\x12\x10\n\x08\x61lloc_id\x18\x06 \x01(\r\x12\x37\n\x10instance_control\x18\x07 \x01(\x0b\x32\x1d.tech_profile.InstanceControl\x12\x14\n\x0cpackage_type\x18\x08 \x01(\t\x12H\n\x1dupstream_queue_attribute_list\x18\t \x03(\x0b\x32!.tech_profile.EPONQueueAttributes\x12J\n\x1f\x64ownstream_queue_attribute_list\x18\n \x03(\x0b\x32!.tech_profile.EPONQueueAttributes\"}\n\x10ResourceInstance\x12\r\n\x05tp_id\x18\x01 \x01(\r\x12\x14\n\x0cprofile_type\x18\x02 \x01(\t\x12\x1d\n\x15subscriber_identifier\x18\x03 \x01(\t\x12\x10\n\x08\x61lloc_id\x18\x04 \x01(\r\x12\x13\n\x0bgemport_ids\x18\x05 \x03(\r*<\n\tDirection\x12\x0c\n\x08UPSTREAM\x10\x00\x12\x0e\n\nDOWNSTREAM\x10\x01\x12\x11\n\rBIDIRECTIONAL\x10\x02*;\n\x10SchedulingPolicy\x12\x07\n\x03WRR\x10\x00\x12\x12\n\x0eStrictPriority\x10\x01\x12\n\n\x06Hybrid\x10\x02*n\n\x0c\x41\x64\x64itionalBW\x12\x15\n\x11\x41\x64\x64itionalBW_None\x10\x00\x12\x13\n\x0f\x41\x64\x64itionalBW_NA\x10\x01\x12\x1b\n\x17\x41\x64\x64itionalBW_BestEffort\x10\x02\x12\x15\n\x11\x41\x64\x64itionalBW_Auto\x10\x03*?\n\rDiscardPolicy\x12\x0c\n\x08TailDrop\x10\x00\x12\r\n\tWTailDrop\x10\x01\x12\x07\n\x03Red\x10\x02\x12\x08\n\x04WRed\x10\x03*\x9c\x01\n\x1cInferredAdditionBWIndication\x12%\n!InferredAdditionBWIndication_None\x10\x00\x12(\n$InferredAdditionBWIndication_Assured\x10\x01\x12+\n\'InferredAdditionBWIndication_BestEffort\x10\x02\x42X\n org.opencord.voltha.tech_profileZ4github.com/opencord/voltha-protos/v5/go/tech_profileb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'voltha_protos.tech_profile_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n org.opencord.voltha.tech_profileZ4github.com/opencord/voltha-protos/v5/go/tech_profile'
  _globals['_DIRECTION']._serialized_start=5133
  _globals['_DIRECTION']._serialized_end=5193
  _globals['_SCHEDULINGPOLICY']._serialized_start=5195
  _globals['_SCHEDULINGPOLICY']._serialized_end=5254
  _globals['_ADDITIONALBW']._serialized_start=5256
  _globals['_ADDITIONALBW']._serialized_end=5366
  _globals['_DISCARDPOLICY']._serialized_start=5368
  _globals['_DISCARDPOLICY']._serialized_end=5431
  _globals['_INFERREDADDITIONBWINDICATION']._serialized_start=5434
  _globals['_INFERREDADDITIONBWINDICATION']._serialized_end=5590
  _globals['_SCHEDULERCONFIG']._serialized_start=81
  _globals['_SCHEDULERCONFIG']._serialized_end=281
  _globals['_TRAFFICSHAPINGINFO']._serialized_start=284
  _globals['_TRAFFICSHAPINGINFO']._serialized_end=433
  _globals['_TRAFFICSCHEDULER']._serialized_start=436
  _globals['_TRAFFICSCHEDULER']._serialized_end=655
  _globals['_TRAFFICSCHEDULERS']._serialized_start=658
  _globals['_TRAFFICSCHEDULERS']._serialized_end=799
  _globals['_TAILDROPDISCARDCONFIG']._serialized_start=801
  _globals['_TAILDROPDISCARDCONFIG']._serialized_end=844
  _globals['_REDDISCARDCONFIG']._serialized_start=846
  _globals['_REDDISCARDCONFIG']._serialized_end=935
  _globals['_WREDDISCARDCONFIG']._serialized_start=938
  _globals['_WREDDISCARDCONFIG']._serialized_end=1097
  _globals['_DISCARDCONFIG']._serialized_start=1100
  _globals['_DISCARDCONFIG']._serialized_end=1385
  _globals['_TRAFFICQUEUE']._serialized_start=1388
  _globals['_TRAFFICQUEUE']._serialized_end=1702
  _globals['_TRAFFICQUEUES']._serialized_start=1705
  _globals['_TRAFFICQUEUES']._serialized_end=1888
  _globals['_INSTANCECONTROL']._serialized_start=1890
  _globals['_INSTANCECONTROL']._serialized_end=1963
  _globals['_QTHRESHOLDS']._serialized_start=1966
  _globals['_QTHRESHOLDS']._serialized_end=2133
  _globals['_GEMPORTATTRIBUTES']._serialized_start=2136
  _globals['_GEMPORTATTRIBUTES']._serialized_end=2618
  _globals['_SCHEDULERATTRIBUTES']._serialized_start=2621
  _globals['_SCHEDULERATTRIBUTES']._serialized_end=2845
  _globals['_EPONQUEUEATTRIBUTES']._serialized_start=2848
  _globals['_EPONQUEUEATTRIBUTES']._serialized_end=3428
  _globals['_TECHPROFILE']._serialized_start=3431
  _globals['_TECHPROFILE']._serialized_end=3843
  _globals['_EPONTECHPROFILE']._serialized_start=3846
  _globals['_EPONTECHPROFILE']._serialized_end=4168
  _globals['_TECHPROFILEINSTANCE']._serialized_start=4171
  _globals['_TECHPROFILEINSTANCE']._serialized_end=4622
  _globals['_EPONTECHPROFILEINSTANCE']._serialized_start=4625
  _globals['_EPONTECHPROFILEINSTANCE']._serialized_end=5004
  _globals['_RESOURCEINSTANCE']._serialized_start=5006
  _globals['_RESOURCEINSTANCE']._serialized_end=5131
# @@protoc_insertion_point(module_scope)
